@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: aguix.cc,v 1.71 2004/10/27 20:34:14 ralf Exp $ */
+/* $Id: aguix.cc,v 1.72 2005/05/23 18:44:44 ralf Exp $ */
 
 #include "aguix.h"
 #include "awindow.h"
@@ -851,6 +851,18 @@ int AGUIX::msgHandler( int mode, AWindow *parent, bool onlyExpose )
 	     ( timerEnabled == true ) ) ) {
       break;
     }
+    //TODO Because it's possible to break the loop
+    //     the msgLockElement could be destroyed already
+    //     ReactMessage will reset msgLockElement if it doesn't
+    //     set ack, but when there's no msg, we can reach this
+    //     code
+    //     possible solution: check every window using contains()
+    if ( msgLockElement->getAllowTimerEventBreak() == true ) {
+      if ( msgLockElement->getNrOfLastEventBreak() != lastTimerEventNr ) {
+	msgLockElement->setNrOfLastEventBreak( lastTimerEventNr );
+	break;
+      }
+    }
 
     // now wait some time
 #ifndef USE_AGUIXTIMER
