@@ -1,6 +1,6 @@
 /* awindow.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: awindow.h,v 1.37 2004/10/27 20:35:28 ralf Exp $ */
+/* $Id: awindow.h,v 1.39 2005/06/23 18:13:00 ralf Exp $ */
 
 #ifndef AWINDOW_H
 #define AWINDOW_H
@@ -33,11 +33,20 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/keysym.h>
+#include "widget.h"
+#include <list>
+#include <string>
 
-class AWindow {
+class AWindow : public Widget {
 public:
-  AWindow(AGUIX *parent);
-  virtual ~AWindow();
+  AWindow( AGUIX *parent,
+	   int x,
+	   int y,
+	   int width,
+	   int height,
+	   int bg,
+	   std::string title );
+  ~AWindow();
   AWindow( const AWindow &other );
   AWindow &operator=( const AWindow &other );
 
@@ -49,48 +58,36 @@ public:
   int setResizable(int state);
   void setMaxSize(int mwidth,int mheight);
   void setMinSize(int mwidth,int mheight);
-  int create(AWindow *parent,int x,int y,int width,int height,int bg,const char *title);
-  virtual void close();
   void show();
   void show(Window);
   void hide();
   void hide(Window);
   void minimize();
   void toFront();
-  void move(int x,int y);
-  int getX() const;
-  int getY() const;
-  void resize(int width,int height);
+  void move( int nx, int ny );
+  void resize( int nw, int nh );
   void sizeChanged(int width,int height);
-  int getWidth() const;
-  int getHeight() const;
   void redraw();
   const char *getTitle() const;
-  void setTitle(const char *new_title);
-  const char *getName() const;
-  void setName(const char *new_name);
-  const char *getIconname() const;
-  void setIconname(const char *new_iconname);
-  GUIElement *add(GUIElement *new_element);
-  bool remove(GUIElement *elem);
+  void setTitle( std::string new_title );
   int getBG() const;
   void setBG(int bg);
   void ReactMessage(Message *msg);
-  virtual bool handleMessage(XEvent *,Message *msg);
+  bool handleMessage(XEvent *,Message *msg);
   void resizeSubWin(Window win,int w,int h);
   void moveSubWin(Window win,int x,int y);
-  bool hasSubWin(Window win);
+  bool hasSubWin(Window win) const;
   Window getSubWindow(Window parent,int x,int y,int w,int h);
   void removeSubWin(Window subwin);
-  void addSubAWindow(AWindow *child);
-  bool isParent(Window childwin,bool);
-  GUIElement *findGUIElement(Window);
+  bool isParent(Window childwin,bool) const;
+  bool isParent( Window ) const;
+  Widget *findWidgetForWindow( Window );
   void setCursor(int type);
   void unsetCursor();
   
   void invalidFocus();
-  void applyFocus(GUIElement *newfocus);
-  bool isOwner(GUIElement *f) const;
+  void applyFocus( Widget *newfocus );
+  bool isOwner( Widget *f ) const;
 
   void maximizeX();
   void maximizeY();
@@ -105,10 +102,8 @@ public:
 			 int *return_count,
 			 int *return_y );
   void centerScreen();
-  bool contains( GUIElement *elem );
-  GUIElement *getFocusOwner() const;
-  void registerFocusElement( GUIElement *elem );
-  void unregisterFocusElement( GUIElement *elem );
+  bool contains( Widget *elem ) const;
+  Widget *getFocusOwner() const;
   void nextFocus();
   void prevFocus();
   void setDoTabCycling( bool nv );
@@ -140,30 +135,21 @@ public:
   int getMapNr() const;
   AContainer *setContainer( AContainer *newcont, bool autoResize = false );
   void removeContainer( AContainer *cont );
-  void removeFromContainer( AWindow *twin );
+  void removeFromContainer( Widget *twid );
 
   void contMaximize( bool applyMinSize = false, bool applyMaxSize = false );
+  Widget *add( Widget *w );
+  void remove( Widget *w );
+  void destroy();
+  int create();
 protected:
-  int x,y,w,h;
   bool onScreen;
-  char *title;
-  char *name;
-  char *iconname;
-  int bg;
+  int _bg;
   int maxw,maxh,minw,minh;
   Window win;
-  AGUIX *aguix;
-  List *gui;
-  List *subwins;
-  List *subawins;
-  AWindow *parentawindow;
-  GUIElement *focusOwner;
+  std::list<Window> subwins;
   int border;
 
-  void removeSubAWindow(AWindow *child);
-  bool created;
-  List *focusElements;
-  void removeFocusElements( AWindow *child );
   bool doTabCycling;
   int forbidinput;
 #ifdef USE_XIM
@@ -175,6 +161,25 @@ protected:
   AContainer *container;
   bool contAutoResize;
   int msgW, msgH;
+  void doCreateStuff();
+  void doDestroyStuff();
+  int setParent( class AWindow *parent );
+  int setWMTitle();
+  const std::list<Widget*> &getChilds() const;
+
+  typedef enum { SEARCH_WIDGET, SEARCH_NEXT, SEARCH_FINISHED } focus_search_mode_t;
+  int searchNextFocus( focus_search_mode_t &search_mode,
+		       const Widget *element,
+		       Widget **new_element,
+		       Widget **prev_element = NULL );
+public:
+  Widget *searchNextFocus( const Widget *current );
+  Widget *searchPrevFocus( const Widget *current );
+private:
+  std::list<Widget*> _childs;
+  typedef std::list<Widget*>::iterator childs_it;
+  typedef std::list<Widget*>::const_iterator childs_const_it;
+  std::string _title;
 };
 
 #endif
