@@ -1,6 +1,6 @@
 /* bevelbox.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: bevelbox.cc,v 1.11 2004/10/27 20:37:12 ralf Exp $ */
+/* $Id: bevelbox.cc,v 1.12 2005/05/15 13:45:00 ralf Exp $ */
 
 #include "bevelbox.h"
 #include "lowlevelfunc.h"
@@ -39,10 +39,10 @@ BevelBox::BevelBox(AGUIX *taguix):GUIElement(taguix)
 BevelBox::BevelBox(AGUIX *taguix,int tx,int ty,int width,int height,
                    int tstate):GUIElement(taguix)
 {
-  this->x=tx;
-  this->y=ty;
-  if ( width > 0 ) this->w = width;
-  if ( height > 0 ) this->h = height;
+  _x=tx;
+  _y=ty;
+  if ( width > 0 ) _w = width;
+  if ( height > 0 ) _h = height;
   this->state=tstate;
   bgset=false;
 }
@@ -61,27 +61,27 @@ void BevelBox::setState(int tstate)
 
 void BevelBox::redraw()
 {
-  if(parent==NULL) return;
+  if ( isCreated() == false ) return;
 
   if(bgset==false) {
-    aguix->SetWindowBG(win,parent->getBG());
+    _aguix->SetWindowBG( win, _parent->getBG() );
     bgset=true;
   }
-  aguix->ClearWin(win);
+  _aguix->ClearWin(win);
   if(state==0) {
-    aguix->setFG(2);
+    _aguix->setFG(2);
   } else {
-    aguix->setFG(1);
+    _aguix->setFG(1);
   }
-  aguix->DrawLine(win,0,h-1,0,0);
-  aguix->DrawLine(win,0,0,w-1,0);
+  _aguix->DrawLine(win,0,_h-1,0,0);
+  _aguix->DrawLine(win,0,0,_w-1,0);
   if(state==0) {
-    aguix->setFG(1);
+    _aguix->setFG(1);
   } else {
-    aguix->setFG(2);
+    _aguix->setFG(2);
   }
-  aguix->DrawLine(win,0,h-1,w-1,h-1);
-  aguix->DrawLine(win,w-1,h-1,w-1,1);
+  _aguix->DrawLine(win,0,_h-1,_w-1,_h-1);
+  _aguix->DrawLine(win,_w-1,_h-1,_w-1,1);
 }
 
 void BevelBox::flush()
@@ -90,7 +90,7 @@ void BevelBox::flush()
 
 bool BevelBox::handleMessage(XEvent *E,Message *msg)
 {
-  if ( parent != NULL ) {
+  if ( isCreated() == true ) {
     if((msg->type==Expose)&&(msg->window==win)) {
       redraw();
     }
