@@ -1,6 +1,6 @@
 /* button.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: button.cc,v 1.27 2004/10/27 20:37:01 ralf Exp $ */
+/* $Id: button.cc,v 1.28 2005/05/15 13:45:12 ralf Exp $ */
 
 #include "button.h"
 #include "awindow.h"
@@ -32,112 +32,61 @@ Button::~Button()
   if(text[1]!=NULL) _freesafe(text[1]);
 }
 
-Button::Button(AGUIX *taguix):GUIElement(taguix)
-{
-  this->dual=false;
-  this->data=0;
-  this->state=0;
-  this->instate=0;
-  this->text[0]=(char*)_allocsafe(1);
-  this->text[1]=(char*)_allocsafe(1);
-  this->text[0][0]=0;
-  this->text[1][0]=0;
-  this->fg[0]=0;
-  this->fg[1]=0;
-  this->bg[0]=0;
-  this->bg[1]=0;
-  lastbg=-1;
-  showdual=true;
-  font=NULL;
-  active[0]=true;
-  active[1]=true;
-  canHandleFocus = true;
-  setAcceptFocus( true );
-  allowWheel = false;
-}
-
 Button::Button(AGUIX *taguix,int tx,int ty,int width,
                const char *ttext,int tfg,int tbg,int tdata):GUIElement(taguix)
 {
-  this->x=tx;
-  this->y=ty;
-  if ( width > 0 )this->w = width;
-  this->h=taguix->getCharHeight()+4;
-  this->dual=false;
-  this->data=tdata;
-  this->state=0;
-  this->instate=0;
-  this->text[0]=dupstring(ttext);
-  this->text[1]=(char*)_allocsafe(1);
-  this->text[1][0]=0;
-  this->fg[0]=tfg;
-  this->fg[1]=0;
-  this->bg[0]=tbg;
-  this->bg[1]=0;
-  lastbg=-1;
-  showdual=true;
-  font=NULL;
-  active[0]=true;
-  active[1]=true;
-  canHandleFocus = true;
-  setAcceptFocus( true );
-  allowWheel = false;
+  init_class();
+  
+  _x = tx;
+  _y = ty;
+  if ( width > 0 ) _w = width;
+  _h = taguix->getCharHeight() + 4;
+  fg[0] = tfg;
+  fg[1] = 0;
+  bg[0] = tbg;
+  bg[1] = 0;
+
+  data = tdata;
+  _freesafe( text[0] );
+  text[0] = dupstring( ttext );
 }
 
 Button::Button(AGUIX *taguix,int tx,int ty,
                const char *ttext,int tfg,int tbg,int tdata):GUIElement(taguix)
 {
-  this->x=tx;
-  this->y=ty;
-  this->w = ( strlen( ttext ) + 2 ) * taguix->getCharWidth();
-  this->h=taguix->getCharHeight()+4;
-  this->dual=false;
-  this->data=tdata;
-  this->state=0;
-  this->instate=0;
-  this->text[0]=dupstring(ttext);
-  this->text[1]=(char*)_allocsafe(1);
-  this->text[1][0]=0;
-  this->fg[0]=tfg;
-  this->fg[1]=0;
-  this->bg[0]=tbg;
-  this->bg[1]=0;
-  lastbg=-1;
-  showdual=true;
-  font=NULL;
-  active[0]=true;
-  active[1]=true;
-  canHandleFocus = true;
-  setAcceptFocus( true );
-  allowWheel = false;
+  init_class();
+  
+  _x = tx;
+  _y = ty;
+  _w = ( strlen( ttext ) + 2 ) * taguix->getCharWidth();
+  _h = taguix->getCharHeight() + 4;
+
+  data = tdata;
+  _freesafe( text[0] );
+  text[0] = dupstring( ttext );
+  fg[0] = tfg;
+  fg[1] = 0;
+  bg[0] = tbg;
+  bg[1] = 0;
 }
 
 Button::Button(AGUIX *taguix,int tx,int ty,int width,int height,
                const char *ttext,int tfg,int tbg,int tdata):GUIElement(taguix)
 {
-  this->x=tx;
-  this->y=ty;
-  if ( width > 0 ) this->w = width;
-  if ( height > 0 ) this->h = height;
-  this->dual=false;
-  this->data=tdata;
-  this->state=0;
-  this->instate=0;
-  this->text[0]=dupstring(ttext);
-  this->text[1]=(char*)_allocsafe(1);
-  this->text[1][0]=0;
-  this->fg[0]=tfg;
-  this->fg[1]=0;
-  this->bg[0]=tbg;
-  this->bg[1]=0;
-  lastbg=-1;
-  showdual=true;
-  font=NULL;
-  active[0]=true;
-  active[1]=true;
-  canHandleFocus = true;
-  setAcceptFocus( true );
-  allowWheel = false;
+  init_class();
+  
+  _x = tx;
+  _y = ty;
+  if ( width > 0 ) _w = width;
+  if ( height > 0 ) _h = height;
+
+  data = tdata;
+  _freesafe( text[0] );
+  text[0] = dupstring( ttext );
+  fg[0] = tfg;
+  fg[1] = 0;
+  bg[0] = tbg;
+  bg[1] = 0;
 }
 
 Button::Button(AGUIX *taguix,int tx,int ty,int width,
@@ -145,28 +94,23 @@ Button::Button(AGUIX *taguix,int tx,int ty,int width,
                int fg_normal,int fg_high,
                int bg_normal,int bg_high,int tdata):GUIElement(taguix)
 {
-  this->x=tx;
-  this->y=ty;
-  if ( width > 0 ) this->w = width;
-  this->h=taguix->getCharHeight()+4;
-  this->dual=true;
-  this->data=tdata;
-  this->state=0;
-  this->instate=0;
-  this->text[0]=dupstring(text_normal);
-  this->text[1]=dupstring(text_high);
-  this->fg[0]=fg_normal;
-  this->fg[1]=fg_high;
-  this->bg[0]=bg_normal;
-  this->bg[1]=bg_high;
-  lastbg=-1;
-  showdual=true;
-  font=NULL;
-  active[0]=true;
-  active[1]=true;
-  canHandleFocus = true;
-  setAcceptFocus( true );
-  allowWheel = false;
+  init_class();
+  
+  _x = tx;
+  _y = ty;
+  if ( width > 0 ) _w = width;
+  _h = taguix->getCharHeight() + 4;
+
+  dual = true;
+  data = tdata;
+  _freesafe( text[0] );
+  _freesafe( text[1] );
+  text[0] = dupstring( text_normal );
+  text[1] = dupstring( text_high );
+  fg[0] = fg_normal;
+  fg[1] = fg_high;
+  bg[0] = bg_normal;
+  bg[1] = bg_high;
 }
 
 const char *Button::getText(int index2) const
@@ -197,7 +141,7 @@ void Button::setDualState(bool new_dual)
 void Button::setFG(int index2,int tfg)
 {
   if((index2<0)||(index2>1)) return;
-  if((tfg<(aguix->getMaxCols()))&&(tfg>=0)) {
+  if((tfg<(_aguix->getMaxCols()))&&(tfg>=0)) {
     this->fg[index2]=tfg;
   }
   redraw();
@@ -212,7 +156,7 @@ int Button::getFG(int index2) const
 void Button::setBG(int index2,int tbg)
 {
   if((index2<0)||(index2>1)) return;
-  if((tbg<(aguix->getMaxCols()))&&(tbg>=0)) {
+  if((tbg<(_aguix->getMaxCols()))&&(tbg>=0)) {
     this->bg[index2]=tbg;
   }
   redraw();
@@ -251,8 +195,8 @@ void Button::redraw()
   char *tstr;
   int ch,cw;
 
-  if(parent==NULL) return;
-  if(win==0) return;
+  if ( isCreated() == false ) return;
+  if ( win == 0 ) return;
 
   /* Clear the window */
 
@@ -261,9 +205,9 @@ void Button::redraw()
   } else {
     newbg=bg[1];
   }
-  aguix->SetWindowBG(win,newbg);
+  _aguix->SetWindowBG(win,newbg);
   lastbg=newbg;
-  aguix->ClearWin(win);
+  _aguix->ClearWin(win);
   if(font==NULL) usegc=0; else usegc=font->getGC();
 
   /* calculate dimension of the turned-down corner */
@@ -271,35 +215,35 @@ void Button::redraw()
   if ( ( dual == true ) && ( showdual == true ) && ( state != 2 ) ) {
     showe = true;
 
-    dw=w/4;
-    dw2=(int)((double)(h/3)*1.3);
+    dw=_w/4;
+    dw2=(int)((double)(_h/3)*1.3);
     if( dw2 < dw ) dw = dw2;
 
-    px1 = w-dw;
+    px1 = _w-dw;
     py1 = 0;
-    px2 = w-dw;
+    px2 = _w-dw;
     py2 = dw-1;
-    px3 = w-1;
+    px3 = _w-1;
     py3 = dw-1;
   }
 
   /* draw the text */
 
   if ( ( dual == false ) || ( state != 2 ) ) {
-    aguix->setFG(usegc,fg[0]);
+    _aguix->setFG(usegc,fg[0]);
   } else {
-    aguix->setFG(usegc,fg[1]);
+    _aguix->setFG(usegc,fg[1]);
   }
   if(font==NULL) {
-    ch=aguix->getCharHeight();
-    cw=aguix->getCharWidth();
+    ch=_aguix->getCharHeight();
+    cw=_aguix->getCharWidth();
   } else {
     ch=font->getCharHeight();
     cw=font->getCharWidth();
   }
 
-  dy=h/2-ch/2;
-  maxdisplay=(w-2)/cw;
+  dy=_h/2-ch/2;
+  maxdisplay=(_w-2)/cw;
   if ( ( dual == false ) || ( state != 2 ) ) {
     tstr=dupstring(text[0]);
   } else {
@@ -307,59 +251,59 @@ void Button::redraw()
   }
   if(strlen(tstr)>maxdisplay) tstr[maxdisplay]=0;
   dw=strlen(tstr)*cw;
-  int dx=w/2-dw/2;
+  int dx=_w/2-dw/2;
   if(font==NULL) {
-    aguix->DrawText(win,tstr,dx,dy);
+    _aguix->DrawText(win,tstr,dx,dy);
   } else {
-    aguix->DrawText(win,font,tstr,dx,dy);
+    _aguix->DrawText(win,font,tstr,dx,dy);
   }
   _freesafe(tstr);
 
   // draw the focus
-  if ( ( hasFocus() == true ) && ( getAcceptFocus() == true ) ) {
-    aguix->setDottedFG( 1 );
-    aguix->DrawDottedRectangle( win, 1, 1, w - 2, h - 2 );
+  if ( ( getHasFocus() == true ) && ( getAcceptFocus() == true ) ) {
+    _aguix->setDottedFG( 1 );
+    _aguix->DrawDottedRectangle( win, 1, 1, _w - 2, _h - 2 );
   }
 
   /* now draw the button */
 
   if( showe == true ) {
-    aguix->setFG( usegc, 2 );
-    aguix->DrawTriangleFilled( win, usegc, px1, py1, px2, py2, px3, py3 );
-    aguix->setFG( usegc, 0 );
-    aguix->DrawTriangleFilled( win, usegc, px1, py1, w-1, 0, px3, py3 );
+    _aguix->setFG( usegc, 2 );
+    _aguix->DrawTriangleFilled( win, usegc, px1, py1, px2, py2, px3, py3 );
+    _aguix->setFG( usegc, 0 );
+    _aguix->DrawTriangleFilled( win, usegc, px1, py1, _w-1, 0, px3, py3 );
   }
 
   if( state == 0 )
-    aguix->setFG( usegc, 2 );
+    _aguix->setFG( usegc, 2 );
   else
-    aguix->setFG( usegc, 1 );
+    _aguix->setFG( usegc, 1 );
 
-  aguix->DrawLine( win, usegc, 0, h-1, 0, 0 );
+  _aguix->DrawLine( win, usegc, 0, _h-1, 0, 0 );
 
   if( showe == true ) {
-    aguix->DrawLine( win, usegc, 0, 0, px1, py1 );
-    aguix->setFG( usegc, 1 );
-    aguix->DrawLine( win, usegc, px1, py1, px2, py2 );
+    _aguix->DrawLine( win, usegc, 0, 0, px1, py1 );
+    _aguix->setFG( usegc, 1 );
+    _aguix->DrawLine( win, usegc, px1, py1, px2, py2 );
   } else
-    aguix->DrawLine( win, usegc, 0, 0, w-1, 0 );
+    _aguix->DrawLine( win, usegc, 0, 0, _w-1, 0 );
 
   if( state == 0 )
-    aguix->setFG( usegc, 1 );
+    _aguix->setFG( usegc, 1 );
   else
-    aguix->setFG( usegc, 2 );
+    _aguix->setFG( usegc, 2 );
 
-  aguix->DrawLine( win, usegc, 0, h-1, w-1, h-1 );
+  _aguix->DrawLine( win, usegc, 0, _h-1, _w-1, _h-1 );
 
   if( showe == true ) {
-    aguix->DrawLine( win, usegc, px3, py3, w-1, h-1 );
-    aguix->setFG( usegc, 1 );
-    aguix->DrawLine( win, usegc, px2, py2, px3, py3 );
-    aguix->DrawLine( win, usegc, px1, py1, px3, py3 );
+    _aguix->DrawLine( win, usegc, px3, py3, _w-1, _h-1 );
+    _aguix->setFG( usegc, 1 );
+    _aguix->DrawLine( win, usegc, px2, py2, px3, py3 );
+    _aguix->DrawLine( win, usegc, px1, py1, px3, py3 );
   } else
-    aguix->DrawLine(win,usegc,w-1,h-1,w-1,1);
+    _aguix->DrawLine(win,usegc,_w-1,_h-1,_w-1,1);
 
-  aguix->Flush();
+  _aguix->Flush();
 }
 
 void Button::flush()
@@ -373,7 +317,7 @@ void Button::setState(int tstate)
   } else {
     this->state=tstate;
   }
-  redraw();
+  redraw(); 
 }
 
 int Button::getState() const
@@ -383,8 +327,8 @@ int Button::getState() const
 
 bool Button::isInside(int px,int py) const
 {
-  if((px>0)&&(px<=w)) {
-    if((py>0)&&(py<=h)) return true;
+  if((px>0)&&(px<=_w)) {
+    if((py>0)&&(py<=_h)) return true;
   }
   return false;
 }
@@ -393,7 +337,7 @@ bool Button::handleMessage(XEvent *E,Message *msg)
 {
   bool returnvalue;
 
-  if ( parent == NULL ) return false;
+  if ( isCreated() == false ) return false;
 
   returnvalue=false;
   if((msg->type==ButtonPress)||(msg->type==ButtonRelease)) {
@@ -432,7 +376,7 @@ bool Button::handleMessage(XEvent *E,Message *msg)
 		setState( instate );
 		agmsg->button.state = instate;
 	      }
-	      aguix->putAGMsg(agmsg);
+	      _aguix->putAGMsg(agmsg);
 	      returnvalue=true;
 	    }
 	  }
@@ -442,12 +386,12 @@ bool Button::handleMessage(XEvent *E,Message *msg)
 	    agmsg->type=AG_BUTTONRELEASED;
 	    agmsg->button.button=this;
 	    agmsg->button.state=instate;
-	    aguix->putAGMsg(agmsg);
+	    _aguix->putAGMsg(agmsg);
 	    agmsg = AGUIX_allocAGMessage();
 	    agmsg->type=AG_BUTTONCLICKED;
 	    agmsg->button.button=this;
 	    agmsg->button.state=instate;
-	    aguix->putAGMsg(agmsg);
+	    _aguix->putAGMsg(agmsg);
 	  }
 	  if(instate!=0) {
 	    setState(0);
@@ -480,17 +424,17 @@ bool Button::handleMessage(XEvent *E,Message *msg)
       redraw();
     }
   } else if ( msg->type == KeyPress ) {
-    if ( ( getAcceptFocus() == true ) && ( hasFocus() == true ) ) {
+    if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
       if ( msg->key == XK_space ) {
 	if ( isVisible() == true ) {
-	  if ( parent->isTopParent( msg->window ) == true ) {
+	  if ( _parent->isTopParent( msg->window ) == true ) {
 	    AGMessage *agmsg;
 
 	    agmsg = AGUIX_allocAGMessage();
 	    agmsg->type=AG_BUTTONCLICKED;
 	    agmsg->button.button=this;
 	    agmsg->button.state=1;
-	    aguix->putAGMsg(agmsg);
+	    _aguix->putAGMsg(agmsg);
 	    if(instate!=0) {
 	      setState(0);
 	      instate=0;
@@ -525,7 +469,7 @@ void Button::setShowDual(bool new_val)
 
 int Button::setFont(char *fontname)
 {
-  font=aguix->getFont(fontname);
+  font=_aguix->getFont(fontname);
   if(font==NULL) return -1;
   return 0;
 }
@@ -577,3 +521,26 @@ void Button::setAllowWheel( bool nv )
 {
   allowWheel = nv;
 }
+
+void Button::init_class()
+{
+  dual = false;
+  data = 0;
+  state = 0;
+  instate = 0;
+  lastbg = -1;
+  showdual = true;
+  font = NULL;
+  active[0] = true;
+  active[1] = true;
+  fg[0] = 0;
+  fg[1] = 0;
+  bg[0] = 0;
+  bg[1] = 0;
+  text[0] = dupstring( "" );
+  text[1] = dupstring( "" );
+  allowWheel = false;
+  
+  setCanHandleFocus();
+  setAcceptFocus( true );
+}
