@@ -1,6 +1,6 @@
 /* button.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: button.h,v 1.10 2004/10/27 20:36:55 ralf Exp $ */
+/* $Id: button.h,v 1.11 2005/05/15 13:45:19 ralf Exp $ */
 
 #ifndef BUTTON_H
 #define BUTTON_H
@@ -31,7 +31,6 @@ class AGUIXFont;
 
 class Button:public GUIElement {
 public:
-  Button(AGUIX *aguix);
   Button(AGUIX *aguix,int x,int y,int width,
          const char *text,int fg,int bg,int data);
   Button(AGUIX *aguix,int x,int y,
@@ -90,6 +89,7 @@ private:
   bool allowWheel;
 
   static const char *type;
+  void init_class();
 };
 
 #endif
