@@ -1,6 +1,6 @@
 /* choosebutton.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: choosebutton.cc,v 1.22 2004/10/27 20:36:50 ralf Exp $ */
+/* $Id: choosebutton.cc,v 1.24 2005/05/21 12:16:23 ralf Exp $ */
 
 #include "choosebutton.h"
 #include "awindow.h"
@@ -28,35 +28,17 @@ const char *ChooseButton::type="ChooseButton";
 
 ChooseButton::~ChooseButton()
 {
-  if ( parent != NULL ) parent->remove( this );
+  destroy();
   if(label!=NULL) _freesafe(label);
 }
 
-ChooseButton::ChooseButton(AGUIX *taguix):GUIElement(taguix)
-{
-  this->data=0;
-  this->state=false;
-  this->instate=false;
-  this->label=(char*)_allocsafe(1);
-  this->label[0]=0;
-  this->labelcolor=0;
-  this->labelpos=LABEL_RIGHT;
-  bgset=false;
-  cross=false;
-  laststate=false;
-  font=NULL;
-  lwin = 0;
-  canHandleFocus = true;
-  setAcceptFocus( true );
-}
-
 ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,int width,int height,bool tstate,
                            const char *tlabel,int tlabelpos,int tlabelcolor,int tdata):GUIElement(taguix)
 {
-  this->x=tx;
-  this->y=ty;
-  if ( width > 0 ) this->w = width;
-  if ( height > 0 ) this->h = height;
+  _x=tx;
+  _y=ty;
+  if ( width > 0 ) _w = width;
+  if ( height > 0 ) _h = height;
   this->data=tdata;
   this->state=tstate;
   this->instate=tstate;
@@ -70,7 +52,7 @@ ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,int width,int height,bool
   calcRealPos(tx,ty);
   laststate=tstate;
   lwin = 0;
-  canHandleFocus = true;
+  setCanHandleFocus();
   setAcceptFocus( true );
 }
 
@@ -81,10 +63,10 @@ ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,bool tstate,
 
   th = taguix->getCharHeight() + 6;
 
-  this->x=tx;
-  this->y=ty;
-  this->w = th;
-  this->h = th;
+  _x=tx;
+  _y=ty;
+  _w = th;
+  _h = th;
   this->data=tdata;
   this->state=tstate;
   this->instate=tstate;
@@ -98,7 +80,7 @@ ChooseButton::ChooseButton(AGUIX *taguix,int tx,int ty,bool tstate,
   calcRealPos(tx,ty);
   laststate=tstate;
   lwin = 0;
-  canHandleFocus = true;
+  setCanHandleFocus();
   setAcceptFocus( true );
 }
 
@@ -117,7 +99,7 @@ void ChooseButton::setLabel(const char *new_text)
 
 void ChooseButton::setLabelColor(int color)
 {
-  if((color<(aguix->getMaxCols()))&&(color>=0)) {
+  if((color<(_aguix->getMaxCols()))&&(color>=0)) {
     this->labelcolor=color;
     lredraw();
   }
@@ -158,66 +140,66 @@ void ChooseButton::redraw()
 
 void ChooseButton::cbredraw()
 {
-  if(parent==NULL) return;
-  if(win==0) return;
+  if ( isCreated() == false ) return;
+  if ( win == 0 ) return;
   if(bgset==false) {
-    aguix->SetWindowBG(win,parent->getBG());
-    aguix->SetWindowBG(lwin,parent->getBG());
+    _aguix->SetWindowBG(win,_parent->getBG());
+    _aguix->SetWindowBG(lwin,_parent->getBG());
     bgset=true;
   }
-  aguix->ClearWin(win);
-  aguix->setFG(2);
-  aguix->DrawLine(win,0,h-1,0,0);
-  aguix->DrawLine(win,0,0,w-1,0);
-  aguix->setFG(1);
-  aguix->DrawLine(win,0,h-1,w-1,h-1);
-  aguix->DrawLine(win,w-1,h-1,w-1,1);
+  _aguix->ClearWin(win);
+  _aguix->setFG(2);
+  _aguix->DrawLine(win,0,_h-1,0,0);
+  _aguix->DrawLine(win,0,0,_w-1,0);
+  _aguix->setFG(1);
+  _aguix->DrawLine(win,0,_h-1,_w-1,_h-1);
+  _aguix->DrawLine(win,_w-1,_h-1,_w-1,1);
   int dx1,dy1;
   if(state==true) {
-    dy1=h/2;
-    dx1=w/4;
-    int dy2=h*3/4;
-    int dx2=w/2;
-    aguix->DrawLine(win,dx1,dy1,dx2,dy2);
-    dy1=h/4;
-    dx1=w*3/4;
-    aguix->DrawLine(win,dx2,dy2,dx1,dy1);
+    dy1=_h/2;
+    dx1=_w/4;
+    int dy2=_h*3/4;
+    int dx2=_w/2;
+    _aguix->DrawLine(win,dx1,dy1,dx2,dy2);
+    dy1=_h/4;
+    dx1=_w*3/4;
+    _aguix->DrawLine(win,dx2,dy2,dx1,dy1);
   }
 
-  if ( ( getAcceptFocus() == true ) && ( hasFocus() == true ) ) {
+  if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
     if ( strlen( label ) < 1 ) {
-      aguix->setDottedFG( 1 );
-      aguix->DrawDottedRectangle( win, 1, 1, w - 2, h - 2 );
+      _aguix->setDottedFG( 1 );
+      _aguix->DrawDottedRectangle( win, 1, 1, _w - 2, _h - 2 );
     }
   }
 
-  aguix->Flush();
+  _aguix->Flush();
 }
 
 void ChooseButton::lredraw()
 {
   GC usegc;
-  if(parent==NULL) return;
-  if(lwin==0) return;
+  if ( isCreated() == false ) return;
+  if ( lwin == 0 ) return;
   if(font==NULL) usegc=0; else usegc=font->getGC();
   if(bgset==false) {
-    aguix->SetWindowBG(lwin,parent->getBG());
-    aguix->SetWindowBG(win,parent->getBG());
+    _aguix->SetWindowBG(lwin,_parent->getBG());
+    _aguix->SetWindowBG(win,_parent->getBG());
     bgset=true;
   }
-  aguix->ClearWin(lwin);
-  aguix->setFG(usegc,labelcolor);
-  if(font==NULL) aguix->DrawText(lwin,label,0,0);
-  else aguix->DrawText(lwin,font,label,0,0);
+  _aguix->ClearWin(lwin);
+  _aguix->setFG(usegc,labelcolor);
+  if(font==NULL) _aguix->DrawText(lwin,label,0,0);
+  else _aguix->DrawText(lwin,font,label,0,0);
 
-  if ( ( getAcceptFocus() == true ) && ( hasFocus() == true ) ) {
+  if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
     if ( strlen( label ) > 0 ) {
-      aguix->setDottedFG( 1 );
-      aguix->DrawDottedRectangle( lwin, 0, 0, getLabelWidth(), getLabelHeight() );
+      _aguix->setDottedFG( 1 );
+      _aguix->DrawDottedRectangle( lwin, 0, 0, getLabelWidth(), getLabelHeight() );
     }
   }
 
-  aguix->Flush();
+  _aguix->Flush();
 }
 
 void ChooseButton::flush()
@@ -237,8 +219,8 @@ int ChooseButton::getState() const
 
 bool ChooseButton::isInside(int px,int py) const
 {
-  if((px>0)&&(px<=w)) {
-    if((py>0)&&(py<=h)) return true;
+  if((px>0)&&(px<=_w)) {
+    if((py>0)&&(py<=_h)) return true;
   }
   return false;
 }
@@ -247,49 +229,47 @@ bool ChooseButton::handleMessage(XEvent *E,Message *msg)
 {
   bool returnvalue;
 
-  if ( parent == NULL ) return false;
+  if ( isCreated() == false ) return false;
 
   returnvalue=false;
   if((msg->type==ButtonPress)||(msg->type==ButtonRelease)) {
-    if(msg->window==win) {
+    if ( msg->window == win || msg->window == lwin ) {
       takeFocus();
       if(msg->type==ButtonPress) {
-        if(msg->window==win) {
-          AGMessage *agmsg = AGUIX_allocAGMessage();
-          agmsg->type=AG_CHOOSEPRESSED;
-          agmsg->choose.button=this;
-          laststate=state;
-          if(state==false) {
-            setState(true);
-            instate=true;
-          } else {
-            setState(false);
-            instate=false;
-          }
-          cross=true;
-          agmsg->choose.state=state;
-          aguix->putAGMsg(agmsg);
-          returnvalue=true;
-        }
+	AGMessage *agmsg = AGUIX_allocAGMessage();
+	agmsg->type=AG_CHOOSEPRESSED;
+	agmsg->choose.button=this;
+	laststate=state;
+	if(state==false) {
+	  setState(true);
+	  instate=true;
+	} else {
+	  setState(false);
+	  instate=false;
+	}
+	cross=true;
+	agmsg->choose.state=state;
+	_aguix->putAGMsg(agmsg);
+	returnvalue=true;
       } else {
         if(state==instate) {
           AGMessage *agmsg = AGUIX_allocAGMessage();
           agmsg->type=AG_CHOOSERELEASED;
           agmsg->choose.button=this;
           agmsg->choose.state=state;
-          aguix->putAGMsg(agmsg);
+          _aguix->putAGMsg(agmsg);
           agmsg = AGUIX_allocAGMessage();
           agmsg->type=AG_CHOOSECLICKED;
           agmsg->choose.button=this;
           agmsg->choose.state=state;
-          aguix->putAGMsg(agmsg);
+          _aguix->putAGMsg(agmsg);
           laststate=state;
         }
         cross=false;
       }
     }
   } else if(msg->type==EnterNotify) {
-    if(msg->window==win) {
+    if ( msg->window == win || msg->window == lwin ) {
       if(cross==true) {
 	if(instate!=state) {
 	  setState(instate);
@@ -297,23 +277,23 @@ bool ChooseButton::handleMessage(XEvent *E,Message *msg)
       }
     }
   } else if(msg->type==LeaveNotify) {
-    if(msg->window==win) {
+    if ( msg->window == win || msg->window == lwin ) {
       if(cross==true) {
 	setState(laststate);
       }
     }
   } else if ( msg->type == KeyPress ) {
     if ( msg->key == XK_space ) {
-      if ( ( getAcceptFocus() == true ) && ( hasFocus() == true ) ) {
+      if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
 	if ( isVisible() == true ) {
-	  if ( parent->isTopParent( msg->window ) == true ) {
+	  if ( _parent->isTopParent( msg->window ) == true ) {
 	    setState( ( state == true ) ? false : true );
 	    AGMessage *agmsg;
 	    agmsg = AGUIX_allocAGMessage();
 	    agmsg->type=AG_CHOOSECLICKED;
 	    agmsg->choose.button=this;
 	    agmsg->choose.state=state;
-	    aguix->putAGMsg(agmsg);
+	    _aguix->putAGMsg(agmsg);
 	    laststate=state;
 	    cross=false;
 	  }
@@ -332,26 +312,26 @@ bool ChooseButton::handleMessage(XEvent *E,Message *msg)
 void ChooseButton::resize(int tw,int th)
 {
   if ( ( tw < 1 ) || ( th < 1 ) ) return;
-  this->w=tw;
-  this->h=th;
+  _w=tw;
+  _h=th;
   updateWin();
-  if(parent!=NULL) parent->resizeSubWin(win,tw,th);
+  if ( isCreated() == true ) _parent->resizeSubWin( win, tw, th );
 }
 
 void ChooseButton::move(int nx,int ny)
 {
-  x=nx;
-  y=ny;
-  calcRealPos(x,y);
+  _x=nx;
+  _y=ny;
+  calcRealPos(_x,_y);
   updateWin();
-  if(parent!=NULL) parent->moveSubWin(win,x,y);
+  if ( isCreated() == true ) _parent->moveSubWin( win, _x, _y );
 }
 
 int ChooseButton::getLabelWidth() const
 {
   if(label!=NULL) {
     int l;
-    if(font==NULL) l=strlen(label)*aguix->getCharWidth();
+    if(font==NULL) l=strlen(label)*_aguix->getCharWidth();
     else l=strlen(label)*font->getCharWidth();
     l += 2;
     return l;
@@ -360,7 +340,7 @@ int ChooseButton::getLabelWidth() const
 
 int ChooseButton::getLabelHeight() const
 {
-  if(font==NULL) return ( aguix->getCharHeight() + 2 );
+  if(font==NULL) return ( _aguix->getCharHeight() + 2 );
   else return ( font->getCharHeight() + 2 );
 }
 
@@ -371,23 +351,23 @@ void ChooseButton::calcLabelGeometry()
   lh=getLabelHeight();
   switch(labelpos) {
     case LABEL_LEFT:
-      lx=x-5-lw;
-      f1=y+h/2-lh/2;
+      lx=_x-5-lw;
+      f1=_y+_h/2-lh/2;
       ly=(int)f1;
       break;
     case LABEL_RIGHT:
-      lx=x+w+5;
-      f1=y+h/2-lh/2;
+      lx=_x+_w+5;
+      f1=_y+_h/2-lh/2;
       ly=(int)f1;
       break;
     case LABEL_TOP:
-      ly=y-5-lh;
-      f1=x+w/2-lw/2;
+      ly=_y-5-lh;
+      f1=_x+_w/2-lw/2;
       lx=(int)f1;
       break;
     case LABEL_BOTTOM:
-      ly=y+h+5;
-      f1=x+w/2-lw/2;
+      ly=_y+_h+5;
+      f1=_x+_w/2-lw/2;
       lx=(int)f1;
       break;
   }
@@ -397,15 +377,15 @@ void ChooseButton::calcLabelGeometry()
 void ChooseButton::updateWin()
 {
   calcLabelGeometry();
-  if(parent!=NULL) {
-    parent->moveSubWin(lwin,lx,ly);
-    parent->resizeSubWin(lwin,lw,lh);
+  if ( isCreated() == true ) {
+    _parent->moveSubWin(lwin,lx,ly);
+    _parent->resizeSubWin(lwin,lw,lh);
   }
 }
 
 int ChooseButton::setFont(char *fontname)
 {
-  font=aguix->getFont(fontname);
+  font=_aguix->getFont(fontname);
   if(font==NULL) return -1;
   updateWin();
   return 0;
@@ -424,7 +404,7 @@ bool ChooseButton::isType(const char *qtype) const
 
 bool ChooseButton::isParent(Window child) const
 {
-  if ( parent != NULL ) {
+  if ( isCreated() == true ) {
     if(child==win) return true;
     if(child==lwin) return true;
   }
@@ -433,28 +413,28 @@ bool ChooseButton::isParent(Window child) const
 
 int ChooseButton::getX() const
 {
-  return ((x<lx)?x:lx);
+  return ((_x<lx)?_x:lx);
 }
 
 int ChooseButton::getY() const
 {
-  return ((y<ly)?y:ly);
+  return ((_y<ly)?_y:ly);
 }
 
 int ChooseButton::getWidth() const
 {
   if((labelpos==LABEL_TOP)||(labelpos==LABEL_BOTTOM)) {
-    return ((w>lw)?w:lw);
+    return ((_w>lw)?_w:lw);
   }
-  return lw+w+5;
+  return lw+_w+5;
 }
 
 int ChooseButton::getHeight() const
 {
   if((labelpos==LABEL_LEFT)||(labelpos==LABEL_RIGHT)) {
-    return ((h>lh)?h:lh);
+    return ((_h>lh)?_h:lh);
   }
-  return lh+h+5;
+  return lh+_h+5;
 }
 
 void ChooseButton::calcRealPos(int tx,int ty)
@@ -462,62 +442,62 @@ void ChooseButton::calcRealPos(int tx,int ty)
   switch(labelpos) {
     case LABEL_TOP:
     case LABEL_BOTTOM:
-      if(lw<w) {
-        x=tx;
+      if(lw<_w) {
+        _x=tx;
       } else {
-        double b=tx+lw/2-w/2;
-        x=(int)b;
+        double b=tx+lw/2-_w/2;
+        _x=(int)b;
       }
       break;
     case LABEL_RIGHT:
-      x=tx;
+      _x=tx;
       break;
     default: // LABEL_LEFT
-      x=tx+5+lw;
+      _x=tx+5+lw;
   }
   switch(labelpos) {
     case LABEL_TOP:
-      y=ty+5+lh;
+      _y=ty+5+lh;
       break;
     case LABEL_BOTTOM:
-      y=ty;
+      _y=ty;
       break;
     default: // LABEL_LEFT & LABEL_RIGHT
-      if(lh<h) {
-        y=ty;
+      if(lh<_h) {
+        _y=ty;
       } else {
-        double b=ty+lh/2-h/2;
-        y=(int)b;
+        double b=ty+lh/2-_h/2;
+        _y=(int)b;
       }
   }
 }
 
 void ChooseButton::toBack()
 {
-  if ( parent == NULL ) return;
+  if ( isCreated() == false ) return;
   GUIElement::toBack();
-  aguix->WindowtoBack( lwin );
+  _aguix->WindowtoBack( lwin );
 }
 
 void ChooseButton::toFront()
 {
-  if ( parent == NULL ) return;
+  if ( isCreated() == false ) return;
   GUIElement::toFront();
-  aguix->WindowtoFront( lwin );
+  _aguix->WindowtoFront( lwin );
 }
 
 void ChooseButton::hide()
 {
-  if ( parent == NULL ) return;
+  if ( isCreated() == false ) return;
   GUIElement::hide();
-  parent->hide( lwin );
+  _parent->hide( lwin );
 }
 
 void ChooseButton::show()
 {
-  if ( parent == NULL ) return;
+  if ( isCreated() == false ) return;
   GUIElement::show();
-  parent->show( lwin );
+  _parent->show( lwin );
 }
 
 void ChooseButton::doCreateStuff()
@@ -525,14 +505,14 @@ void ChooseButton::doCreateStuff()
   GUIElement::doCreateStuff();
   calcLabelGeometry();
   if ( lwin == 0 ) {
-    lwin = parent->getSubWindow( 0, lx, ly, lw, lh );
+    lwin = _parent->getSubWindow( 0, lx, ly, lw, lh );
   }
 }
 
 void ChooseButton::doDestroyStuff()
 {
   if ( lwin != 0 ) {
-    parent->removeSubWin( lwin );
+    _parent->removeSubWin( lwin );
     lwin = 0;
   }
   GUIElement::doDestroyStuff();
