@@ -1,6 +1,6 @@
 /* cyclebutton.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: cyclebutton.cc,v 1.20 2004/10/27 20:37:27 ralf Exp $ */
+/* $Id: cyclebutton.cc,v 1.21 2005/05/15 13:45:33 ralf Exp $ */
 
 #include "cyclebutton.h"
 #include "awindow.h"
@@ -36,28 +36,13 @@ CycleButton::~CycleButton()
   delete options;
 }
 
-CycleButton::CycleButton(AGUIX *taguix):GUIElement(taguix)
-{
-  this->data=0;
-  this->state=0;
-  this->instate=0;
-  this->fg=1;
-  this->bg=0;
-  lastbg=-1;
-  font=NULL;
-  options=new List();
-  act_opt=-1;
-  canHandleFocus = true;
-  setAcceptFocus( true );
-}
-
 CycleButton::CycleButton(AGUIX *taguix,int tx,int ty,int width,
                          int tfg,int tbg,int tdata):GUIElement(taguix)
 {
-  this->x=tx;
-  this->y=ty;
-  if ( width > 0 ) this->w = width;
-  this->h=taguix->getCharHeight()+4;
+  _x=tx;
+  _y=ty;
+  if ( width > 0 ) _w = width;
+  _h=taguix->getCharHeight()+4;
   this->data=tdata;
   this->state=0;
   this->instate=0;
@@ -67,17 +52,17 @@ CycleButton::CycleButton(AGUIX *taguix,int tx,int ty,int width,
   font=NULL;
   options=new List();
   act_opt=-1;
-  canHandleFocus = true;
+  setCanHandleFocus();
   setAcceptFocus( true );
 }
 
 CycleButton::CycleButton(AGUIX *taguix,int tx,int ty,int width,int height,
                          int tfg,int tbg,int tdata):GUIElement(taguix)
 {
-  this->x=tx;
-  this->y=ty;
-  if ( width > 0 ) this->w = width;
-  if ( height > 0 ) this->h = height;
+  _x=tx;
+  _y=ty;
+  if ( width > 0 ) _w = width;
+  if ( height > 0 ) _h = height;
   this->data=tdata;
   this->state=0;
   this->instate=0;
@@ -87,7 +72,7 @@ CycleButton::CycleButton(AGUIX *taguix,int tx,int ty,int width,int height,
   font=NULL;
   options=new List();
   act_opt=-1;
-  canHandleFocus = true;
+  setCanHandleFocus();
   setAcceptFocus( true );
 }
 
@@ -133,7 +118,7 @@ void CycleButton::setOption(int index2)
 
 void CycleButton::setFG(int tfg)
 {
-  if((tfg<(aguix->getMaxCols()))&&(tfg>=0)) {
+  if((tfg<(_aguix->getMaxCols()))&&(tfg>=0)) {
     this->fg=tfg;
   }
   redraw();
@@ -146,7 +131,7 @@ int CycleButton::getFG() const
 
 void CycleButton::setBG(int tbg)
 {
-  if((tbg<(aguix->getMaxCols()))&&(tbg>=0)) {
+  if((tbg<(_aguix->getMaxCols()))&&(tbg>=0)) {
     this->bg=tbg;
   }
   redraw();
@@ -182,72 +167,72 @@ void CycleButton::redraw()
 			{6.0/8, 4.0/8, 7.0/8, 3.0/8}};
   GC usegc;
   double x1,x2,ty1,y2;
-  if(parent==NULL) return;
-  if(win==0) return;
+  if ( isCreated() == false ) return;
+  if ( win == 0 ) return;
   if(bg!=lastbg) {
-    aguix->SetWindowBG(win,bg);
+    _aguix->SetWindowBG(win,bg);
     lastbg=bg;
   }
-  aguix->ClearWin(win);
+  _aguix->ClearWin(win);
   if(font==NULL) usegc=0; else usegc=font->getGC();
   if(state==0) {
-    aguix->setFG(usegc,2);
+    _aguix->setFG(usegc,2);
   } else {
-    aguix->setFG(usegc,1);
+    _aguix->setFG(usegc,1);
   }
-  aguix->DrawLine(win,usegc,0,h-1,0,0);
-  aguix->DrawLine(win,usegc,0,0,w-1,0);
+  _aguix->DrawLine(win,usegc,0,_h-1,0,0);
+  _aguix->DrawLine(win,usegc,0,0,_w-1,0);
   if(state==0) {
-    aguix->setFG(usegc,1);
+    _aguix->setFG(usegc,1);
   } else {
-    aguix->setFG(usegc,2);
+    _aguix->setFG(usegc,2);
   }
-  aguix->DrawLine(win,usegc,0,h-1,w-1,h-1);
-  aguix->DrawLine(win,usegc,w-1,h-1,w-1,1);
+  _aguix->DrawLine(win,usegc,0,_h-1,_w-1,_h-1);
+  _aguix->DrawLine(win,usegc,_w-1,_h-1,_w-1,1);
 
-  aguix->setFG(usegc,1);
-  aguix->DrawLine(win,usegc,h-1,1,h-1,h-2);
+  _aguix->setFG(usegc,1);
+  _aguix->DrawLine(win,usegc,_h-1,1,_h-1,_h-2);
   for(int i=0;i<11;i++) {
     x1=circle[i][0];
     x2=circle[i][2];
     ty1=circle[i][1];
     y2=circle[i][3];
-    x1*=h-2;
-    x2*=h-2;
-    ty1*=h-2;
-    y2*=h-2;
-    aguix->DrawLine(win,usegc,(int)x1+1,(int)ty1+1,(int)x2+1,(int)y2+1);
+    x1*=_h-2;
+    x2*=_h-2;
+    ty1*=_h-2;
+    y2*=_h-2;
+    _aguix->DrawLine(win,usegc,(int)x1+1,(int)ty1+1,(int)x2+1,(int)y2+1);
   }
 
-  aguix->setFG(usegc,fg);
+  _aguix->setFG(usegc,fg);
   int ch,cw;
   if(font==NULL) {
-    ch=aguix->getCharHeight();
-    cw=aguix->getCharWidth();
+    ch=_aguix->getCharHeight();
+    cw=_aguix->getCharWidth();
   } else {
     ch=font->getCharHeight();
     cw=font->getCharWidth();
   }
-  int dy=h/2-ch/2;
-  unsigned int maxdisplay=(w-2)/cw;
+  int dy=_h/2-ch/2;
+  unsigned int maxdisplay=(_w-2)/cw;
   char *tstr;
   if(act_opt>=0) tstr=dupstring((char*)options->getElementAt(act_opt));
   else tstr=dupstring("");
   if(strlen(tstr)>maxdisplay) tstr[maxdisplay]=0;
-  int dx=h+5;
+  int dx=_h+5;
   if(font==NULL) {
-    aguix->DrawText(win,tstr,dx,dy);
+    _aguix->DrawText(win,tstr,dx,dy);
   } else {
-    aguix->DrawText(win,font,tstr,dx,dy);
+    _aguix->DrawText(win,font,tstr,dx,dy);
   }
   _freesafe(tstr);
 
-  if ( ( getAcceptFocus() == true ) && ( hasFocus() == true ) ) {
-    aguix->setDottedFG( 1 );
-    aguix->DrawDottedRectangle( win, h, 1, w - h - 1, h - 2 );
+  if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
+    _aguix->setDottedFG( 1 );
+    _aguix->DrawDottedRectangle( win, _h, 1, _w - _h - 1, _h - 2 );
   }
 
-  aguix->Flush();
+  _aguix->Flush();
 }
 
 void CycleButton::flush()
@@ -267,8 +252,8 @@ int CycleButton::getState() const
 
 bool CycleButton::isInside(int px,int py) const
 {
-  if((px>0)&&(px<=w)) {
-    if((py>0)&&(py<=h)) return true;
+  if((px>0)&&(px<=_w)) {
+    if((py>0)&&(py<=_h)) return true;
   }
   return false;
 }
@@ -277,7 +262,7 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
 {
   bool returnvalue;
   
-  if ( parent == NULL ) return false;
+  if ( isCreated() == false ) return false;
 
   returnvalue=false;
   AGMessage *agmsg;
@@ -315,7 +300,7 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
 	  agmsg->type=AG_CYCLEBUTTONCLICKED;
 	  agmsg->cyclebutton.cyclebutton=this;
 	  agmsg->cyclebutton.option=act_opt;
-	  aguix->putAGMsg(agmsg);
+	  _aguix->putAGMsg(agmsg);
 	}
 	if(instate!=0) {
 	  setState(0);
@@ -347,10 +332,10 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
       redraw();
     }
   } else if ( msg->type == KeyPress ) {
-    if ( ( getAcceptFocus() == true ) && ( hasFocus() == true ) ) {
+    if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
       if ( options->size() > 0 ) {
 	if ( isVisible() == true ) {
-	  if ( parent->isTopParent( msg->window ) == true ) {
+	  if ( _parent->isTopParent( msg->window ) == true ) {
 	    switch ( msg->key ) {
 	    case XK_space:
 	      if(options->size()>0) {
@@ -362,7 +347,7 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
 	      agmsg->type=AG_CYCLEBUTTONCLICKED;
 	      agmsg->cyclebutton.cyclebutton=this;
 	      agmsg->cyclebutton.option=act_opt;
-	      aguix->putAGMsg(agmsg);
+	      _aguix->putAGMsg(agmsg);
 	      if(instate!=0) {
 		setState(0);
 		instate=0;
@@ -376,7 +361,7 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
 		agmsg->type = AG_CYCLEBUTTONCLICKED;
 		agmsg->cyclebutton.cyclebutton = this;
 		agmsg->cyclebutton.option = act_opt;
-		aguix->putAGMsg( agmsg );
+		_aguix->putAGMsg( agmsg );
 		redraw();
 	      }
 	      break;
@@ -387,7 +372,7 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
 		agmsg->type = AG_CYCLEBUTTONCLICKED;
 		agmsg->cyclebutton.cyclebutton = this;
 		agmsg->cyclebutton.option = act_opt;
-		aguix->putAGMsg( agmsg );
+		_aguix->putAGMsg( agmsg );
 		redraw();
 	      }
 	      break;
@@ -409,7 +394,7 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
 
 int CycleButton::setFont(char *fontname)
 {
-  font=aguix->getFont(fontname);
+  font=_aguix->getFont(fontname);
   if(font==NULL) return -1;
   return 0;
 }
@@ -436,11 +421,11 @@ int CycleButton::getMaxSize() const
     tstr=(char*)options->getNextElement();
   }
   if(font==NULL) {
-    cw=aguix->getCharWidth();
+    cw=_aguix->getCharWidth();
   } else {
     cw=font->getCharWidth();
   }
-  return h+10+cw*maxlen;
+  return _h+10+cw*maxlen;
 }
 
 int
