@@ -1,6 +1,6 @@
 /* fieldlistviewdnd.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2004 Ralf Hoffmann.
+ * Copyright (C) 2002-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: fieldlistviewdnd.cc,v 1.17 2004/10/27 20:39:02 ralf Exp $ */
+/* $Id: fieldlistviewdnd.cc,v 1.19 2005/06/23 18:13:26 ralf Exp $ */
 
 #include "fieldlistviewdnd.h"
 #include "awindow.h"
@@ -58,7 +58,7 @@ void FieldListViewDND::handleSelect(Message *msg)
   int newelement;
   AGMessage *agmsg;
   
-  if ( parent == NULL ) return;
+  if ( isCreated() == false ) return;
 
   if ( dndMode != DND_IDLE ) {
     handleDND( msg );
@@ -71,7 +71,7 @@ void FieldListViewDND::handleSelect(Message *msg)
 	   ( selectMode == SELECT_HOLD ) ){
 	dndMode = DND_ACTIVE;
 
-	XQueryPointer( aguix->getDisplay(),
+	XQueryPointer( _aguix->getDisplay(),
 		       win,
 		       &root,
 		       &child,
@@ -99,7 +99,7 @@ void FieldListViewDND::handleSelect(Message *msg)
 	  if ( tstr == NULL ) tstr = dupstring( ( elementarray[ clickLastSelectedRow ]->getText( 0 ) ).c_str() );
 	  else tstr = dupstring( tstr );
 
-	  AGMessage *agmsg = AGUIX_allocAGMessage();
+	  agmsg = AGUIX_allocAGMessage();
 	  agmsg->dnd.element = this;
 	  agmsg->dnd.specialinfo.voidP = NULL;
 	  agmsg->dnd.specialinfo.value = clickLastSelectedRow;
@@ -114,9 +114,9 @@ void FieldListViewDND::handleSelect(Message *msg)
 	  agmsg->dnd.relx = win_x;
 	  agmsg->dnd.rely = win_y;
 	  agmsg->type = AG_DND_START;
-	  aguix->putAGMsg( agmsg );
+	  _aguix->putAGMsg( agmsg );
 
-	  dndtext = new DNDText( aguix,
+	  dndtext = new DNDText( _aguix,
 				 tstr,
 				 getFG( clickLastSelectedRow, ti ),
 				 getBG( clickLastSelectedRow, ti),
@@ -144,15 +144,15 @@ void FieldListViewDND::handleSelect(Message *msg)
     
     selectMode = SELECT_HOLD;
 
-    aguix->Flush();
-    aguix->msgLock( this );
+    _aguix->Flush();
+    _aguix->msgLock( this );
   } else if ( msg->type == MotionNotify ) {
     if ( ( msg->window == win ) &&
 	 ( ( selectMode == SELECT_HOLD ) ||
 	   ( selectMode == SELECT_SCROLL_DOWN ) ||
 	   ( selectMode == SELECT_SCROLL_UP ) ) ) {
-      //    aguix->queryPointer( win, &mx, &my );
-      XQueryPointer( aguix->getDisplay(),
+      //    _aguix->queryPointer( win, &mx, &my );
+      XQueryPointer( _aguix->getDisplay(),
 		     msg->window,
 		     &root,
 		     &child,
@@ -171,7 +171,7 @@ void FieldListViewDND::handleSelect(Message *msg)
 	      clickSelected += selectRowsRange( clickLastSelectedRow, newelement, clickState );
 	      clickLastSelectedRow = newelement;
 	      selectMode = SELECT_SCROLL_UP;
-	      aguix->enableTimer();
+	      _aguix->enableTimer();
 	    }
 	  }
 	} else if ( ( j >= maxdisplayv ) && ( ( yoffset + maxdisplayv ) < elements ) ) {
@@ -182,7 +182,7 @@ void FieldListViewDND::handleSelect(Message *msg)
 	      clickSelected += selectRowsRange( clickLastSelectedRow, newelement, clickState );
 	      clickLastSelectedRow = newelement;
 	      selectMode = SELECT_SCROLL_DOWN;
-	      aguix->enableTimer();
+	      _aguix->enableTimer();
 	    }
 	  }
 	} else {
@@ -197,7 +197,7 @@ void FieldListViewDND::handleSelect(Message *msg)
 	  }
 	  if ( selectMode != SELECT_HOLD ) {
 	    selectMode = SELECT_HOLD;
-	    aguix->disableTimer();
+	    _aguix->disableTimer();
 	  }
 	}
       }
@@ -207,12 +207,12 @@ void FieldListViewDND::handleSelect(Message *msg)
 	 ( msg->button == Button1 ) ) {
       switch ( selectMode ) {
 	case SELECT_IGNORE:
-	  aguix->msgUnlock( this );
+	  _aguix->msgUnlock( this );
 	  selectMode = SELECT_IDLE;
 	  break;
 	case SELECT_SCROLL_UP:
 	case SELECT_SCROLL_DOWN:
-	  aguix->disableTimer();
+	  _aguix->disableTimer();
 	case SELECT_HOLD:
 	  agmsg = AGUIX_allocAGMessage();
 	  agmsg->fieldlv.lv = this;
@@ -224,8 +224,8 @@ void FieldListViewDND::handleSelect(Message *msg)
 	  } else {
 	    agmsg->type = AG_FIELDLV_MULTISELECT;
 	  }
-	  aguix->putAGMsg( agmsg );
-	  aguix->msgUnlock( this );
+	  _aguix->putAGMsg( agmsg );
+	  _aguix->msgUnlock( this );
 	  selectMode = SELECT_IDLE;
 	  break;
 	default:
@@ -250,7 +250,7 @@ void FieldListViewDND::handleSelect(Message *msg)
 	    clickLastSelectedRow = newelement;
 	  }
 	}
-	aguix->Flush();
+	_aguix->Flush();
       }
     }
   }
@@ -262,7 +262,7 @@ void FieldListViewDND::handleDND( Message *msg )
   Window root, child, rroot;
   unsigned int keys_button;
   
-  if ( parent == NULL ) return;
+  if ( isCreated() == false ) return;
 
   if ( msg->type == ButtonPress ) {
     if ( ( dndMode == DND_ACTIVE ) &&
@@ -280,8 +280,8 @@ void FieldListViewDND::handleDND( Message *msg )
 	delete dndtext;
 	dndtext = NULL;
       }
-      Display *dsp=aguix->getDisplay();
-      root=RootWindow(dsp,aguix->getScreen());
+      Display *dsp=_aguix->getDisplay();
+      root=RootWindow(dsp,_aguix->getScreen());
       for(;;) {
       XQueryPointer(dsp,root,&rroot,&child,&xr,&yr,&xw,&yw,&keys_button);
 	if(child==0) break;
@@ -289,14 +289,14 @@ void FieldListViewDND::handleDND( Message *msg )
       }
       // Fenster finden, dass child enthaelt
       child=root;
-      AWindow *awin=aguix->findAWindow(child);
-      GUIElement *guiel=NULL;
+      AWindow *awin=_aguix->findAWindow(child);
+      Widget *widel = NULL;
       if(awin!=NULL) {
-	guiel=awin->findGUIElement(child);
-	if(guiel!=NULL) XQueryPointer(dsp,guiel->getWindow(),&root,&child,&xr,&yr,&xw,&yw,&keys_button);
+	widel = awin->findWidgetForWindow( child );
+	if(widel!=NULL) XQueryPointer(dsp,widel->getWindow(),&root,&child,&xr,&yr,&xw,&yw,&keys_button);
       }
       AGMessage *agmsg = AGUIX_allocAGMessage();
-      agmsg->dnd.element=guiel;
+      agmsg->dnd.element = widel;
       agmsg->dnd.window=awin;
       agmsg->dnd.specialinfo.voidP = NULL;
       agmsg->dnd.specialinfo.value = 0;
@@ -305,12 +305,12 @@ void FieldListViewDND::handleDND( Message *msg )
       agmsg->dnd.rely=yw;
       if ( dndMode == DND_ACTIVE ) agmsg->type=AG_DND_END;
       else agmsg->type=AG_DND_CANCEL;
-      aguix->putAGMsg(agmsg);
+      _aguix->putAGMsg(agmsg);
 
       switch ( selectMode ) {
 	case SELECT_SCROLL_UP:
 	case SELECT_SCROLL_DOWN:
-	  aguix->disableTimer();
+	  _aguix->disableTimer();
 	case SELECT_HOLD:
 	  setSelect( clickLastSelectedRow, false );
 	  runSelectHandler( clickLastSelectedRow );
@@ -324,12 +324,12 @@ void FieldListViewDND::handleDND( Message *msg )
 	  } else {
 	    agmsg->type = AG_FIELDLV_MULTISELECT;
 	  }
-	  aguix->putAGMsg( agmsg );
+	  _aguix->putAGMsg( agmsg );
 	  break;
 	default:
 	  break;
       }
-      aguix->msgUnlock( this );
+      _aguix->msgUnlock( this );
       selectMode = SELECT_IDLE;
       dndMode = DND_IDLE;
     }
