@@ -1,6 +1,6 @@
 /* kartei.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004 Ralf Hoffmann.
+ * Copyright (C) 2004-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,13 +18,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: kartei.cc,v 1.4 2004/12/16 19:11:25 ralf Exp $ */
+/* $Id: kartei.cc,v 1.9 2005/07/07 20:15:07 ralf Exp $ */
 
 #include "kartei.h"
 #include "acontainer.h"
 #include "karteibutton.h"
 
-Kartei::Kartei( AGUIX *parent ) : AWindow( parent )
+Kartei::Kartei( AGUIX *parent,
+		int x,
+		int y,
+		int width,
+		int height,
+		int bg,
+		std::string title  ) : AWindow( parent, x, y, width, height, bg, title )
 {
   cont = new AContainer( this, 1, 2 );
   cont->setMinSpace( 0 );
@@ -37,30 +43,22 @@ Kartei::Kartei( AGUIX *parent ) : AWindow( parent )
 
 Kartei::~Kartei()
 {
-  setContainer( NULL );
-  delete cont;
+  destroy();
 }
 
-int Kartei::create( AWindow *parent,
-		    int tx,
-		    int ty,
-		    int width,
-		    int height,
-		    int tbg,
-		    const char *ttitle )
+void Kartei::doCreateStuff()
 {
   const int cincw = AContainer::ACONT_MINH +
                     AContainer::ACONT_MINW +
                     AContainer::ACONT_MAXH;
-  int erg;
+  
+  AWindow::doCreateStuff();
+  if ( _created == false ) return;
 
-  erg = AWindow::create( parent, tx, ty, width, height, tbg, ttitle );
-  if ( erg != 0 ) return erg;
-
-  optionkb = new KarteiButton( aguix, 0, 0, 100, 1, 0, 0 );
+  optionkb = new KarteiButton( _aguix, 0, 0, 100, 1, 0, 0 );
   cont->add( optionkb, 0, 0, cincw );
   optionkb->setOptionChangeCallback( optionChangeCallback, this );
-  return 0;
+  return;
 }
 
 void Kartei::setOption( AWindow *twin, unsigned int option, const char *optionname )
@@ -83,20 +81,30 @@ void Kartei::showCurOption()
 {
   AWindow *twin, *otwin;
   unsigned int i;
+  bool find_new_focus = false;
 
   if ( curOption >= options.size() ) return;
   twin = options[curOption];
-  if ( subawins->getIndex( twin ) < 0 ) return;
+  if ( std::find( getChilds().begin(), getChilds().end(), twin ) == getChilds().end() ) return;
   
   for ( i = 0; i < options.size(); i++ ) {
     if ( i == curOption ) continue;
     otwin = options[i];
-    if ( subawins->getIndex( otwin ) < 0 ) continue;
+    if ( std::find( getChilds().begin(), getChilds().end(), twin ) == getChilds().end() ) continue;
+    if ( otwin->contains( getFocusOwner() ) == true )
+      find_new_focus = true;
     otwin->hide();
   }
   twin->show();
   cont->add( twin, 0, 1 );
   cont->rearrange();
+
+  if ( find_new_focus == true ) {
+    // find new focus element as the old one is now hidden
+    Widget *w = twin->searchNextFocus( NULL );
+    if ( w != NULL )
+      applyFocus( w );
+  }
 }
 
 void Kartei::maximize()
@@ -107,7 +115,7 @@ void Kartei::maximize()
 
   for ( i = 0; i < options.size(); i++ ) {
     twin = options[i];
-    if ( subawins->getIndex( twin ) < 0 ) continue;
+    if ( std::find( getChilds().begin(), getChilds().end(), twin ) == getChilds().end() ) continue;
     twin->contMaximize();
     if ( twin->getWidth() > tw ) tw = twin->getWidth();
     if ( twin->getHeight() > th ) th = twin->getHeight();
@@ -124,9 +132,13 @@ void Kartei::optionChangeCallback( Kartei *k1, unsigned int option )
 
 void Kartei::optionChange( unsigned int option )
 {
+  unsigned int old_option = curOption;
+
   if ( curOption != option ) {
     curOption = option;
     if ( curOption >= options.size() ) curOption = 0;
+    if ( old_option != curOption )
+      optionkb->setOption( curOption);
     showCurOption();
     boxRedraw();
   }
@@ -138,11 +150,11 @@ void Kartei::boxRedraw()
 
   if ( optionkb != NULL ) ty = optionkb->getY() + optionkb->getHeight();
   else ty = 0;
-  aguix->setFG( 0, 2 );
-  aguix->DrawLine( win, 0, 0, ty, 0, h - 1 );
-  aguix->setFG( 0, 1 );
-  aguix->DrawLine( win, 0, 0, h - 1, w - 1, h - 1 );
-  aguix->DrawLine( win, 0, w - 1, h - 1, w - 1, ty - 1 );
+  _aguix->setFG( 0, 2 );
+  _aguix->DrawLine( win, 0, 0, ty, 0, _h - 1 );
+  _aguix->setFG( 0, 1 );
+  _aguix->DrawLine( win, 0, 0, _h - 1, _w - 1, _h - 1 );
+  _aguix->DrawLine( win, 0, _w - 1, _h - 1, _w - 1, ty - 1 );
 }
 
 bool Kartei::handleMessage(XEvent *E,Message *msg)
@@ -155,10 +167,14 @@ bool Kartei::handleMessage(XEvent *E,Message *msg)
   return AWindow::handleMessage( E, msg );
 }
 
-void Kartei::close()
+void Kartei::doDestroyStuff()
 {
-  AWindow::close();
+  AWindow::doDestroyStuff();
   optionkb = NULL;
-  options.clear();
   curOption = 0;
 }
+
+int Kartei::getCurOption() const
+{
+  return curOption;
+}
