@@ -1,6 +1,6 @@
 /* karteicyclebutton.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004 Ralf Hoffmann.
+ * Copyright (C) 2004-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: karteibutton.cc,v 1.2 2004/10/27 20:41:07 ralf Exp $ */
+/* $Id: karteibutton.cc,v 1.4 2005/07/07 19:41:28 ralf Exp $ */
 
 #include "karteibutton.h"
 #include "awindow.h"
@@ -31,13 +31,6 @@ KarteiButton::~KarteiButton()
 {
 }
 
-KarteiButton::KarteiButton( AGUIX *taguix ) : CycleButton( taguix )
-{
-  optionChangeCallback = NULL;
-  k2 = NULL;
-  focusPos = 0;
-}
-
 KarteiButton::KarteiButton( AGUIX *taguix,
 			    int tx,
 			    int ty,
@@ -86,23 +79,23 @@ void KarteiButton::redraw()
   int basex, basey, midy, delx, i, dx, dx2, sx, sy, ex, ey;
   int act_x1 = -1, act_x2 = -1;
 
-  if ( parent == NULL ) return;
+  if ( isCreated() == false ) return;
   if ( win == 0 ) return;
   if ( bg != lastbg ) {
-    aguix->SetWindowBG( win, bg );
+    _aguix->SetWindowBG( win, bg );
     lastbg = bg;
   }
-  aguix->ClearWin( win );
+  _aguix->ClearWin( win );
   if ( font == NULL ) usegc = 0; else usegc = font->getGC();
 
   basex = 0;
-  basey = h - 1;
-  midy = h / 2 - 1;
-  delx = h / 4;
+  basey = _h - 1;
+  midy = _h / 2 - 1;
+  delx = _h / 4;
 
   if ( font == NULL ) {
-    ch = aguix->getCharHeight();
-    cw = aguix->getCharWidth();
+    ch = _aguix->getCharHeight();
+    cw = _aguix->getCharWidth();
   } else {
     ch = font->getCharHeight();
     cw = font->getCharWidth();
@@ -122,15 +115,15 @@ void KarteiButton::redraw()
     } else {
       sy = midy;
     }
-    aguix->setFG( usegc, 2 );
-    aguix->DrawLine( win, usegc,
+    _aguix->setFG( usegc, 2 );
+    _aguix->DrawLine( win, usegc,
 		     sx, sy,
 		     sx + dx, 0 );
     tstr = dupstring((char*)options->getElementAt( i ) );
 
     dx2 = strlen( tstr ) * cw;
     dx2 += 2 * delx;
-    aguix->DrawLine( win, usegc,
+    _aguix->DrawLine( win, usegc,
 		     sx + dx, 0,
 		     sx + dx + dx2, 0 );
     if ( ( i + 1 ) == act_opt ) {
@@ -140,8 +133,8 @@ void KarteiButton::redraw()
       ex = sx + dx + dx2 + 2 * delx;
       ey = basey;
     }
-    aguix->setFG( usegc, 1 );
-    aguix->DrawLine( win, usegc,
+    _aguix->setFG( usegc, 1 );
+    _aguix->DrawLine( win, usegc,
 		     sx + dx + dx2, 0,
 		     ex, ey );
     
@@ -151,28 +144,28 @@ void KarteiButton::redraw()
     }
 
     if ( font == NULL ) {
-      aguix->DrawText( win, tstr, sx + dx + delx, 2 );
+      _aguix->DrawText( win, tstr, sx + dx + delx, 2 );
     } else {
-      aguix->DrawText( win, font, tstr, sx + dx + delx, 1 );
+      _aguix->DrawText( win, font, tstr, sx + dx + delx, 1 );
     }
     _freesafe( tstr );
 
     if ( ( getAcceptFocus() == true ) &&
-	 ( hasFocus() == true ) &&
+	 ( getHasFocus() == true ) &&
 	 ( focusPos == i ) ) {
-      aguix->setDottedFG( 1 );
-      aguix->DrawDottedRectangle( win, sx + dx + delx - 2, 1, dx2 - 2 * delx + 4, 1 + ch + 1 );
+      _aguix->setDottedFG( 1 );
+      _aguix->DrawDottedRectangle( win, sx + dx + delx - 2, 1, dx2 - 2 * delx + 4, 1 + ch + 1 );
     }
 
     basex = sx + dx + dx2;
   }
   if ( ( act_x1 >= 0 ) && ( act_x2 > act_x1 ) ) {
-    aguix->setFG( usegc, 2 );
-    aguix->DrawLine( win, usegc, 0, basey, act_x1, basey );
-    aguix->DrawLine( win, usegc, act_x2 + 1, basey, w, basey );
+    _aguix->setFG( usegc, 2 );
+    _aguix->DrawLine( win, usegc, 0, basey, act_x1, basey );
+    _aguix->DrawLine( win, usegc, act_x2 + 1, basey, _w, basey );
   }
 
-  aguix->Flush();
+  _aguix->Flush();
 }
 
 void KarteiButton::flush()
@@ -184,7 +177,7 @@ bool KarteiButton::handleMessage(XEvent *E,Message *msg)
   bool returnvalue;
   AGMessage *agmsg;
   
-  if ( parent == NULL ) return false;
+  if ( isCreated() == false ) return false;
 
   returnvalue = false;
 
@@ -221,7 +214,7 @@ bool KarteiButton::handleMessage(XEvent *E,Message *msg)
 	  agmsg->type=AG_KARTEIBUTTONCLICKED;
 	  agmsg->karteibutton.karteibutton=this;
 	  agmsg->karteibutton.option=act_opt;
-	  aguix->putAGMsg(agmsg);
+	  _aguix->putAGMsg(agmsg);
 
 	  if ( ( optionChangeCallback != NULL ) && ( act_opt >= 0 ) ) {
 	    optionChangeCallback( k2, (unsigned int)act_opt );
@@ -257,10 +250,10 @@ bool KarteiButton::handleMessage(XEvent *E,Message *msg)
       redraw();
     }
   } else if ( msg->type == KeyPress ) {
-    if ( ( getAcceptFocus() == true ) && ( hasFocus() == true ) ) {
+    if ( ( getAcceptFocus() == true ) && ( getHasFocus() == true ) ) {
       if ( options->size() > 0 ) {
 	if ( isVisible() == true ) {
-	  if ( parent->isTopParent( msg->window ) == true ) {
+	  if ( _parent->isTopParent( msg->window ) == true ) {
 	    switch ( msg->key ) {
 	    case XK_space:
 	      if ( act_opt != focusPos ) {
@@ -271,7 +264,7 @@ bool KarteiButton::handleMessage(XEvent *E,Message *msg)
 		agmsg->type=AG_KARTEIBUTTONCLICKED;
 		agmsg->karteibutton.karteibutton=this;
 		agmsg->karteibutton.option=act_opt;
-		aguix->putAGMsg(agmsg);
+		_aguix->putAGMsg(agmsg);
 
                 if ( ( optionChangeCallback != NULL ) && ( act_opt >= 0 ) ) {
                   optionChangeCallback( k2, (unsigned int)act_opt );
@@ -328,11 +321,11 @@ int KarteiButton::getMaxSize() const
   int cw;
   int delx, i, dx2, tw;
 
-  delx = h / 4;
+  delx = _h / 4;
   tw = 2 * delx;
   
   if ( font == NULL ) {
-    cw = aguix->getCharWidth();
+    cw = _aguix->getCharWidth();
   } else {
     cw = font->getCharWidth();
   }
@@ -361,11 +354,11 @@ int KarteiButton::findClickedOption( int mx )
   int delx, i, dx2, tw, basex;
   int opt = -1;
 
-  delx = h / 4;
+  delx = _h / 4;
   basex = 0;
 
   if ( font == NULL ) {
-    cw = aguix->getCharWidth();
+    cw = _aguix->getCharWidth();
   } else {
     cw = font->getCharWidth();
   }
@@ -389,3 +382,20 @@ int KarteiButton::findClickedOption( int mx )
   }
   return opt;
 }
+
+void KarteiButton::setOption( int nv )
+{
+  int old_opt = act_opt;
+  
+  if ( ( nv >= 0 ) && ( options->size() > 0 ) ) {
+    act_opt = nv;
+    if ( act_opt >= options->size() ) act_opt = 0;
+
+    if ( old_opt != act_opt ) {
+      if ( ( optionChangeCallback != NULL ) && ( act_opt >= 0 ) ) {
+	optionChangeCallback( k2, (unsigned int)act_opt );
+      }
+      redraw();
+    }
+  }
+}
