@@ -1,6 +1,6 @@
 /* lowlevelfunc.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: lowlevelfunc.cc,v 1.31 2004/10/27 20:40:57 ralf Exp $ */
+/* $Id: lowlevelfunc.cc,v 1.32 2005/06/27 17:41:59 ralf Exp $ */
 
 #include "lowlevelfunc.h"
 #include <locale.h>
@@ -182,40 +182,13 @@ char *dupstring(const char *str)
   return tstr;
 }
 
-int WriteLong2Str(char *buffer,loff_t size)
+int MakeLong2NiceStr( loff_t size, std::string &buffer, bool do_nice )
 {
-  int i=0,digit,j;
-  loff_t x=size;
-  do {
-    digit = abs( (int)( x % 10 ) );
-    x/=10;
-    buffer[i++]='0'+digit;
-  } while(x!=0);
-  if(size<0) buffer[i++]='-';
-  // now reverse the buffer for human readable
-  for(j=0;j<(i/2);j++) {
-    digit=buffer[i-1-j];
-    buffer[i-1-j]=buffer[j];
-    buffer[j]=digit;
-  }
-  return i;
-}
-
-const char *GetLong2Str( loff_t size )
-{
-  static char nrbuf[ A_BYTESFORNUMBER( size ) ];
-
-  nrbuf[ WriteLong2Str( nrbuf, size ) ] = '\0';
-  return nrbuf;
-}
-
-int MakeLong2NiceStr(char *buffer,loff_t size)
-{
-  int s = NiceLongSize( size );
-  char ch;
-  int l,i,pos;
   static char own_thousands_sep = '\0';
   struct lconv *current_locale;
+  std::string numstr;
+  loff_t tmpval = size;
+  int digit, i;
 
   if ( own_thousands_sep == '\0' ) {
     // thousands separator isn't set so try to determine it
@@ -231,53 +204,24 @@ int MakeLong2NiceStr(char *buffer,loff_t size)
     }
   }
 
-  // first write the normal str into buf
-  l=WriteLong2Str(buffer,size);
-  // start at the right of needed room (the lowest number)
-  pos=s-1;
-  // for all chars in the normal str
-  for(i=0;i<l;i++) {
-    // save the char
-    ch=buffer[l-1-i];
-    // when taking over the thousand/million/billion number write the
-    // own_thousands_sep (depending on the current locale) into the dest
-    // this will NOT overwrite any important information because
-    // 1.we saved the ch we will write
-    // 2.at the end we will be at pos 0 (pos starts at s-1)
-    //   and if we have all points written, we will take over the ch
-    if ( ( ( i == 3 ) || ( i == 6 ) || ( i == 9 ) ) &&
-	 ( isdigit( ch ) ) ) buffer[pos--] = own_thousands_sep;
-    buffer[pos--]=ch;
-  }
-  return s;
-}
+  numstr = "";
+  i = 0;
+  do {
+    digit = abs( (int)( tmpval % 10 ) );
+    tmpval /= 10;
 
-int NiceLongSize(loff_t value)
-{
-  int size;
-  loff_t x;
-  x=value;
-  size=1;
-  
-  if(value<0) {
-    size++;
-    if(x<-999) size++;
-    if(x<-999999) size++;
-    if(x<-999999999) size++;
-    while(x<-9) {
-      size++;
-      x=x/10;
-    }
-  } else {
-    if(x>999) size++;
-    if(x>999999) size++;
-    if(x>999999999) size++;
-    while(x>9) {
-      size++;
-      x=x/10;
-    }
-  }
-  return size;
+    if ( ( do_nice == true ) && ( i != 0 ) && ( i % 3 == 0 ) )
+      numstr += own_thousands_sep;
+
+    numstr += '0' + digit;
+    i++;
+  } while ( tmpval != 0 );
+  if ( size < 0 ) numstr += '-';
+
+  std::reverse( numstr.begin(), numstr.end() );
+  buffer = numstr;
+
+  return numstr.length();
 }
 
 char *catstring(const char *str1,const char *str2)
