@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: request.cc,v 1.34 2005/03/24 07:11:40 ralf Exp $ */
+/* $Id: request.cc,v 1.35 2005/05/15 13:46:53 ralf Exp $ */
 
 #include "request.h"
 #include "aguix.h"
@@ -31,6 +31,7 @@
 #include "acontainer.h"
 #include "acontainerbb.h"
 #include "choosebutton.h"
+#include "textview.h"
 
 #define ACCEPT_ENTER_FOR_CHOOSE 1
 
@@ -69,8 +70,8 @@ int Requester::request(const char *title,const char *text,const char *buttons, A
 
   nbuttons=createLines(buttons,&buttonss);
   w = h = 10;
-  AWindow *win=new AWindow(aguix);
-  win->create(NULL,10,10,w,h,0,title);
+  AWindow *win=new AWindow(aguix,10,10,w,h,0, title );
+  win->create();
   if ( twin != NULL ) {
     win->setTransientForAWindow( twin );
   } else if ( transientawin != NULL ) {
@@ -147,7 +148,7 @@ int Requester::request(const char *title,const char *text,const char *buttons, A
 	      case XK_Return:
 #ifdef ACCEPT_ENTER_FOR_CHOOSE
 		for ( i = 0; i < nbuttons; i++ ) {
-		  if ( buts[i]->hasFocus() == true ) {
+		  if ( buts[i]->getHasFocus() == true ) {
 		    endmode = i;
 		    break;
 		  }
@@ -221,7 +222,6 @@ int Requester::request(const char *title,const char *text,const char *buttons, A
       aguix->ReplyMessage(msg);
     }
   }
-  win->close();
   delete win;
   for(i=0;i<nbuttons;i++) _freesafe(buttonss[i]);
   _freesafe(buttonss);
@@ -249,8 +249,8 @@ int Requester::string_request( const char *title, const char *text, const char *
   
   nbuttons=createLines(buttons,&buttonss);
   w = h = 10;
-  AWindow *win=new AWindow(aguix);
-  win->create(NULL,10,10,w,h,0,title);
+  AWindow *win=new AWindow(aguix,10,10,w,h,0,title);
+  win->create();
   if ( twin != NULL ) {
     win->setTransientForAWindow( twin );
   } else if ( transientawin != NULL ) {
@@ -352,7 +352,7 @@ int Requester::string_request( const char *title, const char *text, const char *
 	      case XK_Return:
 #ifdef ACCEPT_ENTER_FOR_CHOOSE
 		for ( i = 0; i < nbuttons; i++ ) {
-		  if ( buts[i]->hasFocus() == true ) {
+		  if ( buts[i]->getHasFocus() == true ) {
 		    endmode = i;
 		    break;
 		  }
@@ -431,7 +431,6 @@ int Requester::string_request( const char *title, const char *text, const char *
   if ( return_str != NULL ) {
     *return_str = dupstring( sg->getText() );
   }
-  win->close();
   delete win;
   for(i=0;i<nbuttons;i++) _freesafe(buttonss[i]);
   _freesafe(buttonss);
@@ -479,8 +478,8 @@ int Requester::request_choose( const char *title,
   char **liness;
 
   nbuttons = createLines( buttons, &buttonss );
-  AWindow *win = new AWindow( aguix );
-  win->create( NULL, 10, 10, 10, 10, 0, title );
+  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, title );
+  win->create();
   if ( twin != NULL ) {
     win->setTransientForAWindow( twin );
   } else if ( transientawin != NULL ) {
@@ -569,7 +568,7 @@ int Requester::request_choose( const char *title,
 	      case XK_Return:
 #ifdef ACCEPT_ENTER_FOR_CHOOSE
 		for ( i = 0; i < nbuttons; i++ ) {
-		  if ( buts[i]->hasFocus() == true ) {
+		  if ( buts[i]->getHasFocus() == true ) {
 		    endmode = i;
 		    break;
 		  }
@@ -640,7 +639,195 @@ int Requester::request_choose( const char *title,
 
   choose_var = ( cb1->getState() == 0 ) ? false : true;
 
-  win->close();
+  delete win;
+  for ( i = 0; i < nbuttons; i++ ) _freesafe( buttonss[i] );
+  _freesafe( buttonss );
+  _freesafe( buts );
+  return endmode;
+}
+
+
+int Requester::request( const char *title, TextStorage &ts, const char *buttons )
+{
+  return request( title, ts, buttons, REQUEST_NONE );
+}
+
+int Requester::request( const char *title, TextStorage &ts, const char *buttons, request_flags_t flags )
+{
+  return request( title, ts, buttons, NULL, flags );
+}
+
+int Requester::request( const char *title, TextStorage &ts, const char *buttons, AWindow *twin, request_flags_t flags )
+{
+  int i;
+  Button **buts;
+  int nbuttons;
+  char **buttonss;
+  const int cmin = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
+
+  nbuttons = createLines( buttons, &buttonss );
+  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, title );
+  win->create();
+  if ( twin != NULL ) {
+    win->setTransientForAWindow( twin );
+  } else if ( transientawin != NULL ) {
+    win->setTransientForAWindow( transientawin );
+  } else {
+    if ( aguix->getTransientWindow() != NULL ) {
+      win->setTransientForAWindow( aguix->getTransientWindow() );
+    }
+  }
+
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
+
+  TextView *tv = new TextView( aguix, 0, 0, 100, 100, 0, "", ts );
+  tv->setDisplayFocus( true );
+  ac1->add( tv, 0, 0, cmin );
+  tv->create();
+  tv->show();
+  tv->maximizeX();
+  tv->maximizeYLines( 15 );
+  ac1->readLimits();
+
+  if ( nbuttons == 1 ) {
+    AContainer *ac1_3 = ac1->add( new AContainer( win, 3, 1 ), 0, 1 );
+    ac1_3->setMinSpace( 0 );
+    ac1_3->setMaxSpace( -1 );
+    ac1_3->setBorderWidth( 0 );
+    
+    buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
+    buts[0] = (Button*)ac1_3->add( new Button( aguix, 0, 0, buttonss[0], 1, 0, 0 ),
+				   1, 0, cfix );
+  } else {
+    AContainer *ac1_3 = ac1->add( new AContainer( win, nbuttons, 1 ), 0, 1 );
+    ac1_3->setMinSpace( 5 );
+    ac1_3->setMaxSpace( -1 );
+    ac1_3->setBorderWidth( 0 );
+    
+    buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
+    for ( i = 0; i < nbuttons; i++ ) {
+      buts[i] = (Button*)ac1_3->add( new Button( aguix, 0, 0, buttonss[i], 1, 0, i ),
+				     i, 0, cfix );
+    }
+  }
+  for ( i = 0; i < nbuttons; i++ ) {
+    buts[i]->setAcceptFocus( true );
+  }
+  buts[0]->takeFocus();
+
+  win->setDoTabCycling( true );
+  win->contMaximize( true );
+
+  win->useStippleBackground();
+  win->centerScreen();
+  win->show();
+
+  AGMessage *msg;
+  int endmode = -1;
+  for( ; endmode == -1; ) {
+    msg = aguix->WaitMessage( win );
+    if ( msg != NULL ) {
+      switch ( msg->type ) {
+        case AG_CLOSEWINDOW:
+          if ( msg->closewindow.window == win->getWindow() ) {
+	    if ( ( flags & REQUEST_CANCELWITHLEFT ) != 0 ) {
+	      endmode = 0;
+	    } else {
+	      endmode = nbuttons - 1;
+	    }
+	  }
+          break;
+        case AG_BUTTONCLICKED:
+	  for ( i = 0; i < nbuttons; i++ ) {
+	    if ( msg->button.button == buts[i] ) {
+	      endmode = i;
+	      break;
+	    }
+	  }
+          break;
+	case AG_KEYPRESSED:
+	  if ( win->isParent( msg->key.window, false ) == true ) {
+	    switch(msg->key.key) {
+	      case XK_KP_Enter:
+	      case XK_Return:
+#ifdef ACCEPT_ENTER_FOR_CHOOSE
+		for ( i = 0; i < nbuttons; i++ ) {
+		  if ( buts[i]->getHasFocus() == true ) {
+		    endmode = i;
+		    break;
+		  }
+		}
+#else
+		if ( buts[0]->hasFocus() == true ) endmode = 0;
+#endif
+		break;
+	      case XK_Escape:
+		if ( ( flags & REQUEST_CANCELWITHLEFT ) != 0 ) {
+		  endmode = 0;
+		} else {
+		  endmode = nbuttons - 1;
+		}
+		break;
+	      case XK_F1:
+	        endmode = 0;
+	        break;
+	      case XK_F2:
+	        endmode = 1;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F3:
+	        endmode = 2;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F4:
+	        endmode = 3;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F5:
+	        endmode = 4;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F6:
+	        endmode = 5;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F7:
+	        endmode = 6;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F8:
+	        endmode = 7;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F9:
+	        endmode = 8;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_F10:
+	        endmode = 9;
+		if ( endmode >= nbuttons ) endmode = -1;
+	        break;
+	      case XK_Left:
+		win->prevFocus();
+		break;
+  	      case XK_Right:
+		win->nextFocus();
+		break;
+	    }
+	  }
+	  break;
+      }
+      aguix->ReplyMessage( msg );
+    }
+  }
+
   delete win;
   for ( i = 0; i < nbuttons; i++ ) _freesafe( buttonss[i] );
   _freesafe( buttonss );
