@@ -1,6 +1,6 @@
 /* solidbutton.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: solidbutton.cc,v 1.10 2004/10/27 20:42:32 ralf Exp $ */
+/* $Id: solidbutton.cc,v 1.11 2005/05/15 13:47:29 ralf Exp $ */
 
 #include "solidbutton.h"
 #include "lowlevelfunc.h"
@@ -31,24 +31,13 @@ SolidButton::~SolidButton()
   if(text!=NULL) _freesafe(text);
 }
 
-SolidButton::SolidButton(AGUIX *taguix):GUIElement(taguix)
-{
-  this->state=false;
-  this->text=(char*)_allocsafe(1);
-  this->text[0]=0;
-  this->fg=0;
-  this->bg=0;
-  lastbg=-1;
-  font=NULL;
-}
-
 SolidButton::SolidButton(AGUIX *taguix,int tx,int ty,int width,
                          const char *ttext,int tfg,int tbg,bool tstate):GUIElement(taguix)
 {
-  this->x=tx;
-  this->y=ty;
-  if ( width > 0 ) this->w = width;
-  this->h=taguix->getCharHeight()+4;
+  _x=tx;
+  _y=ty;
+  if ( width > 0 ) _w = width;
+  _h=taguix->getCharHeight()+4;
   this->state=tstate;
   this->text=dupstring(ttext);
   this->fg=tfg;
@@ -60,10 +49,10 @@ SolidButton::SolidButton(AGUIX *taguix,int tx,int ty,int width,
 SolidButton::SolidButton(AGUIX *taguix,int tx,int ty,int width,int height,
                          const char *ttext,int tfg,int tbg,bool tstate):GUIElement(taguix)
 {
-  this->x=tx;
-  this->y=ty;
-  if ( width > 0 ) this->w = width;
-  if ( height > 0 ) this->h = height;
+  _x=tx;
+  _y=ty;
+  if ( width > 0 ) _w = width;
+  if ( height > 0 ) _h = height;
   this->state=tstate;
   this->text=dupstring(ttext);
   this->fg=tfg;
@@ -86,7 +75,7 @@ void SolidButton::setText(const char *new_text)
 
 void SolidButton::setFG(int tfg)
 {
-  if((tfg<(aguix->getMaxCols()))&&(tfg>=0)) {
+  if((tfg<(_aguix->getMaxCols()))&&(tfg>=0)) {
     this->fg=tfg;
     redraw();
   }
@@ -99,7 +88,7 @@ int SolidButton::getFG() const
 
 void SolidButton::setBG(int tbg)
 {
-  if((tbg<(aguix->getMaxCols()))&&(tbg>=0)) {
+  if((tbg<(_aguix->getMaxCols()))&&(tbg>=0)) {
     this->bg=tbg;
     redraw();
   }
@@ -124,46 +113,46 @@ void SolidButton::setState(bool tstate)
 void SolidButton::redraw()
 {
   GC usegc;
-  if(parent==NULL) return;
+  if ( isCreated() == false ) return;
   if(win==0) return;
-  aguix->SetWindowBG(win,bg);
+  _aguix->SetWindowBG(win,bg);
   lastbg=bg;
-  aguix->ClearWin(win);
+  _aguix->ClearWin(win);
   if(font==NULL) usegc=0; else usegc=font->getGC();
   if(state==true) {
-    aguix->setFG(usegc,1);
+    _aguix->setFG(usegc,1);
   } else {
-    aguix->setFG(usegc,2);
+    _aguix->setFG(usegc,2);
   }
-  aguix->DrawLine(win,usegc,0,h-1,0,0);
-  aguix->DrawLine(win,usegc,0,0,w-1,0);
+  _aguix->DrawLine(win,usegc,0,_h-1,0,0);
+  _aguix->DrawLine(win,usegc,0,0,_w-1,0);
   if(state==true) {
-    aguix->setFG(usegc,2);
+    _aguix->setFG(usegc,2);
   } else {
-    aguix->setFG(usegc,1);
+    _aguix->setFG(usegc,1);
   }
-  aguix->DrawLine(win,usegc,0,h-1,w-1,h-1);
-  aguix->DrawLine(win,usegc,w-1,h-1,w-1,1);
-  aguix->setFG(usegc,fg);
+  _aguix->DrawLine(win,usegc,0,_h-1,_w-1,_h-1);
+  _aguix->DrawLine(win,usegc,_w-1,_h-1,_w-1,1);
+  _aguix->setFG(usegc,fg);
   int ch,cw;
   if(font==NULL) {
-    ch=aguix->getCharHeight();
-    cw=aguix->getCharWidth();
+    ch=_aguix->getCharHeight();
+    cw=_aguix->getCharWidth();
   } else {
     ch=font->getCharHeight();
     cw=font->getCharWidth();
   }
-  int dy=h/2-ch/2;
-  unsigned int maxdisplay=(w-2)/cw;
+  int dy=_h/2-ch/2;
+  unsigned int maxdisplay=(_w-2)/cw;
   char *tstr;
   tstr=dupstring(text);
   if(strlen(tstr)>maxdisplay) tstr[maxdisplay]=0;
-  int dw=strlen(tstr)*(aguix->getCharWidth());
-  int dx=w/2-dw/2;
-  if(font==NULL) aguix->DrawText(win,tstr,dx,dy);
-  else aguix->DrawText(win,font,tstr,dx,dy);
+  int dw=strlen(tstr)*(_aguix->getCharWidth());
+  int dx=_w/2-dw/2;
+  if(font==NULL) _aguix->DrawText(win,tstr,dx,dy);
+  else _aguix->DrawText(win,font,tstr,dx,dy);
   _freesafe(tstr);
-  aguix->Flush();
+  _aguix->Flush();
 }
 
 void SolidButton::flush()
@@ -172,7 +161,7 @@ void SolidButton::flush()
 
 bool SolidButton::handleMessage(XEvent *E,Message *msg)
 {
-  if ( parent == NULL ) return false;
+  if ( isCreated() == false ) return false;
   if((msg->type==Expose)&&(msg->window==win)) {
     redraw();
   }
@@ -181,7 +170,7 @@ bool SolidButton::handleMessage(XEvent *E,Message *msg)
 
 int SolidButton::setFont(char *fontname)
 {
-  font=aguix->getFont(fontname);
+  font=_aguix->getFont(fontname);
   if(font==NULL) return -1;
   return 0;
 }
