@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: stringgadget.cc,v 1.48 2005/03/22 18:40:46 ralf Exp $ */
+/* $Id: stringgadget.cc,v 1.49 2005/05/15 13:47:38 ralf Exp $ */
 
 #include "stringgadget.h"
 #include "awindow.h"
@@ -28,48 +28,24 @@ const char *StringGadget::type="StringGadget";
 
 StringGadget::~StringGadget()
 {
-  if ( parent != NULL ) parent->remove( this );
-  aguix->cancelCutPaste(this);
-  _freesafe(text);
-}
-
-StringGadget::StringGadget(AGUIX *taguix):GUIElement(taguix)
-{
-  data=0;
-  w=100;
-  h=100;
-  text=(char*)_allocsafe(1);
-  text[0]='\0';
-  cursorpos=0;
-  xoffset=0;
-  active=false;
-  tbg=-1;
-  bgset=false;
-  selstart=selend=cursorpos;
-  font=NULL;
-  forbidPosChange=false;
-  strongkeycapture=true;
-  wantpaste=false;
-  pasterequest=0;
-  twin = 0;
-  canHandleFocus = true;
-  setAcceptFocus( true );
-  passwordMode = false;
+  _aguix->cancelCutPaste( this );
+  destroy();
+  _freesafe( text );
 }
 
 StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,int height,const char *ttext,int tdata):GUIElement(taguix)
 {
   this->data=tdata;
-  this->x=tx;
-  this->y=ty;
+  _x=tx;
+  _y=ty;
   if ( width > 8 )
-    this->w = width;
+    _w = width;
   else
-    this->w = 8;
+    _w = 8;
   if ( height > 8 )
-    this->h = height;
+    _h = height;
   else
-    this->h = 8;
+    _h = 8;
   xoffset=0;
   cursorpos=0;
   active=false;
@@ -83,7 +59,7 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,int height,cons
   wantpaste=false;
   pasterequest=0;
   twin = 0;
-  canHandleFocus = true;
+  setCanHandleFocus();
   setAcceptFocus( true );
   passwordMode = false;
 }
@@ -91,13 +67,13 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,int height,cons
 StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,const char *ttext,int tdata):GUIElement(taguix)
 {
   this->data=tdata;
-  this->x=tx;
-  this->y=ty;
+  _x=tx;
+  _y=ty;
   if ( width > 8 )
-    this->w = width;
+    _w = width;
   else
-    this->w = 8;
-  this->h=taguix->getCharHeight()+2+6;
+    _w = 8;
+  _h=taguix->getCharHeight()+2+6;
   xoffset=0;
   cursorpos=0;
   active=false;
@@ -111,7 +87,7 @@ StringGadget::StringGadget(AGUIX *taguix,int tx,int ty,int width,const char *tte
   wantpaste=false;
   pasterequest=0;
   twin = 0;
-  canHandleFocus = true;
+  setCanHandleFocus();
   setAcceptFocus( true );
   passwordMode = false;
 }
@@ -120,10 +96,10 @@ void StringGadget::resize(int tw,int th)
 {
   if ( tw < 8 ) tw = 8;
   if ( th < 8 ) th = 8;
-  this->w=tw;
-  this->h=th;
-  if(parent!=NULL) {
-    parent->resizeSubWin(win,tw,th);
+  _w=tw;
+  _h=th;
+  if ( isCreated() == true ) {
+    _parent->resizeSubWin(win,tw,th);
   }
   updateWin();
   redraw();
@@ -147,30 +123,30 @@ void StringGadget::redraw()
 
 void StringGadget::bredraw()
 {
-  if(parent!=NULL) {
-    aguix->SetWindowBG(win,parent->getBG());
-    aguix->ClearWin(win);
-    aguix->setFG(2);
-    aguix->DrawLine(win,0,h-1,0,0);
-    aguix->DrawLine(win,0,0,w-1,0);
-    aguix->DrawLine(win,2,h-1-2,w-1-2,h-1-2);
-    aguix->DrawLine(win,w-1-2,h-1-2,w-1-2,2);
-    aguix->setFG(1);
-    aguix->DrawLine(win,0,h-1,w-1,h-1);
-    aguix->DrawLine(win,w-1,h-1,w-1,0);
-    aguix->DrawLine(win,2,h-1-2,2,2);
-    aguix->DrawLine(win,2,2,w-1-2,2);
+  if ( isCreated() == true ) {
+    _aguix->SetWindowBG(win,_parent->getBG());
+    _aguix->ClearWin(win);
+    _aguix->setFG(2);
+    _aguix->DrawLine(win,0,_h-1,0,0);
+    _aguix->DrawLine(win,0,0,_w-1,0);
+    _aguix->DrawLine(win,2,_h-1-2,_w-1-2,_h-1-2);
+    _aguix->DrawLine(win,_w-1-2,_h-1-2,_w-1-2,2);
+    _aguix->setFG(1);
+    _aguix->DrawLine(win,0,_h-1,_w-1,_h-1);
+    _aguix->DrawLine(win,_w-1,_h-1,_w-1,0);
+    _aguix->DrawLine(win,2,_h-1-2,2,2);
+    _aguix->DrawLine(win,2,2,_w-1-2,2);
   }
 }
 
 void StringGadget::tredraw()
 {
-  int maxcol=aguix->getMaxCols();
+  int maxcol=_aguix->getMaxCols();
   int newbg;
   GC usegc;
   int minx, maxx;
 
-  if(parent==NULL) return;
+  if ( isCreated() == false ) return;
   if(active==true) {
     if(maxcol>7) {
       newbg=7;
@@ -180,14 +156,14 @@ void StringGadget::tredraw()
   } else {
     newbg=0;
   }
-  aguix->SetWindowBG(twin,newbg);
+  _aguix->SetWindowBG(twin,newbg);
   tbg=newbg;
-  aguix->ClearWin(twin);
+  _aguix->ClearWin(twin);
   if(font==NULL) usegc=0; else usegc=font->getGC();
   int cw,ch;
   if(font==NULL) {
-    ch=aguix->getCharHeight();
-    cw=aguix->getCharWidth();
+    ch=_aguix->getCharHeight();
+    cw=_aguix->getCharWidth();
   } else {
     ch=font->getCharHeight();
     cw=font->getCharWidth();
@@ -195,7 +171,7 @@ void StringGadget::tredraw()
   char *tstr=(char*)_allocsafe(maxdisplay+1);
   int dx;
   dx=1;
-  double f1=((h-6-2)/2)-(ch/2);
+  double f1=((_h-6-2)/2)-(ch/2);
   int dy=(int)f1;
   int x1,x2;
   int len;
@@ -206,7 +182,7 @@ void StringGadget::tredraw()
   
   if( xoffset < x1 ) {
     // links vom x1 ist noch Text
-    aguix->setFG(usegc,1);
+    _aguix->setFG(usegc,1);
     
     len = a_min( x1 - xoffset, maxdisplay );
 
@@ -216,8 +192,8 @@ void StringGadget::tredraw()
       strncpy( tstr, text + xoffset, len );
     }
     tstr[ len ]=0;
-    if(font==NULL) aguix->DrawText(twin,tstr,dx,dy);
-    else aguix->DrawText(twin,font,tstr,dx,dy);
+    if(font==NULL) _aguix->DrawText(twin,tstr,dx,dy);
+    else _aguix->DrawText(twin,font,tstr,dx,dy);
     dx+=strlen(tstr)*cw;
   }
   if ( ! ( ( x2 < xoffset ) || ( ( x1 - xoffset ) > maxdisplay ) ) ) {
@@ -235,22 +211,22 @@ void StringGadget::tredraw()
     }
     tstr[len] = 0;
     if(active==true) {
-      aguix->setFG(usegc,1);
+      _aguix->setFG(usegc,1);
     } else {
-      aguix->setFG(usegc,0);
+      _aguix->setFG(usegc,0);
     }
-    aguix->FillRectangle( twin, usegc, dx, dy, len * cw, ch );
+    _aguix->FillRectangle( twin, usegc, dx, dy, len * cw, ch );
     if(active==true) {
       if(maxcol>7) {
-	aguix->setFG(usegc,7);
+	_aguix->setFG(usegc,7);
       } else {
-	aguix->setFG(usegc,0);
+	_aguix->setFG(usegc,0);
       }
     } else {
-      aguix->setFG(usegc,1);
+      _aguix->setFG(usegc,1);
     }
-    if(font==NULL) aguix->DrawText(twin,tstr,dx,dy);
-    else aguix->DrawText(twin,font,tstr,dx,dy);
+    if(font==NULL) _aguix->DrawText(twin,tstr,dx,dy);
+    else _aguix->DrawText(twin,font,tstr,dx,dy);
     dx += len * cw;
   }
   if((x2-xoffset)<(maxdisplay-1)) {
@@ -274,13 +250,13 @@ void StringGadget::tredraw()
       }
       tstr[ len ] = 0;
       
-      aguix->setFG(usegc,1);
-      if(font==NULL) aguix->DrawText(twin,tstr,dx,dy);
-      else aguix->DrawText(twin,font,tstr,dx,dy);
+      _aguix->setFG(usegc,1);
+      if(font==NULL) _aguix->DrawText(twin,tstr,dx,dy);
+      else _aguix->DrawText(twin,font,tstr,dx,dy);
     }
   }
   _freesafe(tstr);
-  aguix->Flush();
+  _aguix->Flush();
 }
 
 void StringGadget::flush()
@@ -303,10 +279,10 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
   int tx,ty;
   AGMessage *agmsg;
   
-  if ( parent == NULL ) return false;
+  if ( isCreated() == false ) return false;
 
   if(font==NULL) {
-    cw=aguix->getCharWidth();
+    cw=_aguix->getCharWidth();
   } else {
     cw=font->getCharWidth();
   }
@@ -320,10 +296,10 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
         agmsg->type=AG_STRINGGADGET_DEACTIVATE;
         agmsg->stringgadget.sg=this;
 	agmsg->stringgadget.ok = false;
-        aguix->putAGMsg(agmsg);
+        _aguix->putAGMsg(agmsg);
       } else {
         if(forbidPosChange==false) {
-	  aguix->queryPointer(msg->window,&tx,&ty);
+	  _aguix->queryPointer(msg->window,&tx,&ty);
           int nc=tx/cw;
 	  if ( nc < maxdisplay ) {
 	    cursorpos=nc+xoffset;
@@ -338,7 +314,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
     } else {
       if(msg->type==KeyPress) {
 	if ( isVisible() == true ) {
-	  if ( parent->isTopParent( msg->window ) == true ) {
+	  if ( _parent->isTopParent( msg->window ) == true ) {
 	    ignoreRelease=false;
 	    int keystate=KEYSTATEMASK(msg->keystate);
 	    if((msg->key==XK_Right)||
@@ -380,7 +356,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CURSORCHANGE;
 		agmsg->stringgadget.sg=this;
-		aguix->putAGMsg(agmsg);
+		_aguix->putAGMsg(agmsg);
 	      }
 	    } else if((msg->key==XK_Left)||
 		      (msg->key==XK_Home)||
@@ -421,7 +397,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CURSORCHANGE;
 		agmsg->stringgadget.sg=this;
-		aguix->putAGMsg(agmsg);
+		_aguix->putAGMsg(agmsg);
 	      }
 	    } else if((msg->key==XK_Delete)||((msg->key==XK_d)&&(keystate==ControlMask))) {
 	      int len=strlen(text);
@@ -441,7 +417,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CONTENTCHANGE;
 		agmsg->stringgadget.sg=this;
-		aguix->putAGMsg(agmsg);
+		_aguix->putAGMsg(agmsg);
 	      }
 	    } else if((msg->key==XK_BackSpace)||((msg->key==XK_h)&&(keystate==ControlMask))) {
 	      int len=strlen(text);
@@ -467,7 +443,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CONTENTCHANGE;
 		agmsg->stringgadget.sg=this;
-		aguix->putAGMsg(agmsg);
+		_aguix->putAGMsg(agmsg);
 	      }
 	    } else if ( msg->key == XK_Return ) {
 	      if ( strongkeycapture == true ) returnvalue = true;
@@ -499,13 +475,13 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 	      agmsg = AGUIX_allocAGMessage();
 	      agmsg->type = AG_STRINGGADGET_CONTENTCHANGE;
 	      agmsg->stringgadget.sg = this;
-	      aguix->putAGMsg( agmsg );
+	      _aguix->putAGMsg( agmsg );
 	    }
 	  }
 	}
       } else if((msg->type==KeyRelease)&&(ignoreRelease==false)) {
 	if ( isVisible() == true ) {
-	  if ( parent->isTopParent( msg->window ) == true ) {
+	  if ( _parent->isTopParent( msg->window ) == true ) {
 	    int keystate=KEYSTATEMASK(msg->keystate);
 	    if((msg->key==XK_Return)||(msg->key==XK_Escape)) {
 	      active=false;
@@ -516,17 +492,17 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
 	      agmsg->type=AG_STRINGGADGET_DEACTIVATE;
 	      agmsg->stringgadget.sg=this;
 	      agmsg->stringgadget.ok = ( msg->key == XK_Return ) ? true : false;
-	      aguix->putAGMsg(agmsg);
+	      _aguix->putAGMsg(agmsg);
 	      if(msg->key==XK_Return) {
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_OK;
 		agmsg->stringgadget.sg=this;
-		aguix->putAGMsg(agmsg);
+		_aguix->putAGMsg(agmsg);
 	      } else {
 		agmsg = AGUIX_allocAGMessage();
 		agmsg->type=AG_STRINGGADGET_CANCEL;
 		agmsg->stringgadget.sg=this;
-		aguix->putAGMsg(agmsg);
+		_aguix->putAGMsg(agmsg);
 	      }
 	    } else if((msg->key==XK_Right)||
 		      (msg->key==XK_End)||
@@ -558,7 +534,7 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
       } else if(msg->type==ButtonRelease) {
         applySelection();
       } else if(E->type==MotionNotify) {
-        aguix->queryPointer(msg->window,&tx,&ty);
+        _aguix->queryPointer(msg->window,&tx,&ty);
         int nc=tx/cw;
         int ncp=nc+xoffset;
         if(ncp>=(int)strlen(text)) ncp=strlen(text);
@@ -583,9 +559,9 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
       agmsg = AGUIX_allocAGMessage();
       agmsg->type=AG_STRINGGADGET_ACTIVATE;
       agmsg->stringgadget.sg=this;
-      aguix->putAGMsg(agmsg);
+      _aguix->putAGMsg(agmsg);
       if(forbidPosChange==false) {
-        aguix->queryPointer(msg->window,&tx,&ty);
+        _aguix->queryPointer(msg->window,&tx,&ty);
         int nc=tx/cw;
 	if ( nc < maxdisplay ) {
 	  cursorpos=nc+xoffset;
@@ -631,10 +607,10 @@ void StringGadget::updateWin()
 {
   int i1;
 
-  if(parent!=NULL) {
-    parent->resizeSubWin(twin,w-6,h-6);
-    if(font==NULL) maxdisplay=(w-6-2)/aguix->getCharWidth();
-    else maxdisplay=(w-6-2)/font->getCharWidth();
+  if ( isCreated() == true ) {
+    _parent->resizeSubWin(twin,_w-6,_h-6);
+    if(font==NULL) maxdisplay=(_w-6-2)/_aguix->getCharWidth();
+    else maxdisplay=(_w-6-2)/font->getCharWidth();
     
     // make the cursor visible again
     if ( maxdisplay > 0 ) {
@@ -673,7 +649,7 @@ void StringGadget::applySelection()
     if(x1<x2) {
       buffer=dupstring(text+x1);
       buffer[x2-x1+1]=0;
-      aguix->startCut(this,buffer);
+      _aguix->startCut(this,buffer);
       _freesafe(buffer);
     }
   }
@@ -700,12 +676,12 @@ void StringGadget::removeSelection()
 
 void StringGadget::insertSelection()
 {
-  if ( parent == NULL ) return;
+  if ( isCreated() == false ) return;
   int nbytes_return;
   char *bytes_return,*tstr;
 
-  if(aguix->amiOwner()==true) {
-    bytes_return=dupstring(aguix->getCutBuffer());
+  if(_aguix->amiOwner()==true) {
+    bytes_return=dupstring(_aguix->getCutBuffer());
     nbytes_return=strlen(bytes_return);
     // an Cursorpos einfgen
     int tl=strlen(text);
@@ -719,8 +695,8 @@ void StringGadget::insertSelection()
     text=tstr;
     _freesafe(bytes_return);
   } else {
-    aguix->requestCut(getWindow());
-    aguix->startPaste(this);
+    _aguix->requestCut(getWindow());
+    _aguix->startPaste(this);
     wantpaste=true;
     pasterequest=time(NULL);
   }
@@ -728,7 +704,7 @@ void StringGadget::insertSelection()
 
 int StringGadget::setFont(char *fontname)
 {
-  font=aguix->getFont(fontname);
+  font=_aguix->getFont(fontname);
   updateWin();
   if(font==NULL) return -1;
   return 0;
@@ -747,7 +723,7 @@ bool StringGadget::isType(const char *qtype) const
 
 bool StringGadget::isParent(Window child) const
 {
-  if ( parent == NULL ) return false;
+  if ( isCreated() == false ) return false;
   if(child==win) return true;
   if(child==twin) return true;
   return false;
@@ -845,49 +821,21 @@ void StringGadget::doCreateStuff()
 {
   GUIElement::doCreateStuff();
   if ( twin == 0 ) {
-    twin=parent->getSubWindow(win,3,3,w-6,h-6);
+    twin=_parent->getSubWindow(win,3,3,_w-6,_h-6);
   }
-  if(font==NULL) maxdisplay=(w-6-2)/aguix->getCharWidth();
-  else maxdisplay=(w-6-2)/font->getCharWidth();
+  if(font==NULL) maxdisplay=(_w-6-2)/_aguix->getCharWidth();
+  else maxdisplay=(_w-6-2)/font->getCharWidth();
 }
 
 void StringGadget::doDestroyStuff()
 {
   if ( twin != 0 ) {
-    parent->removeSubWin(twin);
+    _parent->removeSubWin(twin);
     twin = 0;
   }
   GUIElement::doDestroyStuff();
 }
 
-void StringGadget::takeFocus()
-{
-  GUIElement::takeFocus();
-  if ( active == false ) {
-    //    active = true;
-    //    redraw();
-    activate();
-    AGMessage *agmsg = AGUIX_allocAGMessage();
-    agmsg->type = AG_STRINGGADGET_ACTIVATE;
-    agmsg->stringgadget.sg = this;
-    aguix->putAGMsg( agmsg );
-  }
-}
-
-void StringGadget::leaveFocus()
-{
-  GUIElement::leaveFocus();
-  if ( active == true ) {
-    active = false;
-    tredraw();
-    AGMessage *agmsg = AGUIX_allocAGMessage();
-    agmsg->type = AG_STRINGGADGET_DEACTIVATE;
-    agmsg->stringgadget.sg = this;
-    agmsg->stringgadget.ok = false;
-    aguix->putAGMsg( agmsg );
-  }
-}
-
 void StringGadget::insertAtCursor( const char *str )
 {
   if ( str == NULL ) return;
@@ -922,3 +870,27 @@ void StringGadget::setPasswordMode( bool nv )
   passwordMode = nv;
   redraw();
 }
+
+void StringGadget::lostFocus()
+{
+  if ( active == true ) {
+    active = false;
+    tredraw();
+    AGMessage *agmsg = AGUIX_allocAGMessage();
+    agmsg->type = AG_STRINGGADGET_DEACTIVATE;
+    agmsg->stringgadget.sg = this;
+    agmsg->stringgadget.ok = false;
+    _aguix->putAGMsg( agmsg );
+  }
+}
+
+void StringGadget::gotFocus()
+{
+  if ( active == false ) {
+    activate();
+    AGMessage *agmsg = AGUIX_allocAGMessage();
+    agmsg->type = AG_STRINGGADGET_ACTIVATE;
+    agmsg->stringgadget.sg = this;
+    _aguix->putAGMsg( agmsg );
+  }
+}
