@@ -1,6 +1,6 @@
 /* stringgadget.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: stringgadget.h,v 1.17 2005/03/20 20:44:56 ralf Exp $ */
+/* $Id: stringgadget.h,v 1.18 2005/05/15 13:47:42 ralf Exp $ */
 
 #ifndef STRINGGADGET_H
 #define STRINGGADGET_H
@@ -28,7 +28,6 @@
 
 class StringGadget:public GUIElement {
 public:
-  StringGadget(class AGUIX *aguix);
   StringGadget(class AGUIX *aguix,int x,int y,int width,int height,const char *text,int data);
   StringGadget(class AGUIX *aguix,int x,int y,int width,const char *text,int data);
   virtual ~StringGadget();
@@ -60,8 +59,6 @@ public:
   virtual void paste(unsigned char*);
   virtual void cancelpaste();
   virtual void cancelcut();
-  virtual void takeFocus();
-  virtual void leaveFocus();
   void insertAtCursor( const char *str );
   void selectAll();
   void setPasswordMode( bool nv );
@@ -95,6 +92,8 @@ private:
   bool wantpaste;
   time_t pasterequest;
   bool passwordMode;
+  void lostFocus();
+  void gotFocus();
 };
 
 #endif
