@@ -1,6 +1,6 @@
 /* text.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: text.cc,v 1.11 2004/10/27 20:43:21 ralf Exp $ */
+/* $Id: text.cc,v 1.12 2005/05/15 13:47:47 ralf Exp $ */
 
 #include "text.h"
 #include "lowlevelfunc.h"
@@ -26,24 +26,13 @@
 
 const char *Text::type="Text";
 
-Text::Text(AGUIX *taguix):GUIElement(taguix)
-{
-  text=(char*)_allocsafe(1);
-  text[0]='\0';
-  color=1;
-  bgset=false;
-  font=NULL;
-  bg = 0;
-  ownbg = false;
-}
-
 Text::Text(AGUIX *taguix,int tx,int ty,const char *ttext,int tcolor):GUIElement(taguix)
 {
   this->text=dupstring(ttext);
-  this->x=tx;
-  this->y=ty;
-  this->w=taguix->getCharWidth()*strlen(ttext)+1;
-  this->h=taguix->getCharHeight();
+  _x=tx;
+  _y=ty;
+  _w=taguix->getCharWidth()*strlen(ttext)+1;
+  _h=taguix->getCharHeight();
   this->color=tcolor;
   bgset=false;
   font=NULL;
@@ -54,10 +43,10 @@ Text::Text(AGUIX *taguix,int tx,int ty,const char *ttext,int tcolor):GUIElement(
 Text::Text( AGUIX *taguix, int tx, int ty, const char *ttext, int tfg, int tbg ):GUIElement( taguix )
 {
   this->text = dupstring( ttext );
-  this->x = tx;
-  this->y = ty;
-  this->w = taguix->getCharWidth() * strlen( ttext ) + 1;
-  this->h = taguix->getCharHeight();
+  _x = tx;
+  _y = ty;
+  _w = taguix->getCharWidth() * strlen( ttext ) + 1;
+  _h = taguix->getCharHeight();
   this->color = tfg;
   bgset = false;
   font = NULL;
@@ -79,10 +68,10 @@ void Text::setText(const char *new_text)
 {
   if(text!=NULL) _freesafe(text);
   text=dupstring(new_text);
-  if(font==NULL) this->w=aguix->getCharWidth()*strlen(text)+1;
-  else this->w=font->getCharWidth()*strlen(text)+1;
-  if(parent!=NULL) {
-    parent->resizeSubWin(win,w,h);
+  if(font==NULL) _w=_aguix->getCharWidth()*strlen(text)+1;
+  else _w=font->getCharWidth()*strlen(text)+1;
+  if ( isCreated() == true ) {
+    _parent->resizeSubWin(win,_w,_h);
   }
   redraw();
 }
@@ -94,7 +83,7 @@ int Text::getColor() const
 
 void Text::setColor(int tcolor)
 {
-  if((tcolor<(aguix->getMaxCols()))&&(tcolor>=0)) {
+  if((tcolor<(_aguix->getMaxCols()))&&(tcolor>=0)) {
     this->color=tcolor;
     redraw();
   }
@@ -103,21 +92,21 @@ void Text::setColor(int tcolor)
 void Text::redraw()
 {
   GC usegc;
-  if(parent!=NULL) {
+  if ( isCreated() == true ) {
     if(font==NULL) usegc=0;
     else usegc=font->getGC();
     if ( bgset == false ) {
       if ( ownbg == true ) {
-	aguix->SetWindowBG( win, bg );
+	_aguix->SetWindowBG( win, bg );
       } else {
-	aguix->SetWindowBG( win, parent->getBG() );
+	_aguix->SetWindowBG( win, _parent->getBG() );
       }
       bgset = true;
     }
-    aguix->ClearWin(win);
-    aguix->setFG(usegc,color);
-    if(font==NULL) aguix->DrawText(win,text,0,0);
-    else aguix->DrawText(win,font,text,0,0);
+    _aguix->ClearWin(win);
+    _aguix->setFG(usegc,color);
+    if(font==NULL) _aguix->DrawText(win,text,0,0);
+    else _aguix->DrawText(win,font,text,0,0);
   }
 }
 
@@ -127,7 +116,7 @@ void Text::flush()
 
 bool Text::handleMessage(XEvent *E,Message *msg)
 {
-  if ( parent == NULL ) return false;
+  if ( isCreated() == false ) return false;
   if((msg->type==Expose)&&(msg->window==win)) {
     redraw();
   }
@@ -136,12 +125,12 @@ bool Text::handleMessage(XEvent *E,Message *msg)
 
 int Text::setFont(char *fontname)
 {
-  font=aguix->getFont(fontname);
+  font=_aguix->getFont(fontname);
   if(font==NULL) return -1;
-  this->w=font->getCharWidth()*strlen(text)+1;
-  this->h=font->getCharHeight();
-  if(parent!=NULL) {
-    parent->resizeSubWin(win,w,h);
+  _w=font->getCharWidth()*strlen(text)+1;
+  _h=font->getCharHeight();
+  if ( isCreated() == true ) {
+    _parent->resizeSubWin(win,_w,_h);
   }
   return 0;
 }
@@ -159,7 +148,7 @@ bool Text::isType(const char *qtype) const
 
 void Text::setBG( int tcolor )
 {
-  if ( ( tcolor < ( aguix->getMaxCols() ) ) && ( tcolor >= 0 ) ) {
+  if ( ( tcolor < ( _aguix->getMaxCols() ) ) && ( tcolor >= 0 ) ) {
     bg = tcolor;
     ownbg = true;
     bgset = false;
