@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: basic_actions.cc,v 1.23 2004/12/12 22:00:23 ralf Exp $ */
+/* $Id: basic_actions.cc,v 1.24 2005/05/15 14:03:55 ralf Exp $ */
 
 #include "basic_actions.h"
 #include "listermode.h"
@@ -929,11 +929,11 @@ int UserAction::configure()
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(4))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(4));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win =new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   rcyb=(CycleButton*)win->add(new CycleButton(aguix,x,y,100,1,0,0));
@@ -1006,7 +1006,6 @@ int UserAction::configure()
     nr=rcyb->getSelectedOption();
   }
   
-  win->close();
   delete win;
 
   return endmode;
@@ -1144,11 +1143,11 @@ int ChangeHiddenFlag::configure()
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(7))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(7));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win=new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   rcyb=(CycleButton*)win->add(new CycleButton(aguix,x,y,100,1,0,0));
@@ -1234,7 +1233,6 @@ int ChangeHiddenFlag::configure()
     }
   }
   
-  win->close();
   delete win;
 
   return endmode;
