@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: chmodop.cc,v 1.23 2004/12/12 21:59:43 ralf Exp $ */
+/* $Id: chmodop.cc,v 1.24 2005/05/15 14:04:31 ralf Exp $ */
 
 #include "chmodop.h"
 #include "listermode.h"
@@ -176,10 +176,11 @@ ChModOp::doconfigure(int mode)
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
+
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(38))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(38));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
   
   Text *tt1 = (Text*)win->add( new Text( aguix, x, y, catalog.getLocaleCom( 38 ), 1 ) );
@@ -266,7 +267,7 @@ ChModOp::doconfigure(int mode)
                 rcb->setState((rcb->getState()==1)?0:1);
                 break;
               case XK_Return:
-                if ( cb->hasFocus() == false )
+                if ( cb->getHasFocus() == false )
                   endmode=0;
                 break;
               case XK_Escape:
@@ -294,7 +295,6 @@ ChModOp::doconfigure(int mode)
     }
   }
   
-  win->close();
   delete win;
 
   return endmode;
