@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: chownop.cc,v 1.12 2004/12/12 21:59:31 ralf Exp $ */
+/* $Id: chownop.cc,v 1.13 2005/05/15 15:53:10 ralf Exp $ */
 
 #include "chownop.h"
 #include "listermode.h"
@@ -177,10 +177,10 @@ ChOwnOp::doconfigure( int mode )
   
   w = h = 10;
   x = y = 5;
-  win = new AWindow( aguix );
   tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( catalog.getLocaleCom( 43 ) ) + 1 );
   sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 43 ) );
-  win->create( NULL, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe( tstr );
 
   Text *tt1 = (Text*)win->add( new Text( aguix, x, y, catalog.getLocaleCom( 43 ), 1 ) );
@@ -263,7 +263,7 @@ ChOwnOp::doconfigure( int mode )
                 rcb->setState( ( rcb->getState() == 1 ) ? 0 : 1 );
                 break;
               case XK_Return:
-                if ( cb->hasFocus() == false ) {
+                if ( cb->getHasFocus() == false ) {
                   endmode = 0;
                 }
                 break;
@@ -292,7 +292,6 @@ ChOwnOp::doconfigure( int mode )
     }
   }
   
-  win->close();
   delete win;
 
   return endmode;
