@@ -305,14 +305,18 @@
      PASSWORD_WCP = 528,
      DONTENTERFTP_WCP = 529,
      ALWAYSSTOREPW_WCP = 530,
-     ERROR = 531,
-     ACTIVESIDE_WCP = 532,
-     SHOWFREESPACE_WCP = 533,
-     ACTIVEMODE_WCP = 534,
-     ASK_WCP = 535,
-     SSHALLOW_WCP = 536,
-     STRING_WCP = 537,
-     NUM_WCP = 538
+     INTERNALVIEWOP_WCP = 531,
+     CUSTOMFILES_WCP = 532,
+     SHOWMODE_WCP = 533,
+     SELECTED_WCP = 534,
+     ERROR = 535,
+     ACTIVESIDE_WCP = 536,
+     SHOWFREESPACE_WCP = 537,
+     ACTIVEMODE_WCP = 538,
+     ASK_WCP = 539,
+     SSHALLOW_WCP = 540,
+     STRING_WCP = 541,
+     NUM_WCP = 542
    };
 #endif
 #define LEFTBRACE_WCP 258
@@ -588,14 +592,18 @@
 #define PASSWORD_WCP 528
 #define DONTENTERFTP_WCP 529
 #define ALWAYSSTOREPW_WCP 530
-#define ERROR 531
-#define ACTIVESIDE_WCP 532
-#define SHOWFREESPACE_WCP 533
-#define ACTIVEMODE_WCP 534
-#define ASK_WCP 535
-#define SSHALLOW_WCP 536
-#define STRING_WCP 537
-#define NUM_WCP 538
+#define INTERNALVIEWOP_WCP 531
+#define CUSTOMFILES_WCP 532
+#define SHOWMODE_WCP 533
+#define SELECTED_WCP 534
+#define ERROR 535
+#define ACTIVESIDE_WCP 536
+#define SHOWFREESPACE_WCP 537
+#define ACTIVEMODE_WCP 538
+#define ASK_WCP 539
+#define SSHALLOW_WCP 540
+#define STRING_WCP 541
+#define NUM_WCP 542
 
 
 
@@ -607,7 +615,7 @@ typedef union {
   char *strptr;
 } yystype;
 /* Line 1281 of /usr/share/bison/yacc.c.  */
-#line 611 "configparser.tab.h"
+#line 619 "configparser.tab.h"
 # define YYSTYPE yystype
 #endif
 
