@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: configtokens.cc,v 1.19 2005/03/23 21:57:28 ralf Exp $ */
+/* $Id: configtokens.cc,v 1.20 2005/05/19 19:47:05 ralf Exp $ */
 
 #include "wdefines.h"
 #include <aguix/util.h>
@@ -301,7 +301,11 @@ struct mytoken tokenlist[]={
   { DONTENTERFTP_WCP, "dontenterftp" },
   { ALWAYSSTOREPW_WCP, "alwaysstorepw" },
   { ASK_WCP, "ask" },
-  { SSHALLOW_WCP, "sshallow" }
+  { SSHALLOW_WCP, "sshallow" },
+  { INTERNALVIEWOP_WCP, "internalviewop" },
+  { CUSTOMFILES_WCP, "customfiles" },
+  { SHOWMODE_WCP, "showmode" },
+  { SELECTED_WCP, "selected" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
