@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: copyop.cc,v 1.64 2004/12/12 21:59:12 ralf Exp $ */
+/* $Id: copyop.cc,v 1.66 2005/06/27 17:44:30 ralf Exp $ */
 
 #include "listermode.h"
 #include "normalmode.h"
@@ -333,10 +333,11 @@ CopyOp::doconfigure(int mode)
   req=new Requester(aguix);
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
+
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(8))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(8));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   ttext = (Text*)win->add( new Text( aguix, x, y, catalog.getLocaleCom( 8 ), 1 ) );
@@ -506,7 +507,7 @@ CopyOp::doconfigure(int mode)
                 fccyb->setOption(i);
                 break;
               case XK_Return:
-                if ( cb->hasFocus() == false ) {
+                if ( cb->getHasFocus() == false ) {
                   endmode = 0;
                 }
                 break;
@@ -589,7 +590,6 @@ CopyOp::doconfigure(int mode)
     }
   }
   
-  win->close();
   delete win;
   delete req;
 
@@ -729,13 +729,13 @@ CopyOpWin::open(bool tslim)
 
   close();
   this->slim=tslim;
-  window=new AWindow(aguix);
   w=400;
   h=10;
-  window->create( NULL,
-                  10, 10,
-                  w, h,
-                  0, ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ) );
+  window = new AWindow( aguix,
+			10, 10,
+			w, h,
+			0, ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ) );
+  window->create();
   tx=5;
   ty=5;
   sourcetext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
@@ -818,7 +818,6 @@ void
 CopyOpWin::close()
 {
   if(window!=NULL) {
-    window->close();
     delete window;
   }
   window=NULL;
@@ -927,13 +926,15 @@ CopyOpWin::redraw()
   struct timeval curtime;
   double difftime2, lastdiff2;
   char tstr[1024],
-       buf1[A_BYTESFORNICENUMBER(loff_t)],
-       buf2[A_BYTESFORNICENUMBER(loff_t)],
        *tstr2;
   double rate;
   int tw;
   bool doresize = false;
   int newglob_percent;
+  std::string copied_bytes_curfile_str,
+              bytes_curfile_str,
+              copied_bytes_str,
+              bytes_str;
   
   char *tstr3;
 
@@ -983,9 +984,13 @@ CopyOpWin::redraw()
       lasttime = curtime;
     }
     
-    buf1[MakeLong2NiceStr(buf1,copied_bytes_curfile)]='\0';
-    buf2[MakeLong2NiceStr(buf2,bytes_curfile)]='\0';
-    snprintf( tstr, sizeof( tstr ), "%s / %s @ %.2f KB/s", buf1, buf2, lastrate / 1024.0 );
+    MakeLong2NiceStr( copied_bytes_curfile, copied_bytes_curfile_str );
+
+    MakeLong2NiceStr( bytes_curfile, bytes_curfile_str );
+    snprintf( tstr, sizeof( tstr ), "%s / %s @ %.2f KB/s",
+	      copied_bytes_curfile_str.c_str(),
+	      bytes_curfile_str.c_str(),
+	      lastrate / 1024.0 );
     tstr[ sizeof( tstr ) - 1 ] = '\0';
     filetext->setText(tstr);
     tw = filetext->getX() + filetext->getWidth() + window->getBorderWidth();
@@ -1019,13 +1024,14 @@ CopyOpWin::redraw()
     if(difftime2>0.0) {
       rate = (double)copied_bytes * 1000000.0 / difftime2;
     } else rate=0.0;
-    buf1[MakeLong2NiceStr(buf1,copied_bytes)]='\0';
+
+    MakeLong2NiceStr( copied_bytes, copied_bytes_str );
     if(slim==true) {
-      snprintf( tstr, sizeof( tstr ), "%s @ %.2f KB/s", buf1, rate / 1024.0 );
+      snprintf( tstr, sizeof( tstr ), "%s @ %.2f KB/s", copied_bytes_str.c_str(), rate / 1024.0 );
       tstr[ sizeof( tstr ) - 1 ] = '\0';
     } else {
-      buf2[MakeLong2NiceStr(buf2,bytes)]='\0';
-      snprintf( tstr, sizeof( tstr ), "%s / %s @ %.2f KB/s", buf1, buf2, rate / 1024.0 );
+      MakeLong2NiceStr( bytes, bytes_str );
+      snprintf( tstr, sizeof( tstr ), "%s / %s @ %.2f KB/s", copied_bytes_str.c_str(), bytes_str.c_str(), rate / 1024.0 );
       tstr[ sizeof( tstr ) - 1 ] = '\0';
     }
     
