@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: createsymlinkop.cc,v 1.25 2004/12/12 21:58:58 ralf Exp $ */
+/* $Id: createsymlinkop.cc,v 1.26 2005/05/15 15:54:04 ralf Exp $ */
 
 #include "createsymlinkop.h"
 #include "listermode.h"
@@ -217,11 +217,11 @@ CreateSymlinkOp::doconfigure(int mode)
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(36))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(36));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   Text *tt1 = (Text*)win->add( new Text( aguix, x, y, catalog.getLocaleCom( 36 ), 1 ) );
@@ -299,7 +299,7 @@ CreateSymlinkOp::doconfigure(int mode)
                 gcb->setState((gcb->getState()==1)?0:1);
                 break;
               case XK_Return:
-                if ( cb->hasFocus() == false ) {
+                if ( cb->getHasFocus() == false ) {
                   endmode=0;
                 }
                 break;
@@ -326,7 +326,6 @@ CreateSymlinkOp::doconfigure(int mode)
     }
   }
   
-  win->close();
   delete win;
 
   return endmode;
