@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: cursorops.cc,v 1.21 2004/12/12 21:57:38 ralf Exp $ */
+/* $Id: cursorops.cc,v 1.22 2005/05/15 15:54:12 ralf Exp $ */
 
 #include "cursorops.h"
 #include "listermode.h"
@@ -831,11 +831,11 @@ int EnterDirOp::configure()
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(18))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(18));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(317),1));
@@ -967,7 +967,6 @@ int EnterDirOp::configure()
     dir=dupstring(sg->getText());
   }
   
-  win->close();
   delete win;
 
   return endmode;
