@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: datei.cc,v 1.111 2005/03/29 20:38:34 ralf Exp $ */
+/* $Id: datei.cc,v 1.114 2005/07/13 19:44:03 ralf Exp $ */
 
 #include "datei.h"
 #include <aguix/lowlevelfunc.h>
@@ -87,12 +87,17 @@ int Datei::open( const char *name, const char *mode )
   return 0;
 }
 
-void Datei::close()
+int Datei::close()
 {
-  if ( fd < 0 ) return;
-  ::worker_close( fd );
+  int res = -1;
+
+  if ( fd < 0 ) return res;
+  res = ::worker_close( fd );
   fd = -1;
   iseof = false;
+
+  if ( res != 0 ) error++;
+  return res;
 }
 
 int Datei::putUChar(unsigned char value)
@@ -101,7 +106,6 @@ int Datei::putUChar(unsigned char value)
   int x;
   x = putCharacter( value );
   if(x!=EOF) return 1;
-  printf("fehler bei PutChar\n");
   return 0;
 }
 
@@ -183,7 +187,10 @@ int Datei::putString( const char *str1 )
   
   l = strlen( str1 );
   x = worker_write( fd, str1, l );
-  if ( x < 0 ) return -2;
+  if ( x < 0 ) {
+    error++;
+    return -2;
+  }
   return x;
 }
 
@@ -1115,12 +1122,7 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
             s1 = wconfig->getStringForDirSize();
             lv->setText( row, 2 * i, s1 );
           } else {
-            mlen = NiceLongSize( dissize );
-            str = (char*)_allocsafe( mlen + 1 );
-            MakeLong2NiceStr( str, dissize );
-            str[ mlen ] = '\0';
-            s1 = str;
-            _freesafe( str );
+	    MakeLong2NiceStr( dissize, s1 );
             lv->setText( row, 2 * i, s1 );
           }
         }
@@ -1200,17 +1202,17 @@ void FileEntry::setLVC( FieldListView *lv, int row, const std::vector<WorkerType
         break;
       case WorkerTypes::LISTCOL_INODE:
         li = (loff_t)statbuf.inode;
-        s1 = GetLong2Str( li );
+	MakeLong2NiceStr( li, s1, false );
         lv->setText( row, 2 * i, s1 );
         break;
       case WorkerTypes::LISTCOL_NLINK:
         li = (loff_t)statbuf.nlink;
-        s1 = GetLong2Str( li );
+	MakeLong2NiceStr( li, s1, false );
         lv->setText( row, 2 * i, s1 );
         break;
       case WorkerTypes::LISTCOL_BLOCKS:
         li = (loff_t)statbuf.blocks;
-        s1 = GetLong2Str( li );
+	MakeLong2NiceStr( li, s1, false );
         lv->setText( row, 2 * i, s1 );
         break;
       default:
@@ -2280,10 +2282,16 @@ int Datei::putLine( const char *str )
   
   l = strlen( str );
   x = worker_write( fd, str, l );
-  if ( x < 0 ) return -2;
+  if ( x < 0 ) {
+    error++;
+    return -2;
+  }
 
   y = worker_write( fd, "\n", 1 );
-  if ( y < 0 ) return -2;
+  if ( y < 0 ) {
+    error++;
+    return -2;
+  }
 
   return x + y;
 }
@@ -2746,7 +2754,10 @@ int Datei::putCharacter( int c )
   cf[0] = (unsigned char)c;
   
   count = worker_write( fd, cf, 1 );
-  if ( count < 1 ) return EOF;
+  if ( count < 1 ) {
+    error++;
+    return EOF;
+  }
   return cf[0];
 }
 
@@ -2831,8 +2842,11 @@ int Datei::copyfile( const char *dest, const char *source )
   } while ( ( readbytes > 0 ) &&
 	    ( cancel == false ) );
 
-  ::worker_close( fdw );
   ::worker_close( fdr );
+  if ( ::worker_close( fdw ) != 0 ) {
+    // error while closing -> incomplete copy
+    erg = 1;
+  }
   return erg;
 #undef BUFSIZE
 }
