@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: datei.h,v 1.58 2005/02/07 22:40:34 ralf Exp $ */
+/* $Id: datei.h,v 1.59 2005/07/13 19:43:27 ralf Exp $ */
 
 #ifndef DATEI_H
 #define DATEI_H
@@ -64,7 +64,7 @@ public:
   Datei &operator=( const Datei &other );
 
   int open( const char *name, const char *mode );
-  void close();
+  int close();
   int putUChar(unsigned char value);
   int putUShort(unsigned short int value);
   int putInt(int);
