@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: deleteop.cc,v 1.27 2004/12/12 21:57:24 ralf Exp $ */
+/* $Id: deleteop.cc,v 1.28 2005/05/15 15:54:18 ralf Exp $ */
 
 #include "listermode.h"
 #include "normalmode.h"
@@ -122,13 +122,14 @@ int DeleteOp::configure()
   int t1,t2;
   ChooseButton *cb;
   AGUIX *aguix = Worker::getAGUIX();
-  AWindow *win=new AWindow(aguix);
+  AWindow *win;
   char *tstr;
 
   w=h=10;
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(25))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(25));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
   
   ty=5;
@@ -186,7 +187,6 @@ int DeleteOp::configure()
   if(ende==1) {
     also_active = ( cb->getState() == 1 ) ? true : false;
   }
-  win->close();
   delete win;
   return (ende==1)?0:1;
 }
@@ -240,10 +240,10 @@ DeleteOpWin::open()
   Text *ttext;
 
   close();
-  window=new AWindow(aguix);
   w=400;
   h=10;
-  window->create(NULL,10,10,w,h,0,catalog.getLocaleCom(25));
+  window = new AWindow( aguix, 10, 10, w, h, 0, catalog.getLocaleCom( 25 ) );
+  window->create();
   tx=5;
   ty=5;
   sourcetext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
@@ -294,7 +294,6 @@ void
 DeleteOpWin::close()
 {
   if(window!=NULL) {
-    window->close();
     delete window;
   }
   window=NULL;
