@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: enterpathop.cc,v 1.13 2004/10/27 21:07:16 ralf Exp $ */
+/* $Id: enterpathop.cc,v 1.14 2005/05/15 15:54:39 ralf Exp $ */
 
 #include "enterpathop.h"
 #include "listermode.h"
@@ -154,11 +154,11 @@ EnterPathOp::configure()
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(34))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(34));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(323),1));
@@ -253,7 +253,6 @@ EnterPathOp::configure()
     }
   }
   
-  win->close();
   delete win;
 
   return endmode;
