@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: filereq.cc,v 1.18 2004/10/27 21:07:23 ralf Exp $ */
+/* $Id: filereq.cc,v 1.19 2005/05/15 15:54:50 ralf Exp $ */
 
 #include "filereq.h"
 #include "worker_locale.h"
@@ -68,8 +68,8 @@ int FileRequester::request( const char *title,
   if(w2>w) w=w2;
   int h=3*aguix->getCharHeight()+50+150;
 
-  AWindow *win=new AWindow(aguix);
-  win->create(NULL,10,10,w,h,0,title);
+  AWindow *win = new AWindow( aguix, 10, 10, w, h, 0, title );
+  win->create();
   win->setMinSize(w,h);
   int ty,dh;
   ty=5;
@@ -201,7 +201,6 @@ int FileRequester::request( const char *title,
     }
     endmode=1;
   }
-  win->close();
   delete win;
   delete verz;
   verz=NULL;
@@ -355,9 +354,9 @@ int FileRequester::request_entry( const char *title,
     }
   } else use_dir = dupstring( actdir );
 
-  win = new AWindow( aguix );
   w = h = 10;
-  win->create( NULL, 10, 10, w, h, 0, title );
+  win = new AWindow( aguix, 10, 10, w, h, 0, title );
+  win->create();
 
   ty=5;
   ttext = (Text*)win->add( new Text( aguix, 5, ty, infotext, 1 ) );
@@ -505,7 +504,7 @@ int FileRequester::request_entry( const char *title,
             switch ( msg->key.key ) {
               case XK_KP_Enter:
               case XK_Return:
-                if ( b[1]->hasFocus() == false ) {
+                if ( b[1]->getHasFocus() == false ) {
                   FR_RE_TESTOKAY;
                 }
                 break;
@@ -543,7 +542,6 @@ int FileRequester::request_entry( const char *title,
 #endif
   }
 
-  win->close();
   delete win;
   delete verz;
   verz = NULL;
