@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: informationmode.cc,v 1.34 2004/12/15 22:46:02 ralf Exp $ */
+/* $Id: informationmode.cc,v 1.35 2005/06/27 17:48:36 ralf Exp $ */
 
 #include "informationmode.h"
 #include "normalmode.h"
@@ -251,19 +251,17 @@ void InformationMode::showinfos()
                                                                     // but this is enough
        buffer3[10],
        rights[3][4],
-       *str;
-  char *mstr,*kstr,*tstr;
-  char *bstr1, *bstr2;
+       *tstr, *str;
+  char *bstr2;
   bool showno;
   loff_t size;
-  int size_size,ksize_size,msize_size;
   const char *cstr;
   size_t bufferlen;
+  std::string bytestr, kbytestr, mbytestr, numbufs, numbuff, bstr1;
   
   float percent;
   struct tm *timeptr;
   loff_t f1,s1;
-  char numbufs[A_BYTESFORNUMBER(loff_t)], numbuff[A_BYTESFORNUMBER(loff_t)];
   time_t tvar;
   char *istr;
   
@@ -281,34 +279,29 @@ void InformationMode::showinfos()
       else size=fe->size();
     } else size=fe->size();
 
-    size_size = NiceLongSize( size );
-    str=(char*)_allocsafe(size_size+1);
-    str[MakeLong2NiceStr(str,size)]='\0';
+    MakeLong2NiceStr( size, bytestr );
 
-    ksize_size = NiceLongSize( ( size + 512 ) / 1024 );
-    kstr = (char*)_allocsafe( ksize_size + 1 );
-    kstr[MakeLong2NiceStr(kstr,(size+512)/1024)]='\0';
+    MakeLong2NiceStr( ( size + 512 ) / 1024, kbytestr );
 
-    msize_size = NiceLongSize( ( size + 524288 ) / 1048576 );
-    mstr = (char*)_allocsafe( msize_size + 1 );
-    mstr[MakeLong2NiceStr(mstr,(size+524288)/1048576)]='\0';
+    MakeLong2NiceStr( ( size + 524288 ) / 1048576, mbytestr );
 
-    bstr1 = dupstring( GetLong2Str( fe->blocks() ) );
+    MakeLong2NiceStr( fe->blocks(), bstr1, false );
     bstr2 = (char*)_allocsafe( strlen( catalog.getLocale( 551 ) ) +
-                               strlen( bstr1 ) + 1 );
-    sprintf( bstr2, catalog.getLocale( 551 ), bstr1 );
-    _freesafe( bstr1 );
+                               bstr1.length() + 1 );
+    sprintf( bstr2, catalog.getLocale( 551 ), bstr1.c_str() );
     
-    tstr=(char*)_allocsafe(strlen("%s: %s B, %s KB, %s MB (%s)")+
-                          strlen(catalog.getLocale(177))+
-                          size_size+
-                          ksize_size+
-                          msize_size +
-                          strlen( bstr2 ) + 1);
-    sprintf(tstr,"%s: %s B, %s KB, %s MB (%s)",catalog.getLocale(177),str,kstr,mstr, bstr2);
-    _freesafe(str);
-    _freesafe(kstr);
-    _freesafe(mstr);
+    tstr = (char*)_allocsafe( strlen( "%s: %s B, %s KB, %s MB (%s)" ) +
+			      strlen( catalog.getLocale( 177 ) ) +
+			      bytestr.length() +
+			      kbytestr.length() +
+			      mbytestr.length() +
+			      strlen( bstr2 ) + 1 );
+    sprintf( tstr, "%s: %s B, %s KB, %s MB (%s)",
+	     catalog.getLocale( 177 ),
+	     bytestr.c_str(),
+	     kbytestr.c_str(),
+	     mbytestr.c_str(),
+	     bstr2 );
     _freesafe( bstr2 );
     lv->setText( 2, 0, tstr);
     _freesafe(tstr);
@@ -431,22 +424,20 @@ void InformationMode::showinfos()
     lv->setText( 11, 0, tstr);
     _freesafe(tstr);
 
-    bstr1 = dupstring( GetLong2Str( (loff_t)fe->inode() ) );
+    MakeLong2NiceStr( (loff_t)fe->inode(), bstr1, false );
     tstr = (char*)_allocsafe( strlen( "%s: %s" ) +
                               strlen( catalog.getLocale( 548 ) ) +
-                              strlen( bstr1 ) + 1 );
-    sprintf( tstr, "%s: %s", catalog.getLocale( 548 ), bstr1 );
+                              bstr1.length() + 1 );
+    sprintf( tstr, "%s: %s", catalog.getLocale( 548 ), bstr1.c_str() );
     lv->setText( 12, 0, tstr);
-    _freesafe( bstr1 );
     _freesafe( tstr );
 
-    bstr1 = dupstring( GetLong2Str( (loff_t)fe->nlink() ) );
+    MakeLong2NiceStr( (loff_t)fe->nlink(), bstr1, false );
     tstr = (char*)_allocsafe( strlen( "%s: %s" ) +
                               strlen( catalog.getLocale( 549 ) ) +
-                              strlen( bstr1 ) + 1 );
-    sprintf( tstr, "%s: %s", catalog.getLocale( 549 ), bstr1 );
+                              bstr1.length() + 1 );
+    sprintf( tstr, "%s: %s", catalog.getLocale( 549 ), bstr1.c_str() );
     lv->setText( 13, 0, tstr);
-    _freesafe( bstr1 );
     _freesafe( tstr );
 
     len = strlen( catalog.getLocale( 162 ) );
@@ -530,15 +521,15 @@ void InformationMode::showinfos()
       s1 = parentlister->getWorker()->PS_getSpaceH( &tstr );
       tstr=buffer2;
       f1 = parentlister->getWorker()->PS_getFreeSpaceH( &tstr );
-      numbufs[WriteLong2Str( numbufs, s1 )] = '\0';
-      numbuff[WriteLong2Str( numbuff, f1 )] = '\0';
+      MakeLong2NiceStr( s1, numbufs, false );
+      MakeLong2NiceStr( f1, numbuff, false );
 
       snprintf( buffer, sizeof( buffer ), "%s: %s %s (%2.0f %%) %s %s %s", catalog.getLocale( 187 ),
-                numbuff,
+                numbuff.c_str(),
                 buffer2,
                 percent,
                 catalog.getLocale( 188 ),
-                numbufs,
+                numbufs.c_str(),
                 buffer3 );
       buffer[ sizeof( buffer ) - 1 ] = '\0';
       nospaceinfo = false;
