@@ -1,6 +1,6 @@
 /* lister.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: lister.cc,v 1.28 2004/10/27 21:07:49 ralf Exp $ */
+/* $Id: lister.cc,v 1.29 2005/05/15 15:55:39 ralf Exp $ */
 
 #include "lister.h"
 #include "worker.h"
@@ -60,7 +60,6 @@ Lister::~Lister()
     delete modes[i];
   }
   delete [] modes;
-  win->close();
   delete win;
 }
 
@@ -216,8 +215,8 @@ void Lister::configure()
   const char *cstr;
   ChooseButton **cbs;
   Button **bs;
-  AWindow *win2=new AWindow(aguix);
-  win2->create(NULL,10,10,10,10,0,catalog.getLocale(16));
+  AWindow *win2 = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 16 ) );
+  win2->create();
   w2=0;
   h2=0;
   ty=5;
@@ -295,7 +294,7 @@ void Lister::configure()
         }
       } else if(msg->type==AG_KEYPRESSED) {
         if(msg->key.key==XK_Return) {
-          if ( cancelb->hasFocus() == false )
+          if ( cancelb->getHasFocus() == false )
             ende=1;
         } else if(msg->key.key==XK_Escape) {
           ende=-1;
@@ -336,7 +335,6 @@ void Lister::configure()
     }
     switch2Mode(j);
   }
-  win2->close();
   delete win2;
   _freesafe(cbs);
   _freesafe(bs);
