@@ -1,7 +1,7 @@
 /* nmrowdata.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
  * Copyright (C) 2003-2004 Ralf Hoffmann.
- * You can contact me at: ralf.hoffmann@epost.de
+ * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: nmrowdata.cc,v 1.2 2004/03/18 07:10:24 ralf Exp $ */
+/* $Id: nmrowdata.cc,v 1.4 2004/12/12 21:53:47 ralf Exp $ */
 
 #include "nmrowdata.h"
 #include <aguix/lowlevelfunc.h>
@@ -30,10 +30,14 @@ NMRowData::NMRowData() : FieldLVRowData()
   fullname = NULL;
 }
 
-NMRowData::NMRowData( int trow, FileEntry *tfe, const char *tfullname )
+NMRowData::NMRowData( int trow, const FileEntry *tfe, const char *tfullname )
 {
   row = trow;
-  fe = tfe;
+  if ( tfe != NULL ) {
+    fe = new FileEntry( *tfe );
+  } else {
+    fe = NULL;
+  }
   if ( tfullname != NULL ) {
     fullname = dupstring( tfullname );
   } else {
@@ -44,6 +48,7 @@ NMRowData::NMRowData( int trow, FileEntry *tfe, const char *tfullname )
 NMRowData::~NMRowData()
 {
   if ( fullname != NULL ) _freesafe( fullname );
+  if ( fe != NULL ) delete fe;
 }
 
 NMRowData *NMRowData::duplicate() const
@@ -54,15 +59,6 @@ NMRowData *NMRowData::duplicate() const
   return rd;
 }
 
-void NMRowData::update( int trow, FileEntry *tfe, const char *tfullname )
-{
-  row = trow;
-  fe = tfe;
-  if ( fullname != NULL ) _freesafe( fullname );
-  if ( tfullname != NULL ) fullname = dupstring( tfullname );
-  else fullname = NULL;
-}
-
 int NMRowData::getRow() const
 {
   return row;
