@@ -1,7 +1,7 @@
 /* nmrowdata.h
  * This file belongs to Worker, a filemanager for UNIX/X11.
  * Copyright (C) 2003-2004 Ralf Hoffmann.
- * You can contact me at: ralf.hoffmann@epost.de
+ * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: nmrowdata.h,v 1.2 2004/03/18 20:18:18 ralf Exp $ */
+/* $Id: nmrowdata.h,v 1.4 2004/12/12 21:53:36 ralf Exp $ */
 
 #ifndef NMROWDATA_H
 #define NMROWDATA_H
@@ -31,13 +31,12 @@ class NMRowData : public FieldLVRowData
 {
 public:
   NMRowData();
-  NMRowData( int trow, FileEntry *tfe, const char *tfullname );
+  NMRowData( int trow, const FileEntry *tfe, const char *tfullname );
   ~NMRowData();
   NMRowData( const NMRowData &other );
   NMRowData &operator=( const NMRowData &other );
 
   NMRowData *duplicate() const;
-  void update( int trow, FileEntry *tfe, const char *tfullname );
   int getRow() const;
   const FileEntry *getFE() const;
   const char *getFullname() const;
