@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: normalmode.h,v 1.100 2005/03/23 21:52:40 ralf Exp $ */
+/* $Id: normalmode.h,v 1.106 2005/07/12 19:11:30 ralf Exp $ */
 
 #ifndef NORMALMODE_H
 #define NORMALMODE_H
@@ -200,19 +200,6 @@ public:
   bool dontcd;
 };
 
-struct NM_startprogorder {
-  const FileEntry *usefe;
-  bool global;
-  bool inbackground;
-  enum {NM_START_NORMAL=0,
-        NM_START_IN_TERMINAL,
-        NM_START_IN_TERMINAL_AND_WAIT4KEY,
-        NM_SHOW_OUTPUT} start;
-
-  char *view_str;
-  bool dontcd;
-};
-
 struct NM_renameorder {
   enum {NM_ALLENTRIES,NM_ONLYACTIVE,NM_SPECIAL} source;
   std::list<NM_specialsourceExt*> *sources;
@@ -343,7 +330,6 @@ public:
   void renamef(struct NM_renameorder *renorder);
   void dirsize(struct NM_dirsizeorder *dsorder);
   void simdd();
-  void startprog(struct NM_startprogorder *sporder);
   void searchentry();
   void searchentry( bool ignore_case );
   void enterpath();
@@ -362,11 +348,11 @@ public:
                 NM_GETFILES_ONLYSELECT,
                 NM_GETFILES_SELORACT} nm_getfiles_t;
   int getSelFiles( std::list<NM_specialsourceExt*>*, nm_getfiles_t, bool unselect = false );
-  void freeSelFiles( std::list<NM_specialsourceExt*>* ) const;
+  static void freeSelFiles( std::list<NM_specialsourceExt*>* );
   int getDirSize( FileEntry *fe, loff_t &return_size );
 
   virtual bool startdnd(DNDMsg *dm);
-  virtual bool isyours(GUIElement *elem);
+  virtual bool isyours( Widget *elem );
 
   FileEntry *getFE4DNDSTART( const AGDNDSTART *st );
   void setSortmode(int nmode);
@@ -380,7 +366,7 @@ public:
 #endif
   int createExtList( bool rec, List *extlist );
   static void freeExtList( List *extlist );
-  char *parseComStrExt(char *sstr,class NM_externorder *extorder,int maxlen, NMExtList *entries[2], bool quote);
+  char *parseComStrExt( const char *sstr,class NM_externorder *extorder,int maxlen, NMExtList *entries[2], bool quote);
   /* deselect for extern access, check for existance of fe => slow for big dirs */
   void deselect( const FileEntry *fe );
   int createExtList( ActionMessage *amsg, bool rec, List *extlist );
@@ -532,7 +518,7 @@ protected:
                           bool rec,
                           const FileEntry *fe,
                           int row ) const;
-  char *parseComStr(char *sstr,class NM_externorder *extorder,int maxlen, NMExtList *entries[2], bool quote );
+  char *parseComStr( const char *sstr,class NM_externorder *extorder,int maxlen, NMExtList *entries[2], bool quote );
   void deselect( FileEntry *fe, int row );
   char *StringRequest(char *sstr,class NM_externorder *extorder,int maxlen, NMExtList *entries[2]);
   void startsearchmode();
@@ -575,11 +561,6 @@ protected:
   void setUpdatetime(int nv);
   void setSSHAllow( enum ssh_allow_t nv );
   
-  int runCommand( const char*exestr,
-                  const char *tmpname,
-                  const char *tmpoutput,
-                  bool inbackground );
-  
   static int maxfilestrlen,maxdirstrlen,maxbytesstrlen,maxwbytesstrlen,maxnochanges;
   
 #ifdef WANT_THREADS
@@ -771,6 +752,38 @@ protected:
   WCFiletype *findFiletype( std::vector<unsigned int> *v );
   int getSelFiles( std::list<NM_specialsourceInt*> *, nm_getfiles_t, bool unselect );
   FileEntry *findFE( const FileEntry *tfe );
+
+  class Requests
+  {
+  public:
+    Requests();
+    ~Requests();
+    Requests( const Requests &other );
+    Requests &operator=( const Requests &other );
+    typedef enum { SKIP_CANCEL,
+		   NO_SPACE_LEFT,
+		   WRITE_ERROR } request_t;
+    typedef enum { OKAY, SKIP, CANCEL, REQUEST_ERROR } request_choose_t;
+    request_choose_t request( request_t type, AWindow *win, std::string text );
+    request_choose_t request( request_t type, AWindow *win, const char *format, const char *str2, int error_number );
+    request_choose_t request_va( request_t type, AWindow *win, const char *format, ... );
+  private:
+    std::map<request_t, std::list<request_choose_t> > request_chooses;
+    std::map<request_choose_t, std::string> choose_strings;
+  };
+  Requests requests;
+  std::string formatStringToString( const char *format, ... );
+
+  typedef enum { REG_COPY_OK, REG_COPY_SKIP, REG_COPY_CANCEL, REG_COPY_ERROR } reg_copy_erg_t;
+  
+  reg_copy_erg_t copyfile_reg( const char *sourcename,
+			       const char *destname,
+			       const char *destdirname,
+			       const char *destbasename,
+			       mode_t create_mode,
+			       CopyOpWin *cowin,
+			       loff_t bytesToCopy );
+  bool checkForEmptyActionList( WCFiletype *ft );
 };
 
 class NMFieldListViewDND:public FieldListViewDND
