@@ -1,6 +1,6 @@
 /* normalops.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: normalops.cc,v 1.21 2004/10/27 21:08:13 ralf Exp $ */
+/* $Id: normalops.cc,v 1.22 2005/05/15 15:57:05 ralf Exp $ */
 
 #include "normalops.h"
 #include "listermode.h"
@@ -97,11 +97,11 @@ int ChangeListerSetOp::configure()
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(19))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(19));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(348),1));
@@ -197,7 +197,6 @@ int ChangeListerSetOp::configure()
     }
   }
   
-  win->close();
   delete win;
 
   return endmode;
@@ -379,13 +378,14 @@ int FilterSelectOp::configure()
   int t1,t2;
   StringGadget *sg;
   AGUIX *aguix = Worker::getAGUIX();
-  AWindow *win=new AWindow(aguix);
+  AWindow *win;
   char *tstr;
 
   w=h=10;
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(21))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(21));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
   
   ty=5;
@@ -449,7 +449,6 @@ int FilterSelectOp::configure()
     _freesafe(filter);
     filter=dupstring(sg->getText());
   }
-  win->close();
   delete win;
   return (ende==1)?0:1;
 }
@@ -472,7 +471,7 @@ bool FilterSelectOp::requestfilter()
   StringGadget *sg;
   FieldListView *lv;
   AGUIX *aguix = Worker::getAGUIX();
-  AWindow *win=new AWindow(aguix);
+  AWindow *win;
   int id, row;
   char *tstr;
   bool lvstill;
@@ -480,7 +479,8 @@ bool FilterSelectOp::requestfilter()
   GUIElement *bs[2];
 
   w = h = 10;
-  win->create( NULL, 10, 10, w, h, 0, catalog.getLocale( 268 ) );
+  win = new AWindow( aguix, 10, 10, w, h, 0, catalog.getLocale( 268 ) );
+  win->create();
   ty=5;
   Text *tt1=(Text*)win->add(new Text(aguix,5,ty,catalog.getLocale(270),1));
   tw=tt1->getWidth()+10;
@@ -598,7 +598,7 @@ bool FilterSelectOp::requestfilter()
             lvstill = false;
             break;
           case XK_Down:
-            if ( lv->hasFocus() == true ) {
+            if ( lv->getHasFocus() == true ) {
               if ( ( lv->getActiveRow() == ( lv->getElements() - 1 ) ) &&
                  ( lvstill == true ) ) {
                 lv->setActiveRow( -1 );
@@ -610,7 +610,7 @@ bool FilterSelectOp::requestfilter()
             ende = -1;
             break;
           case XK_Return:
-            if ( cancelb->hasFocus() == false )
+            if ( cancelb->getHasFocus() == false )
               ende = 1;
             break;
           }
@@ -646,7 +646,6 @@ bool FilterSelectOp::requestfilter()
   }
   lastw = win->getWidth();
   lasth = win->getHeight();
-  win->close();
   delete win;
   return (ende==1?true:false);
 }
@@ -817,13 +816,14 @@ int FilterUnSelectOp::configure()
   int t1,t2;
   StringGadget *sg;
   AGUIX *aguix = Worker::getAGUIX();
-  AWindow *win=new AWindow(aguix);
+  AWindow *win;
   char *tstr;
 
   w=h=10;
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(22))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(22));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
   
   ty=5;
@@ -887,7 +887,6 @@ int FilterUnSelectOp::configure()
     _freesafe(filter);
     filter=dupstring(sg->getText());
   }
-  win->close();
   delete win;
   return (ende==1)?0:1;
 }
@@ -903,13 +902,14 @@ bool FilterUnSelectOp::requestfilter()
   StringGadget *sg;
   FieldListView *lv;
   AGUIX *aguix = Worker::getAGUIX();
-  AWindow *win=new AWindow(aguix);
+  AWindow *win;
   int id, row;
   char *tstr;
   bool lvstill;
   int lastrow;
 
-  win->create(NULL,10,10,10,10,0,catalog.getLocale(269));
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 269 ) );
+  win->create();
   w=0;
   h=0;
   ty=5;
@@ -1018,7 +1018,7 @@ bool FilterUnSelectOp::requestfilter()
             lvstill = false;
             break;
           case XK_Down:
-            if ( lv->hasFocus() == true ) {
+            if ( lv->getHasFocus() == true ) {
               if ( ( lv->getActiveRow() == ( lv->getElements() - 1 ) ) &&
                  ( lvstill == true ) ) {
                 lv->setActiveRow( -1 );
@@ -1030,7 +1030,7 @@ bool FilterUnSelectOp::requestfilter()
             ende = -1;
             break;
           case XK_Return:
-            if ( cancelb->hasFocus() == false )
+            if ( cancelb->getHasFocus() == false )
               ende = 1;
             break;
           }
@@ -1055,7 +1055,6 @@ bool FilterUnSelectOp::requestfilter()
     actual_filter=dupstring(sg->getText());
     addHistoryItem( actual_filter );
   }
-  win->close();
   delete win;
   return (ende==1?true:false);
 }
@@ -1196,11 +1195,11 @@ int QuitOp::configure()
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(24))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(24));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(350),1));
@@ -1282,7 +1281,6 @@ int QuitOp::configure()
     }
   }
   
-  win->close();
   delete win;
 
   return endmode;
