@@ -1,6 +1,6 @@
 /* ownop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: ownop.cc,v 1.33 2005/02/07 07:09:35 ralf Exp $ */
+/* $Id: ownop.cc,v 1.35 2005/05/19 19:53:01 ralf Exp $ */
 
 #include "ownop.h"
 #include "listermode.h"
@@ -249,11 +249,11 @@ OwnOp::configure()
   freq = new FileRequester( aguix );
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(28))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(28));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   scb=(ChooseButton*)win->add(new ChooseButton(aguix,x,y,(separate_each_entry==true)?1:0,
@@ -522,7 +522,6 @@ OwnOp::configure()
     }
   }
   
-  win->close();
   delete win;
   delete req;
   delete freq;
@@ -537,30 +536,37 @@ OwnOp::getFlag()
   Button *okb,*cb;
   AWindow *win;
   FieldListView *lv;
-  Text *ttext;
-  int tw,w,h,x,y,t1,t2;
   AGMessage *msg;
   int endmode=-1;
   char *returnstr;
-  Button *b2[2];
   int i, trow, nr;
+  const int cmin = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW;
+  const int cincw = AContainer::ACONT_MINH +
+                    AContainer::ACONT_MINW +
+                    AContainer::ACONT_MAXH;
+  const int cincwnr = cincw +
+                      AContainer::ACONT_NORESIZE;
+  const int cfix = AContainer::ACONT_MINH +
+                   AContainer::ACONT_MINW +
+                   AContainer::ACONT_MAXH +
+                   AContainer::ACONT_MAXW;
   
-  w=400;
-  h=300;
-  x=y=5;
-  win=new AWindow(aguix);
-  win->create(NULL,10,10,w,h,0,catalog.getLocale(338));
+  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 338 ) );
+  win->create();
 
-  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(338),1));
-  y+=ttext->getHeight()+5;
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+  ac1->setMinSpace( 5 );
+  ac1->setMaxSpace( 5 );
 
-  lv = (FieldListView*)win->add( new FieldListView( aguix,
-                                                    x,
-                                                    y,
-                                                    w - 2 * x,
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 338 ), 1 ), 0, 0, cincwnr );
+
+  lv = (FieldListView*)ac1->add( new FieldListView( aguix,
+                                                    0,
+                                                    0,
+                                                    300,
                                                     200,
-                                                    0 ) );
-  y+=lv->getHeight()+5;
+                                                    0 ), 0, 1, cmin );
   lv->setHBarState(2);
   lv->setVBarState(2);
 
@@ -577,39 +583,28 @@ OwnOp::getFlag()
     lv->setData( trow, i );
   }
 
-  t1=(strlen(catalog.getLocale(11))+2);
-  t1*=aguix->getCharWidth();
-  t2=(strlen(catalog.getLocale(8))+2);
-  t2*=aguix->getCharWidth();
-  tw=5+t1+5+t2+5;
-  if(tw>w) w=tw;
-  okb=(Button*)win->add(new Button(aguix,
-                                   5,
-                                   y,
-                                   t1,
-                                   catalog.getLocale(11),
-                                   1,
-                                   0,
-                                   0));
-  cb=(Button*)win->add(new Button(aguix,
-                                  w-5-t2,
-                                  y,
-                                  t2,
-                                  catalog.getLocale(8),
-                                  1,
-                                  0,
-                                  0));
-  y+=okb->getHeight()+5;
-
-  b2[0] = okb;
-  b2[1] = cb;
-  
-  h=y;
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
+  ac1_2->setMinSpace( 5 );
+  ac1_2->setMaxSpace( -1 );
+  ac1_2->setBorderWidth( 0 );
+  okb = (Button*)ac1_2->add( new Button( aguix,
+					 0,
+					 0,
+					 catalog.getLocale( 11 ),
+					 1,
+					 0,
+					 0 ), 0, 0, cfix );
+  cb = (Button*)ac1_2->add( new Button( aguix,
+					0,
+					0,
+					catalog.getLocale( 8 ),
+					1,
+					0,
+					0 ), 1, 0, cfix );
+  win->contMaximize( true );
   win->setDoTabCycling( true );
-  win->resize(w,h);
-  //win->setMaxSize(w,h);
-  win->setMinSize(w,h);
   win->show();
+  
   for(;endmode==-1;) {
     msg=aguix->WaitMessage(win);
     if(msg!=NULL) {
@@ -621,13 +616,6 @@ OwnOp::getFlag()
           if(msg->button.button==okb) endmode=0;
           else if(msg->button.button==cb) endmode=1;
           break;
-        case AG_SIZECHANGED:
-          AGUIX::scaleElementsW( msg->size.neww, 5, 10, -1, false, false, (GUIElement**)b2, NULL, 2 );
-          for ( i = 0; i < 2; i++ ) {
-            b2[i]->move( b2[i]->getX(), msg->size.newh - 5 - b2[i]->getHeight() );
-          }
-          lv->resize( msg->size.neww - 10, b2[0]->getY() - 5 - lv->getY() );
-          break;
       }
       aguix->ReplyMessage(msg);
     }
@@ -643,7 +631,6 @@ OwnOp::getFlag()
     }
   }
   
-  win->close();
   delete win;
 
   return returnstr;
