@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: ownop.h,v 1.20 2005/02/07 22:50:08 ralf Exp $ */
+/* $Id: ownop.h,v 1.21 2005/05/19 19:53:18 ralf Exp $ */
 
 #ifndef OWNOP_H
 #define OWNOP_H
@@ -116,7 +116,7 @@ public:
   void setInBackground( bool );
   void setTakeDirs( bool );
   void setDontCD( bool );
-  char *getFlag();
+  static char *getFlag();
   static const char *name;
 protected:
   // Infos to save
