@@ -1,6 +1,6 @@
 /* partspace.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: partspace.cc,v 1.11 2004/10/27 21:08:25 ralf Exp $ */
+/* $Id: partspace.cc,v 1.15 2005/02/09 21:46:19 ralf Exp $ */
 
 #include "partspace.h"
 
@@ -50,7 +50,7 @@ PartSpace::PartSpace()
   thread_usage = false;
 #endif
   info_lifetime = 10.0;  // force update after this time
-  info_maxlifetime = 30.0;  // remove entries after this time
+  spaceinfo_maxsize = 100;
 }
 
 PartSpace::~PartSpace()
@@ -98,7 +98,7 @@ PartSpace::~PartSpace()
 // 1.1.Wenn ja, alle entnehmen und in spaceinfo einfgen
 //     alte dabei loeschen
 //     falls error == 0
-// 2.Prfen, ob Elemente viel zu alt (mit maxlifetime)
+// 2.Prfen, ob Elemente viel zu alt (mit lifetime)
 // 2.1.Wenn ja, dann ber Liste gehen
 //     Fr alle zu alten:
 //       Entferne Eintrag aus liste
@@ -118,6 +118,12 @@ int PartSpace::readSpace( const char* name )
   time_t ct;
   int id;
   bool do_update = false;
+  worker_struct_stat buf1;
+  dev_t name_device;
+
+  if ( name == NULL ) return EFAULT;
+  if ( worker_stat( name, &buf1 ) != 0 ) return EFAULT;
+  name_device = buf1.st_dev;
 
   ct = time( NULL );
   if ( thread_usage == true ) {
@@ -125,14 +131,17 @@ int PartSpace::readSpace( const char* name )
     while ( spaceanswer->isEmpty_locked() == false ) {
       te = spaceanswer->remove_locked();
       if ( te != NULL ) {
-        if ( te->error == 0 ) {
+        if ( /*te->error*/ 0 == 0 ) {
           // valid
+	  // currently I accept even invalid entries as the VFS
+	  // doesn't support statvfs but I don't want to
+	  // start asking again and again
 
           // search for the same and remove it
           id = spaceinfo->initEnum();
           searchte = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement( id );
           while ( searchte != NULL ) {
-            if ( strcmp( searchte->name, te->name ) == 0 ) {
+            if ( searchte->device == te->device ) {
               spaceinfo->removeElement( searchte);
               _freesafe( searchte->name );
               delete searchte;
@@ -154,23 +163,21 @@ int PartSpace::readSpace( const char* name )
     
     id = spaceinfo->initEnum();
   
-    // remove all entries older then maxlifetime so the spaceinfo list
-    // doesn't gets to big
-    te = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement( id );
-    while ( te != NULL ) {
-      if ( difftime( ct, te->readtime ) > info_maxlifetime ) {
-        // too old
-        spaceinfo->removeFirstElement();
-       _freesafe( te->name );
-        delete te;
-      } else break;
-      te = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement( id );
+    // remove oldest entries if there are too many entries
+    if ( spaceinfo_maxsize > 0 ) {
+      while( spaceinfo->size() > spaceinfo_maxsize ) {
+	te = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement( id );
+	if ( te == NULL ) break;
+	spaceinfo->removeFirstElement();
+	_freesafe( te->name );
+	delete te;
+      }
     }
 
     // find name
     te = (SpaceRequestList::space_request_list_t*)spaceinfo->getFirstElement( id );
     while ( te != NULL ) {
-      if ( strcmp( name, te->name ) == 0 ) {
+      if ( name_device == te->device ) {
         // entry found
         break;
       }
@@ -179,21 +186,26 @@ int PartSpace::readSpace( const char* name )
     spaceinfo->closeEnum( id );
   } else te = NULL;
   
+  blocksize = 0;
+  space = 0;
+  freespace = 0;
   if ( te != NULL ) {
     // found
+    if ( te->error == 0 ) {
 #ifdef HAVE_STATVFS
-    blocksize = te->fsstatistic.f_frsize;
-    space = te->fsstatistic.f_blocks;
-    freespace = te->fsstatistic.f_bavail;
+      blocksize = te->fsstatistic.f_frsize;
+      space = te->fsstatistic.f_blocks;
+      freespace = te->fsstatistic.f_bavail;
 #elif defined( HAVE_STATFS )
-    blocksize = te->fsstatistic.f_bsize;
-    space = te->fsstatistic.f_blocks;
-    freespace = te->fsstatistic.f_bavail;
+      blocksize = te->fsstatistic.f_bsize;
+      space = te->fsstatistic.f_blocks;
+      freespace = te->fsstatistic.f_bavail;
 #else
-    blocksize = 0;
-    space = 0;
-    freespace = 0;
+      blocksize = 0;
+      space = 0;
+      freespace = 0;
 #endif
+    }
     // check if this is too old
     if ( difftime( ct, te->readtime ) > info_lifetime ) {
       do_update = true;
@@ -206,6 +218,7 @@ int PartSpace::readSpace( const char* name )
       // when using thread put a request in the list
       te = new SpaceRequestList::space_request_list_t;
       te->name = dupstring( name );
+      te->device = name_device;
       spacerequest->lock();
       spacerequest->put_locked( te );
       spacerequest->signal();
@@ -492,11 +505,5 @@ void PartSpace::setLifetime( double t )
   // at least one second is minimum
   if ( t < 1.0 ) return;
   
-  // do not take this value but do the following
-  // lifetime is minimum of all previous values
-  // maxlifetime is maximum of all previous values
-  
-  if ( t < info_lifetime ) info_lifetime = t;
-  if ( t > info_maxlifetime ) info_maxlifetime = t;
+  info_lifetime = t;
 }
-
