@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: reloadop.cc,v 1.18 2004/12/12 21:46:17 ralf Exp $ */
+/* $Id: reloadop.cc,v 1.19 2005/05/15 20:54:58 ralf Exp $ */
 
 #include "reloadop.h"
 #include "listermode.h"
@@ -167,11 +167,11 @@ ReloadOp::configure()
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(26))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(26));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(339),1));
@@ -286,7 +286,6 @@ ReloadOp::configure()
     keep_filetypes = ( kftcb->getState() == 1 ) ? true : false;
   }
   
-  win->close();
   delete win;
 
   return endmode;
