@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: scriptop.cc,v 1.16 2004/10/27 21:08:38 ralf Exp $ */
+/* $Id: scriptop.cc,v 1.18 2005/05/15 21:20:49 ralf Exp $ */
 
 #include "scriptop.h"
 #include "listermode.h"
@@ -537,11 +537,11 @@ int ScriptOp::configure()
   
   ttw=tth=10;
   ttx=tty=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getName())+1);
   sprintf(tstr,catalog.getLocale(293),getName());
-  win->create(NULL,10,10,ttw,tth,0,tstr);
+  win = new AWindow( aguix, 10, 10, ttw, tth, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   ttext = (Text*)win->add( new Text( aguix, ttx, tty, catalog.getLocale( 461 ), 1 ) );
@@ -597,8 +597,9 @@ int ScriptOp::configure()
   if(tw>ttw) ttw=tw;
   ttx=5;
 
-  push_win = new AWindow( aguix );
-  push_win->create( win, ttx, tty, 10, 10, 0, "" );
+  push_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
+  win->add( push_win );
+  push_win->create();
   push_win->setBorderWidth( 0 );
   lx = 0;
   ly = 0;
@@ -660,8 +661,9 @@ int ScriptOp::configure()
   push_win->maximizeX();
   push_win->maximizeY();
   
-  pop_win = new AWindow( aguix );
-  pop_win->create( win, ttx, tty, 10, 10, 0, "" );
+  pop_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
+  win->add( pop_win );
+  pop_win->create();
   pop_win->setBorderWidth( 0 );
   lx = 0;
   ly = 0;
@@ -684,8 +686,9 @@ int ScriptOp::configure()
   pop_win->maximizeX();
   pop_win->maximizeY();
   
-  label_win = new AWindow( aguix );
-  label_win->create( win, ttx, tty, 10, 10, 0, "" );
+  label_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
+  win->add( label_win );
+  label_win->create();
   label_win->setBorderWidth( 0 );
   lx = 0;
   ly = 0;
@@ -703,8 +706,9 @@ int ScriptOp::configure()
   label_win->maximizeX();
   label_win->maximizeY();
   
-  nop_win = new AWindow( aguix );
-  nop_win->create( win, ttx, tty, 10, 10, 0, "" );
+  nop_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
+  win->add( nop_win );
+  nop_win->create();
   nop_win->setBorderWidth( 0 );
   lx = 0;
   ly = 0;
@@ -712,8 +716,9 @@ int ScriptOp::configure()
   nop_win->maximizeX();
   nop_win->maximizeY();
   
-  end_win = new AWindow( aguix );
-  end_win->create( win, ttx, tty, 10, 10, 0, "" );
+  end_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
+  win->add( end_win );
+  end_win->create();
   end_win->setBorderWidth( 0 );
   lx = 0;
   ly = 0;
@@ -721,8 +726,9 @@ int ScriptOp::configure()
   end_win->maximizeX();
   end_win->maximizeY();
   
-  if_win = new AWindow( aguix );
-  if_win->create( win, ttx, tty, 10, 10, 0, "" );
+  if_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
+  win->add( if_win );
+  if_win->create();
   if_win->setBorderWidth( 0 );
   lx = 0;
   ly = 0;
@@ -781,8 +787,9 @@ int ScriptOp::configure()
   if_win->maximizeX();
   if_win->maximizeY();
   
-  set_win = new AWindow( aguix );
-  set_win->create( win, ttx, tty, 10, 10, 0, "" );
+  set_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
+  win->add( set_win );
+  set_win->create();
   set_win->setBorderWidth( 0 );
   lx = 0;
   ly = 0;
@@ -810,8 +817,9 @@ int ScriptOp::configure()
   set_win->maximizeX();
   set_win->maximizeY();
   
-  win_win = new AWindow( aguix );
-  win_win->create( win, ttx, tty, 10, 10, 0, "" );
+  win_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
+  win->add( win_win );
+  win_win->create();
   win_win->setBorderWidth( 0 );
   lx = 0;
   ly = 0;
@@ -917,8 +925,9 @@ int ScriptOp::configure()
   win_win->maximizeX();
   win_win->maximizeY();
   
-  goto_win = new AWindow( aguix );
-  goto_win->create( win, ttx, tty, 10, 10, 0, "" );
+  goto_win = new AWindow( aguix, ttx, tty, 10, 10, 0, "" );
+  win->add( goto_win );
+  goto_win->create();
   goto_win->setBorderWidth( 0 );
   lx = 0;
   ly = 0;
@@ -1166,7 +1175,6 @@ int ScriptOp::configure()
         break;
     }
   }
-  win->close();
   delete win;
 
   return endmode;
@@ -1274,8 +1282,8 @@ char *ScriptOp::getIfFlag()
   w=400;
   h=300;
   x=y=5;
-  win=new AWindow(aguix);
-  win->create(NULL,10,10,w,h,0,catalog.getLocale(338));
+  win = new AWindow( aguix, 10, 10, w, h, 0, catalog.getLocale( 338 ) );
+  win->create();
 
   win->addTextFromString( catalog.getLocale( 481 ), x, y, 5, NULL, NULL, &y );
   y += 5;
@@ -1374,7 +1382,6 @@ char *ScriptOp::getIfFlag()
     }
   }
   
-  win->close();
   delete win;
 
   return returnstr;
