@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: scrolllisterop.cc,v 1.13 2004/10/27 21:08:51 ralf Exp $ */
+/* $Id: scrolllisterop.cc,v 1.14 2005/05/15 20:55:28 ralf Exp $ */
 
 #include "scrolllisterop.h"
 #include "listermode.h"
@@ -129,11 +129,11 @@ ScrollListerOp::configure()
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(35))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(35));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win =new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(340),1));
@@ -214,7 +214,6 @@ ScrollListerOp::configure()
     }
   }
   
-  win->close();
   delete win;
 
   return endmode;
