@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: searchentryop.cc,v 1.9 2004/10/27 21:08:56 ralf Exp $ */
+/* $Id: searchentryop.cc,v 1.10 2005/05/15 20:55:34 ralf Exp $ */
 
 #include "searchentryop.h"
 #include "listermode.h"
@@ -114,7 +114,7 @@ int SearchEntryOp::configure()
   int w, h, tw, ty, tx;
   ChooseButton *cb;
   AGUIX *aguix = Worker::getAGUIX();
-  AWindow *win = new AWindow( aguix );
+  AWindow *win;
   char *tstr;
   GUIElement *b[2];
   int ende = 0;
@@ -122,7 +122,8 @@ int SearchEntryOp::configure()
   w = h = 10;
   tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( getDescription() ) + 1 );
   sprintf( tstr, catalog.getLocale( 293 ), getDescription() );
-  win->create( NULL, 10, 10, w, h, 0, tstr );
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe( tstr );
   
   ty = 5;
@@ -175,7 +176,6 @@ int SearchEntryOp::configure()
   if ( ende == 1 ) {
     ignore_case = ( cb->getState() == 1 ) ? true : false;
   }
-  win->close();
   delete win;
   return ( ende == 1 ) ? 0 : 1;
 }
