@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: setfilterop.cc,v 1.17 2004/10/27 21:09:00 ralf Exp $ */
+/* $Id: setfilterop.cc,v 1.18 2005/05/15 20:55:47 ralf Exp $ */
 
 #include "setfilterop.h"
 #include "listermode.h"
@@ -198,10 +198,10 @@ SetFilterOp::doconfigure(int mode)
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
   sprintf(tstr,catalog.getLocale(293),getDescription());
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   ttext = (Text*)win->add( new Text( aguix, x, y, getDescription(), 1 ) );
@@ -343,7 +343,7 @@ SetFilterOp::doconfigure(int mode)
                 if(rfcb!=NULL) rfcb->setState((rfcb->getState()==1)?0:1);
                 break;
               case XK_Return:
-                if ( cb->hasFocus() == false ) {
+                if ( cb->getHasFocus() == false ) {
                   endmode=0;
                 }
                 break;
@@ -367,7 +367,7 @@ SetFilterOp::doconfigure(int mode)
                 break;
               case XK_Down:
                 if ( lv != NULL ) {
-                  if ( lv->hasFocus() == true ) {
+                  if ( lv->getHasFocus() == true ) {
                     if ( ( lv->getActiveRow() == ( lv->getElements() - 1 ) ) &&
                        ( lvstill == true ) ) {
                       lv->setActiveRow( -1 );
@@ -441,7 +441,6 @@ SetFilterOp::doconfigure(int mode)
     }
   }
   
-  win->close();
   delete win;
 
   return endmode;
