@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: setsortmodeop.cc,v 1.13 2004/10/27 21:09:03 ralf Exp $ */
+/* $Id: setsortmodeop.cc,v 1.14 2005/05/15 20:55:52 ralf Exp $ */
 
 #include "setsortmodeop.h"
 #include "listermode.h"
@@ -136,11 +136,11 @@ int SetSortmodeOp::configure()
   
   ttw=tth=10;
   ttx=tty=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getName())+1);
   sprintf(tstr,catalog.getLocale(293),getName());
-  win->create(NULL,10,10,ttw,tth,0,tstr);
+  win = new AWindow( aguix, 10, 10, ttw, tth, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   ttext=(Text*)win->add(new Text(aguix,ttx,tty,catalog.getLocale(158),1));
@@ -284,7 +284,6 @@ int SetSortmodeOp::configure()
     }
     mode=tsortmode;
   }
-  win->close();
   delete win;
 
   return endmode;
