@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: showimagemode.cc,v 1.18 2004/12/12 21:28:29 ralf Exp $ */
+/* $Id: showimagemode.cc,v 1.19 2005/05/15 20:55:58 ralf Exp $ */
 
 #include "showimagemode.h"
 #include "normalmode.h"
@@ -70,8 +70,9 @@ void ShowImageMode::on()
 
   if ( w < 10 ) w = 10;
   if ( h < 10 ) h = 10;
-  imgwin=new AWindow(aguix);
-  imgwin->create(parentawindow,x,y,w,h,0,"");
+  imgwin = new AWindow( aguix, x, y, w, h, 0, "" );
+  parentawindow->add( imgwin );
+  imgwin->create();
   imgwin->show();
   
   parentlister->setActiveMode(this);
@@ -82,7 +83,6 @@ void ShowImageMode::off()
 {
   parentlister->setActiveMode(NULL);
   parentlister->setName("");
-  imgwin->close();
   delete imgwin;
   imgwin=NULL;
   clearLastActiveFE();
@@ -143,11 +143,11 @@ int ShowImageMode::configure()
   
   ttw=tth=10;
   ttx=tty=5;
-  win=new AWindow(aguix);
 
   tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( getLocaleName() ) + 1 );
   sprintf( tstr, catalog.getLocale( 293 ), getLocaleName() );
-  win->create(NULL,10,10,ttw,tth,0,tstr);
+  win = new AWindow( aguix, 10, 10, ttw, tth, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   lines=createLines(catalog.getLocale(521),&liness);
@@ -231,7 +231,6 @@ int ShowImageMode::configure()
     show_program=dupstring(sg->getText());
   }
   
-  win->close();
   delete win;
 
   for(i=0;i<lines;i++) _freesafe(liness[i]);
@@ -444,9 +443,9 @@ char *ShowImageMode::requestDefaultViewer()
   
   ttw = tth = 10;
   ttx = tty = 5;
-  win = new AWindow( aguix );
 
-  win->create( NULL, 10, 10, ttw, tth, 0, catalog.getLocale( 534 ) );
+  win = new AWindow( aguix, 10, 10, ttw, tth, 0, catalog.getLocale( 534 ) );
+  win->create();
 
   win->addTextFromString( catalog.getLocale( 535 ),
                           ttx, tty, 5,
@@ -532,7 +531,6 @@ char *ShowImageMode::requestDefaultViewer()
     }
   }
   
-  win->close();
   delete win;
 
   return result;
