@@ -1,6 +1,6 @@
 /* togglelistermodeop.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * Copyright (C) 2001-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: togglelistermodeop.cc,v 1.12 2004/10/27 21:09:33 ralf Exp $ */
+/* $Id: togglelistermodeop.cc,v 1.13 2005/05/15 20:56:17 ralf Exp $ */
 
 #include "togglelistermodeop.h"
 #include "listermode.h"
@@ -116,11 +116,11 @@ ToggleListermodeOp::configure()
   
   w=h=10;
   x=y=5;
-  win=new AWindow(aguix);
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(39))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(39));
-  win->create(NULL,10,10,w,h,0,tstr);
+  win = new AWindow( aguix, 10, 10, w, h, 0, tstr );
+  win->create();
   _freesafe(tstr);
 
   ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(112),1));
@@ -190,7 +190,6 @@ ToggleListermodeOp::configure()
     mode=cyb->getSelectedOption();
   }
   
-  win->close();
   delete win;
 
   return endmode;
