@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: wconfig.h,v 1.54 2005/02/15 07:20:50 ralf Exp $ */
+/* $Id: wconfig.h,v 1.55 2005/07/07 18:28:22 ralf Exp $ */
 
 #ifndef WCONFIG_H
 #define WCONFIG_H
@@ -114,6 +114,13 @@ protected:
   enum shortkey_type type;
 };
 
+namespace FlatTypeList {
+  typedef struct {
+    WCFiletype *filetype;
+    int depth;
+  } flattypelist_t;
+}
+
 class WConfig
 {
 public:
@@ -286,6 +293,11 @@ public:
   bool getLayoutListviewVert() const;
   void clearLayoutOrders();
   void layoutAddEntry( layoutID_t nv );
+
+  std::vector<FlatTypeList::flattypelist_t> *getFlatTypeList();
+  void buildLVFromFlat( FieldListView *lv,
+			std::vector<FlatTypeList::flattypelist_t> *l1,
+			WCFiletype *highlightft );
 protected:
   char *lang;
   unsigned int rows,columns;
@@ -716,4 +728,3 @@ void freecoms(List*);
 extern WConfig *wconfig;
 
 #endif
-
