@@ -1,6 +1,6 @@
 /* wconfigglb.cc
  * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004 Ralf Hoffmann.
+ * Copyright (C) 2004-2005 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: wconfigglb.cc,v 1.5 2005/01/11 23:29:46 ralf Exp $ */
+/* $Id: wconfigglb.cc,v 1.7 2005/06/23 18:14:35 ralf Exp $ */
 
 #include "wconfig.h"
 #include "worker.h"
@@ -265,7 +265,7 @@ int updateLayoutButtonText( bool bv,
 bool WConfig::configureLayout()
 {
   AGUIX *aguix = worker->getAGUIX();
-  AWindow *win = new AWindow( aguix );
+  AWindow *win = new AWindow( aguix, 10, 10, 100, 100, 0, catalog.getLocale( 569 ) );
   const int cincw = AContainer::ACONT_MINH +
                     AContainer::ACONT_MINW +
                     AContainer::ACONT_MAXH;
@@ -285,7 +285,7 @@ bool WConfig::configureLayout()
   
   bv = layoutConf.buttonVert;
   lvv = layoutConf.listviewVert;
-  win->create( NULL, 10, 10, 100, 100, 0, catalog.getLocale( 569 ) );
+  win->create();
   
   // global container 1x3
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 6 ), true );
@@ -488,7 +488,6 @@ bool WConfig::configureLayout()
     layoutConf.buttonVert = bv;
     layoutConf.listviewVert = lvv;
   }
-  win->close();
   delete win;
   return ( ende == -1 ) ? false : true;
 }
@@ -499,9 +498,9 @@ bool WConfig::changeGlobal()
   // Aktuelle Daten aendern, bei Cancel Daten aus twconfig wiederherstellen
   AGUIX *aguix=worker->getAGUIX();
   CycleButton *cyb;
-  AWindow *glwin=new AWindow(aguix);
+  AWindow *glwin = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 1 ) );
 
-  glwin->create(NULL,10,10,10,10,0,catalog.getLocale(1));
+  glwin->create();
   const char *textstr;
   char *buttonstr;
   int erg;
@@ -860,7 +859,6 @@ bool WConfig::changeGlobal()
     setShowStringForDirSize((sfds_cb->getState()==1)?true:false);
   }
   delete wconfig_bak;
-  glwin->close();
   delete glwin;
   delete req;
   return (ende==-1)?false:true;
@@ -870,7 +868,7 @@ bool WConfig::changeDisplaySets(int side)
 {
   bool *sels;
   AGUIX *aguix=worker->getAGUIX();
-  AWindow *win=new AWindow(aguix);
+  AWindow *win = new AWindow( aguix, 10, 10, 100, 100, 0, catalog.getLocale( 235 ) );
   unsigned int j, ui;
   int trow;
   int i1, i2;
@@ -886,7 +884,7 @@ bool WConfig::changeDisplaySets(int side)
   const int cmin = AContainer::ACONT_MINH +
                    AContainer::ACONT_MINW;
   
-  win->create(NULL,10,10,100,100,0,catalog.getLocale(235));
+  win->create();
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
@@ -1001,7 +999,7 @@ bool WConfig::changeDisplaySets(int side)
         if(msg->button.button==okb) ende=1;
         else if(msg->button.button==cancelb) ende=-1;
         else if(msg->button.button==upb) {
-          int trow = lv1->getActiveRow();
+          trow = lv1->getActiveRow();
           if ( lv1->isValidRow( trow ) == true ) {
             if ( trow > 0) {
               lv1->swapRows( trow, trow - 1 );
@@ -1010,7 +1008,7 @@ bool WConfig::changeDisplaySets(int side)
             }
           }
         } else if(msg->button.button==downb) {
-          int trow = lv1->getActiveRow();
+          trow = lv1->getActiveRow();
           if ( lv1->isValidRow( trow ) == true ) {
             if ( trow < ( lv1->getElements() - 1 ) ) {
               lv1->swapRows( trow, trow + 1 );
@@ -1019,7 +1017,8 @@ bool WConfig::changeDisplaySets(int side)
             }
           }
         } else if(msg->button.button==delb) {
-          int trow = lv1->getActiveRow(), trow2, trow3;
+          int trow2, trow3;
+          trow = lv1->getActiveRow();
           if ( lv1->isValidRow( trow ) == true ) {
             // first find entry from availlist
             for ( j = 0, i1 = -1; j < WorkerTypes::getAvailListColsSize(); j++ ) {
@@ -1051,7 +1050,8 @@ bool WConfig::changeDisplaySets(int side)
             lv2->redraw();
           }
         } else if(msg->button.button==insb) {
-          int trow = lv2->getActiveRow(), trow2;
+          int trow2;
+          trow = lv2->getActiveRow();
           if ( lv2->isValidRow( trow ) == true ) {
             trow2 = lv1->addRow();
             lv1->setText( trow2, 0, lv2->getText( trow, 0 ) );
@@ -1079,7 +1079,6 @@ bool WConfig::changeDisplaySets(int side)
       trow2++;
     }
   }
-  win->close();
   delete win;
   delete [] sels;
   return (ende==-1)?false:true;
@@ -1090,7 +1089,7 @@ bool WConfig::changeFileSets()
   WConfig *twconfig = duplicate();
   char tstr[ A_BYTESFORNUMBER( int ) ];
   AGUIX *aguix = worker->getAGUIX();
-  AWindow *win = new AWindow( aguix );
+  AWindow *win = new AWindow( aguix, 10, 10, 100, 100, 0, catalog.getLocale( 16 ) );
   const int cfix = AContainer::ACONT_MINH +
                    AContainer::ACONT_MINW +
                    AContainer::ACONT_MAXH +
@@ -1105,7 +1104,7 @@ bool WConfig::changeFileSets()
   AGMessage *msg;
   int ende;
   
-  win->create( NULL, 10, 10, 100, 100, 0, catalog.getLocale( 16 ) ); // Groesse wird spaeter angepasst
+  win->create();
   
   // global container 1x3
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
@@ -1428,7 +1427,6 @@ bool WConfig::changeFileSets()
     if(i<5) i=5;
     setVBarWidth(1,i);
   }
-  win->close();
   delete win;
   delete twconfig;
   return (ende==-1)?false:true;
