@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker.cc,v 1.110 2005/03/29 20:17:22 ralf Exp $ */
+/* $Id: worker.cc,v 1.113 2005/07/13 20:00:58 ralf Exp $ */
 
 #include "worker.h"
 #include "lister.h"
@@ -45,6 +45,7 @@
 #include "configparser.tab.h"
 #include "worker_shm.h"
 #include "parentactionop.h"
+#include <aguix/textstorage.h>
 
 Requester *Worker::req_static=NULL;
 int Worker::argc = 0;
@@ -808,7 +809,19 @@ void Worker::setupMainWin()
 
 void Worker::setStatebarText(const char *str)
 {
-  if(statebar!=NULL) statebar->setText(str);
+  if ( statebar != NULL ) {
+    statebar->setText( str );
+    last_statebar_text[0] = last_statebar_text[1];
+    last_statebar_text[1] = str;
+  }
+}
+
+void Worker::resetStatebarText()
+{
+  std::string str1;
+
+  str1 = last_statebar_text[0];
+  setStatebarText( str1.c_str() );
 }
 
 void Worker::shufflePath()
@@ -1307,6 +1320,11 @@ int Worker::saveListerState()
     WConfig::configOpenSection( fh, "right" );
     lister[1]->saveState( fh );
     WConfig::configCloseSection( fh ); //right
+
+    if ( fh->errors() != 0 ) {
+      //TODO: Requester zeigen?
+      fprintf( stderr, "Worker:error while writing listview configuration (lvconf)\n" );
+    }
     fh->close();
   }
   delete fh;
@@ -1869,9 +1887,9 @@ void Worker::activateShortkeyFromList()
   sks->sort(Worker::shortkeysort);
   
   // create window
-  win=new AWindow(aguix);
   lw=lh=20;
-  win->create(NULL,10,10,lw,lh,0,catalog.getLocale(387));
+  win = new AWindow( aguix, 10, 10, lw, lh, 0, catalog.getLocale( 387 ) );
+  win->create();
   
   tx=ty=5;
   ttext=(Text*)win->add(new Text(aguix,tx,ty,catalog.getLocale(388),1));
@@ -2024,7 +2042,7 @@ void Worker::activateShortkeyFromList()
         if ( win->isParent( msg->key.window, false ) == true ) {
           if((msg->key.key==XK_Return)||
              (msg->key.key==XK_KP_Enter)) {
-            if ( cb->hasFocus() == false ) {
+            if ( cb->getHasFocus() == false ) {
               ende=1;
             }
           } else if(msg->key.key==XK_Escape) {
@@ -2060,7 +2078,6 @@ void Worker::activateShortkeyFromList()
   if(ende==1) {
     l = lv->getActiveRow();
   }
-  win->close();
   delete win;
 
   if(l>=0) {
@@ -2404,92 +2421,14 @@ void Worker::closeMainWin()
     delete [] pathbs;
     pathbs = NULL;
   }
-  mainwin->close();
   delete mainwin;
   mainwin = NULL;
 }
 
 void Worker::showLicense()
 {
-  AWindow *lwin;
-  AGMessage *msg;
-  int endmode = -1;
-  FieldListView *llv;
-  int my_w, my_h;
-  Button *okb;
-  const char **pstr;
-  int row;
-  
-  lwin = new AWindow( aguix );
-  lwin->create( NULL, 5, 5, 10, 10, 0, catalog.getLocale( 509 ) );
-  lwin->useStippleBackground();
-  
-  llv = (FieldListView*)lwin->add( new FieldListView( aguix,
-                                                      5,
-                                                      5,
-                                                      50 * aguix->getCharWidth(),
-                                                      20 * aguix->getCharHeight(),
-                                                      0 ) );
-  llv->setHBarState( 2 );
-  llv->setVBarState( 2 );
-  
-  pstr = &cgpl[0];
-  while ( *pstr != NULL ) {
-    row = llv->addRow();
-    llv->setText( row, 0, *pstr );
-    llv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
-    pstr++;
-  }
-  
-  okb = (Button*)lwin->add( new Button( aguix,
-                                        5,
-                                        llv->getY() + llv->getHeight() + 5,
-                                        catalog.getLocale( 11 ),
-                                        1,
-                                        0,
-                                        0 ) );
-  
-  lwin->maximizeX();
-  lwin->maximizeY();
-  my_w = lwin->getWidth();
-  my_h = lwin->getHeight();
-  AGUIX::scaleElementsW( my_w, 5, 10, -1, false, false, (GUIElement**)&okb, NULL, 1 );
-  
-  lwin->setDoTabCycling( true );
-  lwin->setMinSize( my_w, my_h );
-  lwin->show();
-  llv->redraw();
-
-  for( ;endmode == -1; ) {
-    msg = aguix->WaitMessage( lwin );
-    if ( msg != NULL ) {
-      switch ( msg->type ) {
-        case AG_CLOSEWINDOW:
-          if ( msg->closewindow.window == lwin->getWindow() ) endmode = 0;
-          break;
-        case AG_BUTTONCLICKED:
-          if ( msg->button.button == okb ) endmode = 1;
-          break;
-        case AG_KEYPRESSED:
-          if ( lwin->isParent( msg->key.window, false ) == true ) {
-            if ( ( msg->key.key == XK_Return ) ||
-                 ( msg->key.key == XK_Escape ) ) endmode = 0;
-          }
-          break;
-        case AG_SIZECHANGED:
-          if ( msg->size.window == lwin->getWindow() ) {
-            okb->move ( okb->getX(), msg->size.newh - 5 - okb->getHeight() );
-            llv->resize( msg->size.neww - 10, okb->getY() - 5 - llv->getY() );
-            AGUIX::scaleElementsW( msg->size.neww, 5, 10, -1, false, false, (GUIElement**)&okb, NULL, 1 );
-          }
-          break;
-      }
-      aguix->ReplyMessage( msg );
-    }
-  }
-
-  lwin->close();
-  delete lwin;
+  TextStorageString ts( cgpl );
+  req_static->request( catalog.getLocale( 509 ), ts, catalog.getLocale( 11 ) );
 }
 
 void Worker::setWaitCursor()
@@ -2641,8 +2580,8 @@ void Worker::createMainWin()
   
   rows=wconfig->getRows();
   columns=wconfig->getColumns();
-  mainwin=new AWindow(aguix);
-  mainwin->create(NULL,10,10,w,h,0,"Worker");
+  mainwin = new AWindow( aguix, 10, 10, w, h, 0, "Worker" );
+  mainwin->create();
   mainwin->setMinSize(300,200);
 
   aboutb=new Button(aguix,0,0,"A",1,0,1);
@@ -2657,11 +2596,13 @@ void Worker::createMainWin()
   clockbar->setShowDual(false);
   clockbar->setAllowWheel( true );
   
-  listerwin[0] = new AWindow( aguix );
-  listerwin[0]->create( mainwin, 0, 0, 200, 200, 0, "" );
+  listerwin[0] = new AWindow( aguix, 0, 0, 200, 200, 0, "" );
+  mainwin->add( listerwin[0] );
+  listerwin[0]->create();
   listerwin[0]->show();
-  listerwin[1] = new AWindow( aguix );
-  listerwin[1]->create( mainwin, 0, 0, 200, 200, 0, "" );
+  listerwin[1] = new AWindow( aguix, 0, 0, 200, 200, 0, "" );
+  mainwin->add( listerwin[1] );
+  listerwin[1]->create();
   listerwin[1]->show();
   
   mainwin->show();
@@ -2720,3 +2661,155 @@ int Worker::getMaxButtonsWidth()
   return 0;
 }
 
+/*
+ * this method will execute a given string
+ * Worker will fork and wait for this child while the child also forks
+ * and wait for his child
+ *
+ * This way Worker can sent disconnect signal and
+ * the actual program can run even when Worker quits
+ *
+ * for detach I use 2 pipes with the following protocol:
+ * 1.child will always wait for ack from Worker before
+ *   he quits (to avoid broken pipes!)
+ * 2.Worker will not access any pipes when he sent ack single
+ *   (some reason)
+ * 3.Worker will always wait for his child to quit
+ *   (for the child the pipes are opened until he exits)
+ * 4.Child will send Q when his child quits
+ * 5.Worker can send D when user want to detach
+ * 6.After D signal or receiving Q signal Worker
+ *   send A
+ *
+ * it's complicated but avoids any problems with broken pipes (child
+ * exits same time user want to detach->Worker would write to closed pipe)
+ *
+ * an other idea is to use shared memory segmentbut that's not so portable
+ * although it's much nicer
+ */
+int Worker::runCommand( const char*exestr,
+			const char *tmpname,
+			const char *tmpoutput,
+			bool inbackground )
+{
+  pid_t child, ret, p2;
+  int status, retval;
+  
+  setWaitCursor();
+  WorkerSHM::initSHM();
+  if ( WorkerSHM::WSHMInit == true ) {
+    *( WorkerSHM::WSHMPtr ) = ' ';
+  }
+  child = fork();
+  if ( child != 0 ) {
+    // parent
+    if ( child == -1 ) {
+      unsetWaitCursor();
+      return -2;
+    }
+    retval = 0;
+    // calling these functions will clear old values
+    aguix->getLastKeyRelease();
+    aguix->getLastMouseRelease();
+    if ( inbackground == false ) {
+      setStatebarText( catalog.getLocale( 547 ) );
+    }
+    // after setting this flag Worker won't read/write from the pipe
+    // because the child is expected to exit right after this
+    for(;;) {
+      // first answer all messages to be able to redraw
+      aguix->doXMsgs( NULL, false );
+      // check for events to disconnect from child
+      if ( ( aguix->getLastKeyRelease() == XK_Escape ) ||
+           ( aguix->getLastMouseRelease() == Button2 ) ) {
+        if ( WorkerSHM::WSHMInit == true ) {
+          *(WorkerSHM::WSHMPtr ) = 'Q';
+        }
+      }
+      // now check for existence of the child
+      ret = waitpid( child, &status, WNOHANG );
+      if ( ret == child ) {
+        if ( WIFEXITED( status ) ) {
+          // normal exit
+#ifdef DEBUG
+          printf( "child normally exited!\n" );
+#endif
+          retval = WEXITSTATUS( status );
+          break;
+        } else if ( WIFSIGNALED( status ) ) {
+#ifdef DEBUG
+          printf("child exited by a signal!\n");
+#endif
+          retval = -1;
+          break;
+        }
+      }
+      // wait some time and the retry
+      waittime( 10 );
+    }
+    unsetWaitCursor();
+    if ( inbackground == false ) {
+      resetStatebarText();
+    }
+    return retval;
+  }
+  // child
+  // from now on I will use _exit instead of exit to avoid calling
+  // exit handlers
+  // avfs currently has the problem that a exit handler removes
+  // the temp. directory rendering the vfs for the main process
+  // useless
+  //TODO:If this changes in avfs, I will use exit again
+  // wait for second child exit until there is something in the pipe
+
+  // disconnect from parent
+  setsid();
+  worker_chdir( "/" );
+
+  p2 = fork();
+  if ( p2 != 0 ) {
+    // parent
+    if ( p2 < 0 ) {
+      // error
+      _exit( EXIT_FAILURE );
+    } else {
+      // exit immediately when command should run in background
+      bool doexit = inbackground;
+
+      while ( doexit == false ) {
+        ret = waitpid( p2, &status, WNOHANG );
+        if ( ret == p2 ) {
+          doexit = true;
+          continue;
+        }
+        if ( WorkerSHM::WSHMInit == true ) {
+          if ( *(WorkerSHM::WSHMPtr) == 'Q' ) {
+            doexit = true;
+            continue;
+          }
+        }
+        // wait some time and retry
+        waittime( 10 );
+      }
+      _exit( EXIT_SUCCESS );
+    }
+  }
+  setsid();
+  // execute command
+  // we could use exec* to call this
+  //   but then we have to change exestr to give a char**argv
+  //   (which is not so hard because it contains only the commands to execute
+  //    tmpname)
+  //   we also have to make another fork because exec* doesn't return
+  //     and so we need an other process to remove the tmp-files after command finished
+  system( exestr );
+  
+  // remove temp files
+  worker_unlink( tmpname );
+  worker_unlink( tmpoutput );
+  
+  // and exit
+  _exit( EXIT_SUCCESS );
+  // just for some compiler to compile without warning
+  return 0;
+}
