@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker.h,v 1.40 2004/10/27 21:10:13 ralf Exp $ */
+/* $Id: worker.h,v 1.41 2005/07/07 18:28:53 ralf Exp $ */
 
 #ifndef WORKER_H
 #define WORKER_H
@@ -37,6 +37,7 @@
 #include "dnd.h"
 #include "partspace.h"
 #include <aguix/acontainer.h>
+#include <string>
 
 class ListerMode;
 class Lister;
@@ -59,6 +60,7 @@ public:
   ListerMode *getMode4ID(int,Lister *);
   AWindow *getMainWin();
   void setStatebarText(const char*);
+  void resetStatebarText();
   static int getNrOfCommands();
   FunctionProto *getCommand4ID(int);
   static int getID4Command(FunctionProto*);
@@ -89,7 +91,12 @@ public:
   void setWaitCursor();
   void unsetWaitCursor();
   static const std::string getDataDir();
-protected:
+  
+  int runCommand( const char *exestr,
+		  const char *tmpname,
+		  const char *tmpoutput,
+		  bool inbackground );
+ protected:
   void createMainWin();
   void setupMainWin();
   void closeMainWin();
@@ -166,6 +173,7 @@ protected:
   bool restart;
   bool configstarted;
 
+  std::string last_statebar_text[2];
 };
 
 #endif
