@@ -18,14 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* $Id: worker_locale.cc,v 1.165 2005/03/23 21:51:41 ralf Exp $ */
+/* $Id: worker_locale.cc,v 1.168 2005/07/13 20:20:06 ralf Exp $ */
 
 #include "worker_locale.h"
 #include "wconfig.h"
 #include "worker.h"
 
-#define CATENTRY 632
-#define CATCOMENTRY 49
+#define CATENTRY 648
+#define CATCOMENTRY 50
 #define CATFLAGENTRY 59
 
 #define min(a,b) (((a)<(b))?(a):(b))
@@ -726,6 +726,22 @@ don't need a password for a connection to the destination. Otherwise it|\
 will not work at all or you will be asked for the password many times|\
 if you have the ssh_askpass tool. Do you really want to continue?" );
   catalog[631]=dupstring( "Don't ask me again" );
+  catalog[632]=dupstring( "Show mode:" );
+  catalog[633]=dupstring( "Close" );
+  catalog[634]=dupstring( "Show active file" );
+  catalog[635]=dupstring( "Show custom file" );
+  catalog[636]=dupstring( "Custom file:" );
+  catalog[637]=dupstring( "Word wrapping" );
+  catalog[638]=dupstring( "Settings:" );
+  catalog[639]=dupstring( "Enter command:" );
+  catalog[640]=dupstring( "Enter archive handler or choose from list:" );
+  catalog[641]=dupstring( "Execute command" );
+  catalog[642]=dupstring( "Handle like filetype" );
+  catalog[643]=dupstring( "Handle as archive" );
+  catalog[644]=dupstring( "Select filetype. Its double click action will be executed on the active file." );
+  catalog[645]=dupstring( "Start program or apply different action to the current file:" );
+  catalog[646]=dupstring( "The action list of the filetype is empty, you can select a different action here:" );
+  catalog[647]=dupstring( "Error while writing command file %s!|Can't execute external programm." );
 
 //  catalog[]=dupstring( "" );
   
@@ -778,6 +794,7 @@ if you have the ssh_askpass tool. Do you really want to continue?" );
   catalogcom[46]=dupstring( "start action of parent type" );
   catalogcom[47]=dupstring( "do nothing" );
   catalogcom[48]=dupstring( "FTP connection" );
+  catalogcom[49]=dupstring( "Internal text viewer" );
   
   catalogflag[0]=dupstring( "Stringrequester" );
   catalogflag[1]=dupstring( "path" );
